@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Copyright (C) 2009-2012:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #    Gregory Starck, g.starck@gmail.com
@@ -25,15 +25,20 @@
 DIR="$(cd $(dirname "$0"); pwd)"
 echo "$DIR"
 
+# Prepare the launch by cleaning var/log directories
+. $DIR/preparedev
+
 cd "$DIR/.."
 
 export LANG=us_US.UTF-8
+# Protect against proxy variable for dev
+unset http_proxy
+unset https_proxy
+
 
-# Currently skonf is not stable, disabling it
-#"$DIR"/launch_skonf_debug.sh
 "$DIR"/launch_scheduler_debug.sh
 "$DIR"/launch_poller_debug.sh
 "$DIR"/launch_reactionner_debug.sh
 "$DIR"/launch_broker_debug.sh
-#"$DIR"/launch_receiver_debug.sh
+"$DIR"/launch_receiver_debug.sh
 "$DIR"/launch_arbiter_debug.sh
