@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Copyright (C) 2009-2012:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #    Gregory Starck, g.starck@gmail.com
@@ -23,17 +23,17 @@
 
 
 DIR="$(cd $(dirname "$0"); pwd)"
-BIN="$DIR"/../bin
+BIN="$DIR"/../shinken/bin
 ETC="$DIR"/../etc
 DEBUG_PATH="/tmp/arbiter.debug"
 
 # Need to change directory to .../var because arbiter doesn't have a
 # default 'workdir' "properties" attribute:.
-cd "$DIR"/../var
+cd /var/run/shinken
 
 echo "Launching Arbiter (which reads configuration and dispatches it) " \
     "in debug mode to the file $DEBUG_PATH"
 
-"$BIN"/shinken-arbiter -d \
-    -c "$ETC"/nagios.cfg -c "$ETC"/shinken-specific.cfg -c "$ETC"/sample.cfg \
+"$BIN"/shinken_arbiter.py -d \
+    -c "$ETC"/shinken.cfg  -c "$ETC"/sample.cfg -c "$ETC"/dev.cfg\
     --debug "$DEBUG_PATH" -p /tmp/arbiter.profile
