@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Copyright (C) 2009-2012:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #    Gregory Starck, g.starck@gmail.com
@@ -28,7 +28,7 @@ ETC="$DIR"/../etc
 
 echo "Stopping broker"
 
-parent=$(cat "$DIR"/../var/brokerd.pid)
+parent=$(cat /var/run/shinken/brokerd.pid)
 
 kill $parent
 sleep 1
@@ -36,7 +36,7 @@ sleep 1
 # kill parent and childs broker processes
 for brokerpid in $(ps -f --ppid $parent | grep "shinken-broker" | awk '{print $2}')
 do
-    echo "KILLING BROKER PROCESS" $brokerpid
+    echo "KILLING MODULE BROKER PROCESS" $brokerpid
     kill $brokerpid
 done
 
