@@ -1,8 +1,7 @@
 #!/usr/bin/env python
-
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2009-2012:
+# Copyright (C) 2009-2014:
 #     Gabes Jean, naparuba@gmail.com
 #     Gerhard Lausser, Gerhard.Lausser@consol.de
 #     Gregory Starck, g.starck@gmail.com
@@ -31,58 +30,60 @@ import signal
 import select
 import random
 import ConfigParser
-import json
 import threading
-import inspect
 import traceback
 import cStringIO
 import logging
 import inspect
+from Queue import Empty
 
 # Try to see if we are in an android device or not
-is_android = True
 try:
     import android
+    is_android = True
 except ImportError:
     is_android = False
-
-if not is_android:
-    from multiprocessing import Queue, Manager, active_children, cpu_count
     from multiprocessing.managers import SyncManager
-else:
-    from multiprocessing import active_children
 
-import http_daemon
+
+import shinken.http_daemon
 from shinken.http_daemon import HTTPDaemon, InvalidWorkDir
 from shinken.log import logger
+from shinken.stats import statsmgr
 from shinken.modulesctx import modulesctx
 from shinken.modulesmanager import ModulesManager
-from shinken.property import StringProp, BoolProp, PathProp, ConfigPathProp, IntegerProp, LogLevelProp
+from shinken.property import StringProp, BoolProp, PathProp, ConfigPathProp, IntegerProp,\
+    LogLevelProp
+from shinken.misc.common import setproctitle
 
 
 try:
-    import pwd, grp
+    import pwd
+    import grp
     from pwd import getpwnam
-    from grp import getgrnam
-
+    from grp import getgrnam, getgrall
 
     def get_cur_user():
         return pwd.getpwuid(os.getuid()).pw_name
 
-
     def get_cur_group():
         return grp.getgrgid(os.getgid()).gr_name
+
+    def get_all_groups():
+        return getgrall()
 except ImportError, exp:  # Like in nt system or Android
     # temporary workaround:
     def get_cur_user():
         return "shinken"
 
-
     def get_cur_group():
         return "shinken"
 
+    def get_all_groups():
+        return []
 
-##########################   DAEMON PART    ###############################
+
+# #########################   DAEMON PART    ###############################
 # The standard I/O file descriptors are redirected to /dev/null by default.
 REDIRECT_TO = getattr(os, "devnull", "/dev/null")
 
@@ -90,7 +91,8 @@ UMASK = 027
 from shinken.bin import VERSION
 
 """ TODO: Add some comment about this class for the doc"""
-class InvalidPidFile(Exception): pass
+class InvalidPidFile(Exception):
+    pass
 
 
 """ Interface for Inter satellites communications """
@@ -99,15 +101,22 @@ class Interface(object):
     #  'app' is to be set to the owner of this interface.
     def __init__(self, app):
         self.app = app
-        self.running_id = "%d.%d" % (time.time(), random.random())
+        self.start_time = int(time.time())
 
-    
-    doc = 'Test the connexion to the daemon. Returns: pong'
+        self.running_id = "%d.%d" % (
+            self.start_time, random.randint(0, 100000000)
+        )
+
+
+    doc = 'Test the connection to the daemon. Returns: pong'
     def ping(self):
         return "pong"
     ping.need_lock = False
     ping.doc = doc
 
+    doc = 'Get the start time of the daemon'
+    def get_start_time(self):
+        return self.start_time
 
     doc = 'Get the current running id of the daemon (scheduler)'
     def get_running_id(self):
@@ -136,18 +145,21 @@ class Interface(object):
     have_conf.need_lock = False
     have_conf.doc = doc
 
-    
+
     doc = 'Set the current log level in [NOTSET, DEBUG, INFO, WARNING, ERROR, CRITICAL, UNKNOWN]'
     def set_log_level(self, loglevel):
-        return logger.set_level(loglevel)
+        return logger.setLevel(loglevel)
     set_log_level.doc = doc
 
 
     doc = 'Get the current log level in [NOTSET, DEBUG, INFO, WARNING, ERROR, CRITICAL, UNKNOWN]'
     def get_log_level(self):
-        return {logging.NOTSET: 'NOTSET', logging.DEBUG:'DEBUG',
-                logging.INFO: 'INFO', logging.WARNING: 'WARNING',
-                logging.ERROR : 'ERROR', logging.CRITICAL : 'CRITICAL'}.get(logger._level, 'UNKNOWN')
+        return {logging.NOTSET: 'NOTSET',
+                logging.DEBUG: 'DEBUG',
+                logging.INFO: 'INFO',
+                logging.WARNING: 'WARNING',
+                logging.ERROR: 'ERROR',
+                logging.CRITICAL: 'CRITICAL'}.get(logger._level, 'UNKNOWN')
     get_log_level.doc = doc
 
     doc = 'List the methods available on the daemon'
@@ -167,12 +179,12 @@ class Interface(object):
             e = {}
             # Get a string about the args and co
             _s_nondef_args = ', '.join([a for a in args if a not in defaults])
-            _s_def_args = ', '.join( ['%s=%s' % (k,v) for (k,v) in defaults.iteritems()] )
+            _s_def_args = ', '.join(['%s=%s' % (k, v) for (k, v) in defaults.iteritems()])
             _s_args = ''
             if _s_nondef_args:
-                _s_args +=_s_nondef_args
+                _s_args += _s_nondef_args
             if _s_def_args:
-                _s_args += ', '+_s_def_args
+                _s_args += ', ' + _s_def_args
             e['proto'] = '%s(%s)' % (fclean, _s_args)
             e['need_lock'] = getattr(f, 'need_lock', True)
             e['method'] = getattr(f, 'method', 'GET').upper()
@@ -188,10 +200,10 @@ class Interface(object):
 # If we are under android, we can't give parameters
 if is_android:
     DEFAULT_WORK_DIR = '/sdcard/sl4a/scripts/'
-    DEFAULT_LIB_DIR  = DEFAULT_WORK_DIR
+    DEFAULT_LIB_DIR = DEFAULT_WORK_DIR
 else:
     DEFAULT_WORK_DIR = '/var/run/shinken/'
-    DEFAULT_LIB_DIR  = '/var/lib/shinken/'
+    DEFAULT_LIB_DIR = '/var/lib/shinken/'
 
 
 class Daemon(object):
@@ -209,18 +221,18 @@ class Daemon(object):
         'host':          StringProp(default='0.0.0.0'),
         'user':          StringProp(default=get_cur_user()),
         'group':         StringProp(default=get_cur_group()),
-        'use_ssl':       BoolProp(default='0'),
+        'use_ssl':       BoolProp(default=False),
         'server_key':     StringProp(default='etc/certs/server.key'),
         'ca_cert':       StringProp(default='etc/certs/ca.pem'),
         'server_cert':   StringProp(default='etc/certs/server.cert'),
-        'use_local_log': BoolProp(default='1'),
+        'use_local_log': BoolProp(default=True),
         'log_level':     LogLevelProp(default='WARNING'),
-        'hard_ssl_name_check':    BoolProp(default='0'),
-        'idontcareaboutsecurity': BoolProp(default='0'),
-        'daemon_enabled':BoolProp(default='1'),
-        'spare':         BoolProp(default='0'),
-        'max_queue_size': IntegerProp(default='0'),
-        'daemon_thread_pool_size': IntegerProp(default='8'),
+        'hard_ssl_name_check':    BoolProp(default=False),
+        'idontcareaboutsecurity': BoolProp(default=False),
+        'daemon_enabled': BoolProp(default=True),
+        'spare':         BoolProp(default=False),
+        'max_queue_size': IntegerProp(default=0),
+        'daemon_thread_pool_size': IntegerProp(default=8),
         'http_backend':  StringProp(default='auto'),
     }
 
@@ -245,8 +257,8 @@ class Daemon(object):
         self.http_daemon = None
 
         # Log init
-        #self.log = logger
-        #self.log.load_obj(self)
+        # self.log = logger
+        # self.log.load_obj(self)
         logger.load_obj(self)
 
         self.new_conf = None  # used by controller to push conf
@@ -290,17 +302,16 @@ class Daemon(object):
             # Release the lock so the daemon can shutdown without problem
             try:
                 self.http_daemon.lock.release()
-            except:
+            except Exception:
                 pass
             self.http_daemon.shutdown()
-        logger.quit()
 
 
     def request_stop(self):
         self.unlink()
         self.do_stop()
         # Brok facilities are no longer available simply print the message to STDOUT
-        print ("Stopping daemon. Exiting", )
+        print("Stopping daemon. Exiting")
         sys.exit(0)
 
 
@@ -335,7 +346,8 @@ class Daemon(object):
 
     def do_load_modules(self):
         self.modules_manager.load_and_init()
-        logger.info("I correctly loaded the modules: [%s]" % (','.join([inst.get_name() for inst in self.modules_manager.instances])))
+        logger.info("I correctly loaded the modules: [%s]",
+                    ','.join([inst.get_name() for inst in self.modules_manager.instances]))
 
 
     # Dummy method for adding broker to this daemon
@@ -362,6 +374,8 @@ class Daemon(object):
 
 
     def load_modules_manager(self):
+        if not modulesctx.get_modulesdir():
+            modulesctx.set_modulesdir(self.find_modules_path())
         self.modules_manager = ModulesManager(self.name, self.find_modules_path(), [])
         # Set the modules watchdogs
         # TOFIX: Beware, the arbiter do not have the max_queue_size property
@@ -370,10 +384,24 @@ class Daemon(object):
         self.modules_manager.load_manager(self.manager)
 
 
+    # create a dir and set to my user
+    def __create_directory(self, d):
+        if not os.path.exists(d):
+            os.mkdir(d)
+            # And set the user as shinken so the sub-fork can
+            # reopen the pid when no more root
+            if os.name != 'nt':
+                uid = self.find_uid_from_name()
+                gid = self.find_gid_from_name()
+                os.chown(d, uid, gid)
+
 
     def change_to_workdir(self):
         self.workdir = os.path.abspath(self.workdir)
         try:
+            # If the directory is missing, try to create it for me
+            if not os.path.exists(self.workdir):
+                self.__create_directory(self.workdir)
             os.chdir(self.workdir)
         except Exception, e:
             raise InvalidWorkDir(e)
@@ -381,11 +409,11 @@ class Daemon(object):
 
 
     def unlink(self):
-        logger.debug("Unlinking %s" % self.pidfile)
+        logger.debug("Unlinking %s", self.pidfile)
         try:
             os.unlink(self.pidfile)
         except Exception, e:
-            logger.error("Got an error unlinking our pidfile: %s" % (e))
+            logger.error("Got an error unlinking our pidfile: %s", e)
 
 
     # Look if we need a local log or not
@@ -393,12 +421,12 @@ class Daemon(object):
         # The arbiter doesn't have such attribute
         if hasattr(self, 'use_local_log') and self.use_local_log:
             try:
-                #self.local_log_fd = self.log.register_local_log(self.local_log)
+                # self.local_log_fd = self.log.register_local_log(self.local_log)
                 self.local_log_fd = logger.register_local_log(self.local_log)
             except IOError, exp:
-                logger.error("Opening the log file '%s' failed with '%s'" % (self.local_log, exp))
+                logger.error("Opening the log file '%s' failed with '%s'", self.local_log, exp)
                 sys.exit(2)
-            logger.info("Using the local log file '%s'" % self.local_log)
+            logger.info("Using the local log file '%s'", self.local_log)
 
 
     # Only on linux: Check for /dev/shm write access
@@ -409,16 +437,24 @@ class Daemon(object):
             # We get the access rights, and we check them
             mode = stat.S_IMODE(os.lstat(shm_path)[stat.ST_MODE])
             if not mode & stat.S_IWUSR or not mode & stat.S_IRUSR:
-                logger.critical("The directory %s is not writable or readable. Please make it read writable: %s" % (shm_path, shm_path))
+                logger.critical("The directory %s is not writable or readable."
+                                "Please make it read writable: %s", shm_path, shm_path)
                 sys.exit(2)
 
 
     def __open_pidfile(self, write=False):
-        ## if problem on opening or creating file it'll be raised to the caller:
+        # if problem on opening or creating file it'll be raised to the caller:
         try:
             p = os.path.abspath(self.pidfile)
+            # Look if the pid directory is existing or not
+            # (some systems are cleaning /var/run directories, yes I look
+            # at you debian 8)
+            p_dir = os.path.dirname(p)
+            if not os.path.exists(p_dir):
+                self.__create_directory(p_dir)
             self.debug_output.append("Opening pid file: %s" % p)
-            # Windows do not manage the rw+ mode, so we must open in read mode first, then reopen it write mode...
+            # Windows do not manage the rw+ mode,
+            # so we must open in read mode first, then reopen it write mode...
             if not write and os.path.exists(p):
                 self.fpid = open(p, 'r+')
             else:  # If it doesn't exist too, we create it as void
@@ -441,30 +477,32 @@ class Daemon(object):
         try:
             pid = int(self.fpid.readline().strip(' \r\n'))
         except Exception as err:
-            logger.info("Stale pidfile exists at %s (%s). Reusing it." % (err, self.pidfile))
+            logger.info("Stale pidfile exists at %s (%s). Reusing it.", err, self.pidfile)
             return
 
         try:
             os.kill(pid, 0)
-        except Exception as err: # consider any exception as a stale pidfile.
+        except Exception as err:  # consider any exception as a stale pidfile.
             # this includes :
-            #  * PermissionError when a process with same pid exists but is executed by another user.
-            #  * ProcessLookupError: [Errno 3] No such process.
-            logger.info("Stale pidfile exists (%s), Reusing it." % err)
+            #  * PermissionError when a process with same pid exists but is executed by another user
+            #  * ProcessLookupError: [Errno 3] No such process
+            logger.info("Stale pidfile exists (%s), Reusing it.", err)
             return
 
         if not self.do_replace:
-            raise SystemExit("valid pidfile exists (pid=%s) and not forced to replace. Exiting." % pid)
+            raise SystemExit("valid pidfile exists (pid=%s) and not forced to replace. Exiting."
+                             % pid)
 
         self.debug_output.append("Replacing previous instance %d" % pid)
         try:
-            os.kill(pid, signal.SIGQUIT)
+            pgid = os.getpgid(pid)
+            os.killpg(pgid, signal.SIGQUIT)
         except os.error as err:
             if err.errno != errno.ESRCH:
                 raise
 
         self.fpid.close()
-        ## TODO: give some time to wait that previous instance finishes?
+        # TODO: give some time to wait that previous instance finishes?
         time.sleep(1)
         # we must also reopen the pid file in write mode
         # because the previous instance should have deleted it!!
@@ -478,7 +516,7 @@ class Daemon(object):
         self.fpid.truncate()
         self.fpid.write("%d" % (pid))
         self.fpid.close()
-        del self.fpid  ## no longer needed
+        del self.fpid  # no longer needed
 
 
     # Close all the process file descriptors. Skip the descriptors
@@ -513,7 +551,7 @@ class Daemon(object):
         else:
             fdtemp = os.open(REDIRECT_TO, os.O_RDWR)
 
-        ## We close all fd but what we need:
+        # We close all fd but what we need:
         self.close_fds(skip_close_fds + (self.fpid.fileno(), fdtemp))
 
         os.dup2(fdtemp, 1)  # standard output (1)
@@ -523,29 +561,32 @@ class Daemon(object):
         try:
             pid = os.fork()
         except OSError, e:
-            raise Exception, "%s [%d]" % (e.strerror, e.errno)
+            raise Exception("%s [%d]" % (e.strerror, e.errno))
+
         if pid != 0:
             # In the father: we check if our child exit correctly
             # it has to write the pid of our future little child..
             def do_exit(sig, frame):
-                logger.error("Timeout waiting child while it should have quickly returned ; something weird happened")
+                logger.error("Timeout waiting child while it should have quickly returned ;"
+                             "something weird happened")
                 os.kill(pid, 9)
                 sys.exit(1)
             # wait the child process to check its return status:
             signal.signal(signal.SIGALRM, do_exit)
             signal.alarm(3)  # forking & writing a pid in a file should be rather quick..
-            # if it's not then something wrong can already be on the way so let's wait max 3 secs here.
+            # if it's not then something wrong can already be on the way so let's wait max
+            # 3 secs here.
             pid, status = os.waitpid(pid, 0)
             if status != 0:
-                logger.error("Something weird happened with/during second fork: status=", status)
+                logger.error("Something weird happened with/during second fork: status= %s", status)
             os._exit(status != 0)
 
         # halfway to daemonize..
         os.setsid()
         try:
             pid = os.fork()
-        except OSError, e:
-            raise Exception, "%s [%d]" % (e.strerror, e.errno)
+        except OSError as e:
+            raise Exception("%s [%d]" % (e.strerror, e.errno))
         if pid != 0:
             # we are the last step and the real daemon is actually correctly created at least.
             # we have still the last responsibility to write the pid of the daemon itself.
@@ -557,24 +598,57 @@ class Daemon(object):
         self.pid = os.getpid()
         self.debug_output.append("We are now fully daemonized :) pid=%d" % self.pid)
         # We can now output some previously silenced debug output
-        logger.warning("Printing stored debug messages prior to our daemonization")
+        logger.info("Printing stored debug messages prior to our daemonization")
         for s in self.debug_output:
-            logger.debug(s)
+            logger.info(s)
         del self.debug_output
+        self.set_proctitle()
 
 
-    def do_daemon_init_and_start(self, use_pyro=True):
+    if is_android:
+        def _create_manager(self):
+            pass
+    else:
+        # The Manager is a sub-process, so we must be sure it won't have
+        # a socket of your http server alive
+        def _create_manager(self):
+            manager = SyncManager(('127.0.0.1', 0))
+            def close_http_daemon(daemon):
+                try:
+                    # Be sure to release the lock so there won't be lock in shutdown phase
+                    daemon.lock.release()
+                except Exception, exp:
+                    pass
+                daemon.shutdown()
+            # Some multiprocessing lib got problems with start() that cannot take args
+            # so we must look at it before
+            startargs = inspect.getargspec(manager.start)
+            # startargs[0] will be ['self'] if old multiprocessing lib
+            # and ['self', 'initializer', 'initargs'] in newer ones
+            # note: windows do not like pickle http_daemon...
+            if os.name != 'nt' and len(startargs[0]) > 1:
+                manager.start(close_http_daemon, initargs=(self.http_daemon,))
+            else:
+                manager.start()
+            return manager
+
+
+    # Main "go daemon" mode. Will launch the double fork(), close old file descriptor
+    # and such things to have a true DAEMON :D
+    # use_pyro= open the TCP port for communication
+    # fake= use for test to do not launch runonly feature, like the stats reaper thread
+    def do_daemon_init_and_start(self, use_pyro=True, fake=False):
+        self.change_to_workdir()        
         self.change_to_user_group()
-        self.change_to_workdir()
         self.check_parallel_run()
         if use_pyro:
             self.setup_pyro_daemon()
 
         # Setting log level
-        logger.set_level(self.log_level)
+        logger.setLevel(self.log_level)
         # Force the debug level if the daemon is said to start with such level
         if self.debug:
-            logger.set_level('DEBUG')
+            logger.setLevel('DEBUG')
 
         # Then start to log all in the local file if asked so
         self.register_local_log()
@@ -591,31 +665,12 @@ class Daemon(object):
 
         # Now we can start our Manager
         # interprocess things. It's important!
-        if is_android:
-            self.manager = None
-        else:
-            # The Manager is a sub-process, so we must be sure it won't have
-            # a socket of your http server alive
-            self.manager = SyncManager(('127.0.0.1',0))
-            def close_http_daemon(daemon):
-                try:
-                    # Be sure to release the lock so there won't be lock in shutdown phase
-                    daemon.lock.release()
-                except Exception, exp:
-                    pass
-                daemon.shutdown()
-            # Some multiprocessing lib got problems with start() that cannot take args
-            # so we must look at it before
-            startargs = inspect.getargspec(self.manager.start)
-            # startargs[0] will be ['self'] if old multiprocessing lib
-            # and ['self', 'initializer', 'initargs'] in newer ones
-            # note: windows do not like pickle http_daemon...
-            if os.name != 'nt' and len(startargs[0]) > 1:
-                self.manager.start(close_http_daemon, initargs=(self.http_daemon,))
-            else:
-                self.manager.start()
-            # Keep this daemon in the http_daemn module
-        # Will be add to the modules manager later
+        self.manager = self._create_manager()
+
+        # We can start our stats thread but after the double fork() call and if we are not in
+        # a test launch (time.time() is hooked and will do BIG problems there)
+        if not fake:
+            statsmgr.launch_reaper_thread()
 
         # Now start the http_daemon thread
         self.http_thread = None
@@ -643,22 +698,28 @@ class Daemon(object):
         if use_ssl:
             ssl_cert = os.path.abspath(str(ssl_conf.server_cert))
             if not os.path.exists(ssl_cert):
-                logger.error('Error : the SSL certificate %s is missing (server_cert). Please fix it in your configuration' % ssl_cert)
+                logger.error('Error : the SSL certificate %s is missing (server_cert).'
+                             'Please fix it in your configuration', ssl_cert)
                 sys.exit(2)
             ca_cert = os.path.abspath(str(ssl_conf.ca_cert))
-            logger.info("Using ssl ca cert file: %s" % ca_cert)
+            logger.info("Using ssl ca cert file: %s", ca_cert)
             ssl_key = os.path.abspath(str(ssl_conf.server_key))
             if not os.path.exists(ssl_key):
-                logger.error('Error : the SSL key %s is missing (server_key). Please fix it in your configuration' % ssl_key)
+                logger.error('Error : the SSL key %s is missing (server_key).'
+                             'Please fix it in your configuration', ssl_key)
                 sys.exit(2)
-            logger.info("Using ssl server cert/key files: %s/%s" % (ssl_cert, ssl_key))
+            logger.info("Using ssl server cert/key files: %s/%s", ssl_cert, ssl_key)
 
             if ssl_conf.hard_ssl_name_check:
                 logger.info("Enabling hard SSL server name verification")
 
         # Let's create the HTTPDaemon, it will be exec after
-        self.http_daemon = HTTPDaemon(self.host, self.port, http_backend, use_ssl, ca_cert, ssl_key, ssl_cert, ssl_conf.hard_ssl_name_check, self.daemon_thread_pool_size)
-        http_daemon.daemon_inst = self.http_daemon
+        self.http_daemon = HTTPDaemon(self.host, self.port, http_backend,
+                                      use_ssl, ca_cert, ssl_key,
+                                      ssl_cert, ssl_conf.hard_ssl_name_check,
+                                      self.daemon_thread_pool_size)
+        # TODO: fix this "hack" :
+        shinken.http_daemon.daemon_inst = self.http_daemon
 
     # Global loop part
     def get_socks_activity(self, socks, timeout):
@@ -676,29 +737,28 @@ class Daemon(object):
             raise
         return ins
 
-
     # Find the absolute path of the shinken module directory and returns it.
     # If the directory do not exist, we must exit!
     def find_modules_path(self):
-        if not hasattr(self, 'modules_dir') or not self.modules_dir:
-            logger.error("Your configuration is missing the path to the modules (modules_dir). I set it by default to /var/lib/shinken/modules. Please configure it")
-            self.modules_dir = '/var/lib/shinken/modules'
-        self.modules_dir = os.path.abspath(self.modules_dir)
-        logger.info("Modules directory: %s" % (self.modules_dir))
-        if not os.path.exists(self.modules_dir):
-            logger.error("The modules directory '%s' is missing! Bailing out. Please fix your configuration" % self.modules_dir)
-            raise Exception("The modules directory '%s' is missing! Bailing out. Please fix your configuration" % self.modules_dir)
-
-        # Ok remember to populate the modulesctx object
-        modulesctx.set_modulesdir(self.modules_dir)
-
-        return self.modules_dir
+        modules_dir = getattr(self, 'modules_dir', None)
+        if not modules_dir:
+            modules_dir = modulesctx.get_modulesdir()
+            if not modules_dir:
+                logger.error("Your configuration is missing the path to the modules (modules_dir). "
+                             "I set it by default to /var/lib/shinken/modules. Please configure it")
+                modules_dir = '/var/lib/shinken/modules'
+                modulesctx.set_modulesdir(modules_dir)
+            self.modules_dir = modules_dir
+        logger.info("Modules directory: %s", modules_dir)
+        if not os.path.exists(modules_dir):
+            raise RuntimeError("The modules directory '%s' is missing! Bailing out."
+                               "Please fix your configuration" % (modules_dir,))
+        return modules_dir
 
 
     # modules can have process, and they can die
     def check_and_del_zombie_modules(self):
         # Active children make a join with every one, useful :)
-        act = active_children()
         self.modules_manager.check_alive_instances()
         # and try to restart previous dead :)
         self.modules_manager.try_to_restart_deads()
@@ -709,7 +769,7 @@ class Daemon(object):
         try:
             return getpwnam(self.user)[2]
         except KeyError, exp:
-            logger.error("The user %s is unknown" % self.user)
+            logger.error("The user %s is unknown", self.user)
             return None
 
     # Just give the gid of a group by looking at its name
@@ -717,7 +777,7 @@ class Daemon(object):
         try:
             return getgrnam(self.group)[2]
         except KeyError, exp:
-            logger.error("The group %s is unknown" % self.group)
+            logger.error("The group %s is unknown", self.group)
             return None
 
     # Change user of the running program. Just insult the admin
@@ -737,7 +797,7 @@ class Daemon(object):
 
         if (self.user == 'root' or self.group == 'root') and not insane:
             logger.error("You want the application run under the root account?")
-            logger.error("I am not agree with it. If you really want it, put:")
+            logger.error("I do not agree with it. If you really want it, put:")
             logger.error("idontcareaboutsecurity=yes")
             logger.error("in the config file")
             logger.error("Exiting")
@@ -757,13 +817,23 @@ class Daemon(object):
             try:
                 os.initgroups(self.user, gid)
             except OSError, e:
-                logger.warning('Cannot call the additional groups setting with initgroups (%s)' % e.strerror)
+                logger.warning('Cannot call the additional groups setting with initgroups (%s)',
+                               e.strerror)
+        elif hasattr(os, 'setgroups'):
+            groups = [gid] + \
+                     [group.gr_gid for group in get_all_groups() if self.user in group.gr_mem]
+            try:
+                os.setgroups(groups)
+            except OSError, e:
+                logger.warning('Cannot call the additional groups setting with setgroups (%s)',
+                               e.strerror)
         try:
             # First group, then user :)
             os.setregid(gid, gid)
             os.setreuid(uid, uid)
         except OSError, e:
-            logger.error("cannot change user/group to %s/%s (%s [%d]). Exiting" % (self.user, self.group, e.strerror, e.errno))
+            logger.error("cannot change user/group to %s/%s (%s [%d]). Exiting",
+                         self.user, self.group, e.strerror, e.errno)
             sys.exit(2)
 
 
@@ -776,7 +846,7 @@ class Daemon(object):
             config = ConfigParser.ConfigParser()
             config.read(self.config_file)
             if config._sections == {}:
-                logger.error("Bad or missing config file: %s " % self.config_file)
+                logger.error("Bad or missing config file: %s ", self.config_file)
                 sys.exit(2)
             try:
                 for (key, value) in config.items('daemon'):
@@ -786,7 +856,8 @@ class Daemon(object):
             except ConfigParser.InterpolationMissingOptionError, e:
                 e = str(e)
                 wrong_variable = e.split('\n')[3].split(':')[1].strip()
-                logger.error("Incorrect or missing variable '%s' in config file : %s" % (wrong_variable, self.config_file))
+                logger.error("Incorrect or missing variable '%s' in config file : %s",
+                             wrong_variable, self.config_file)
                 sys.exit(2)
         else:
             logger.warning("No config file specified, use defaults parameters")
@@ -800,24 +871,24 @@ class Daemon(object):
     # Some paths can be relatives. We must have a full path by taking
     # the config file by reference
     def relative_paths_to_full(self, reference_path):
-        #print "Create relative paths with", reference_path
+        # print "Create relative paths with", reference_path
         properties = self.__class__.properties
         for prop, entry in properties.items():
             if isinstance(entry, ConfigPathProp):
                 path = getattr(self, prop)
                 if not os.path.isabs(path):
                     new_path = os.path.join(reference_path, path)
-                    #print "DBG: changing", entry, "from", path, "to", new_path
+                    # print "DBG: changing", entry, "from", path, "to", new_path
                     path = new_path
                 setattr(self, prop, path)
-                #print "Setting %s for %s" % (path, prop)
+                # print "Setting %s for %s" % (path, prop)
 
 
     def manage_signal(self, sig, frame):
-        logger.debug("I'm process %d and I received signal %s" % (os.getpid(), str(sig)))
+        logger.debug("I'm process %d and I received signal %s", os.getpid(), str(sig))
         if sig == signal.SIGUSR1:  # if USR1, ask a memory dump
             self.need_dump_memory = True
-        elif sig == signal.SIGUSR2: # if USR2, ask objects dump
+        elif sig == signal.SIGUSR2:  # if USR2, ask objects dump
             self.need_objects_dump = True
         else:  # Ok, really ask us to die :)
             self.interrupted = True
@@ -836,6 +907,8 @@ class Daemon(object):
             for sig in (signal.SIGTERM, signal.SIGINT, signal.SIGUSR1, signal.SIGUSR2):
                 signal.signal(sig, func)
 
+    def set_proctitle(self):
+        setproctitle("shinken-%s" % self.name)
 
     def get_header(self):
         return ["Shinken %s" % VERSION,
@@ -859,14 +932,13 @@ class Daemon(object):
         # The main thing is to have a pool of X concurrent requests for the http_daemon,
         # so "no_lock" calls can always be directly answer without having a "locked" version to
         # finish
-        print "GO FOR IT"
         try:
             self.http_daemon.run()
         except Exception, exp:
-            logger.error('The HTTP daemon failed with the error %s, exiting' % str(exp))
+            logger.error('The HTTP daemon failed with the error %s, exiting', str(exp))
             output = cStringIO.StringIO()
             traceback.print_exc(file=output)
-            logger.error("Back trace of this error: %s" % (output.getvalue()))
+            logger.error("Back trace of this error: %s", output.getvalue())
             output.close()
             self.do_stop()
             # Hard mode exit from a thread
@@ -903,7 +975,7 @@ class Daemon(object):
         if len(ins) == 0:  # trivial case: no fd activity:
             return 0, [], tcdiff
         # HERE WAS THE HTTP, but now it's managed in an other thread
-        #for sock in socks:
+        # for sock in socks:
         #    if sock in ins and sock not in suppl_socks:
         #        ins.remove(sock)
         # Track in elapsed the WHOLE time, even with handling requests
@@ -914,7 +986,8 @@ class Daemon(object):
 
 
     # Check for a possible system time change and act correspondingly.
-    # If such a change is detected then we return the number of seconds that changed. 0 if no time change was detected.
+    # If such a change is detected then we return the number of seconds that changed.
+    # 0 if no time change was detected.
     # Time change can be positive or negative:
     # positive when we have been sent in the future and negative if we have been sent in the past.
     def check_for_system_time_change(self):
@@ -934,7 +1007,7 @@ class Daemon(object):
 
     # Default action for system time change. Actually a log is done
     def compensate_system_time_change(self, difference):
-        logger.warning('A system time change of %s has been detected.  Compensating...' % difference)
+        logger.warning('A system time change of %s has been detected.  Compensating...', difference)
 
 
     # Use to wait conf from arbiter.
@@ -959,15 +1032,18 @@ class Daemon(object):
     # We call the function of modules that got the this
     # hook function
     def hook_point(self, hook_name):
+        _t = time.time()
         for inst in self.modules_manager.instances:
             full_hook_name = 'hook_' + hook_name
             if hasattr(inst, full_hook_name):
                 f = getattr(inst, full_hook_name)
                 try:
                     f(self)
-                except Exception, exp:
-                    logger.warning('The instance %s raised an exception %s. I disabled it, and set it to restart later' % (inst.get_name(), str(exp)))
+                except Exception as exp:
+                    logger.warning('The instance %s raised an exception %s. I disabled it,'
+                                   'and set it to restart later', inst.get_name(), str(exp))
                     self.modules_manager.set_to_restart(inst)
+        statsmgr.incr('core.hook.%s' % hook_name, time.time() - _t)
 
 
     # Dummy function for daemons. Get all retention data
@@ -979,3 +1055,51 @@ class Daemon(object):
     # Save, to get back all data
     def restore_retention_data(self, data):
         pass
+
+
+    # Dummy function for having the stats main structure before sending somewhere
+    def get_stats_struct(self):
+        r = {'metrics': [], 'version': VERSION, 'name': '', 'type': '', 'modules':
+             {'internal': {}, 'external': {}}}
+        modules = r['modules']
+
+        # first get data for all internal modules
+        for mod in self.modules_manager.get_internal_instances():
+            mname = mod.get_name()
+            state = {True: 'ok', False: 'stopped'}[(mod not in self.modules_manager.to_restart)]
+            e = {'name': mname, 'state': state}
+            modules['internal'][mname] = e
+        # Same but for external ones
+        for mod in self.modules_manager.get_external_instances():
+            mname = mod.get_name()
+            state = {True: 'ok', False: 'stopped'}[(mod not in self.modules_manager.to_restart)]
+            e = {'name': mname, 'state': state}
+            modules['external'][mname] = e
+
+        return r
+
+    @staticmethod
+    def print_unrecoverable(trace):
+        logger.critical("I got an unrecoverable error. I have to exit.")
+        logger.critical("You can get help at https://github.com/naparuba/shinken")
+        logger.critical("If you think this is a bug, create a new ticket including"
+                        "details mentioned in the README")
+        logger.critical("Back trace of the error: %s", trace)
+
+    def get_objects_from_from_queues(self):
+        ''' Get objects from "from" queues and add them.
+        :return: True if we got some objects, False otherwise.
+        '''
+        had_some_objects = False
+        for queue in self.modules_manager.get_external_from_queues():
+            while True:
+                try:
+                    o = queue.get(block=False)
+                except (Empty, IOError, EOFError) as err:
+                    if not isinstance(err, Empty):
+                        logger.error("An external module queue got a problem '%s'", str(exp))
+                    break
+                else:
+                    had_some_objects = True
+                    self.add(o)
+        return had_some_objects
