@@ -1,8 +1,7 @@
 #!/usr/bin/python
-
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2009-2012:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #    Gregory Starck, g.starck@gmail.com
@@ -27,29 +26,40 @@ import os
 import sys
 import time
 import traceback
-import socket
 import cPickle
-
+import base64
+import zlib
+import threading
 from multiprocessing import active_children
-from Queue import Empty
 
 from shinken.satellite import BaseSatellite
-
 from shinken.property import PathProp, IntegerProp
 from shinken.util import sort_by_ids
 from shinken.log import logger
-
-import shinken.pyro_wrapper as pyro
-from shinken.pyro_wrapper import Pyro
-
+from shinken.stats import statsmgr
 from shinken.external_command import ExternalCommand
+from shinken.http_client import HTTPClient, HTTPExceptions
+from shinken.daemon import Daemon, Interface
 
-# Pack of common Pyro exceptions
-#Pyro_exp_pack = (Pyro.errors.ProtocolError, Pyro.errors.URIError, \
-#                    Pyro.errors.CommunicationError, \
-#                    Pyro.errors.DaemonError, Pyro.errors.TimeoutError)
+class IStats(Interface):
+    """
+    Interface for various stats about broker activity
+    """
 
-from shinken.pyro_wrapper import Pyro_exp_pack
+    doc = 'Get raw stats from the daemon'
+    def get_raw_stats(self):
+        app = self.app
+        res = []
+
+        insts = [inst for inst in app.modules_manager.instances if inst.is_external]
+        for inst in insts:
+            try:
+                res.append({'module_name': inst.get_name(), 'queue_size': inst.to_q.qsize()})
+            except Exception, exp:
+                res.append({'module_name': inst.get_name(), 'queue_size': 0})
+
+        return res
+    get_raw_stats.doc = doc
 
 
 # Our main APP class
@@ -58,20 +68,22 @@ class Broker(BaseSatellite):
     properties = BaseSatellite.properties.copy()
     properties.update({
         'pidfile':   PathProp(default='brokerd.pid'),
-        'port':      IntegerProp(default='7772'),
+        'port':      IntegerProp(default=7772),
         'local_log': PathProp(default='brokerd.log'),
     })
 
-    def __init__(self, config_file, is_daemon, do_replace, debug, debug_file):
+    def __init__(self, config_file, is_daemon, do_replace, debug, debug_file, profile=''):
 
-        super(Broker, self).__init__('broker', config_file, is_daemon, do_replace, debug, debug_file)
+        super(Broker, self).__init__('broker', config_file, is_daemon, do_replace, debug,
+                                     debug_file)
 
         # Our arbiters
         self.arbiters = {}
 
-        # Our pollers and reactionners
+        # Our pollers, reactionners and receivers
         self.pollers = {}
         self.reactionners = {}
+        self.receivers = {}
 
         # Modules are load one time
         self.have_modules = False
@@ -84,9 +96,16 @@ class Broker(BaseSatellite):
         self.broks = []  # broks to manage
         # broks raised this turn and that needs to be put in self.broks
         self.broks_internal_raised = []
+        # broks raised by the arbiters, we need a lock so the push can be in parallel
+        # to our current activities and won't lock the arbiter
+        self.arbiter_broks = []
+        self.arbiter_broks_lock = threading.RLock()
 
         self.timeout = 1.0
 
+        self.istats = IStats(self)
+
+
     # Schedulers have some queues. We can simplify the call by adding
     # elements into the proper queue just by looking at their type
     # Brok -> self.broks
@@ -100,7 +119,7 @@ class Broker(BaseSatellite):
             self.broks_internal_raised.append(elt)
             return
         elif cls_type == 'externalcommand':
-            logger.debug("Enqueuing an external command '%s'" % str(ExternalCommand.__dict__))
+            logger.debug("Enqueuing an external command '%s'", str(ExternalCommand.__dict__))
             self.external_commands.append(elt)
         # Maybe we got a Message from the modules, it's way to ask something
         # like from now a full data from a scheduler for example.
@@ -114,59 +133,81 @@ class Broker(BaseSatellite):
                 if 'full_instance_id' in data:
                     c_id = data['full_instance_id']
                     source = elt.source
-                    logger.info('The module %s is asking me to get all initial data from the scheduler %d' % (source, c_id))
-                    # so we just reset the connection and the running_id, it will just get all new things
+                    logger.info('The module %s is asking me to get all initial data '
+                                'from the scheduler %d',
+                                source, c_id)
+                    # so we just reset the connection and the running_id,
+                    # it will just get all new things
                     try:
                         self.schedulers[c_id]['con'] = None
                         self.schedulers[c_id]['running_id'] = 0
                     except KeyError:  # maybe this instance was not known, forget it
-                        logger.warning("the module %s ask me a full_instance_id for an unknown ID (%d)!" % (source, c_id))
+                        logger.warning("the module %s ask me a full_instance_id "
+                                       "for an unknown ID (%d)!", source, c_id)
             # Maybe a module tells me that it's dead, I must log it's last words...
             if elt.get_type() == 'ICrash':
                 data = elt.get_data()
-                logger.error('the module %s just crash! Please look at the traceback:' % data['name'])
+                logger.error('the module %s just crash! Please look at the traceback:',
+                             data['name'])
                 logger.error(data['trace'])
 
                 # The module death will be looked for elsewhere and restarted.
 
 
     # Get the good tabs for links by the kind. If unknown, return None
-    def get_links_from_type(self, type):
-        t = {'scheduler': self.schedulers, 'arbiter': self.arbiters, \
-             'poller': self.pollers, 'reactionner': self.reactionners}
-        if type in t:
-            return t[type]
+    def get_links_from_type(self, d_type):
+        t = {'scheduler': self.schedulers,
+             'arbiter': self.arbiters,
+             'poller': self.pollers,
+             'reactionner': self.reactionners,
+             'receiver': self.receivers
+             }
+        if d_type in t:
+            return t[d_type]
         return None
 
-    # Call by arbiter to get our external commands
-    def get_external_commands(self):
-        res = self.external_commands
-        self.external_commands = []
-        return res
+
 
     # Check if we do not connect to often to this
     def is_connection_try_too_close(self, elt):
         now = time.time()
         last_connection = elt['last_connection']
         if now - last_connection < 5:
-            return  True
+            return True
         return False
 
+
+    # wrapper function for the real function do_
+    # just for timing the connection
+    def pynag_con_init(self, id, type='scheduler'):
+        _t = time.time()
+        r = self.do_pynag_con_init(id, type)
+        statsmgr.incr('con-init.%s' % type, time.time() - _t)
+        return r
+
+
     # initialize or re-initialize connection with scheduler or
     # arbiter if type == arbiter
-    def pynag_con_init(self, id, type='scheduler'):
+    def do_pynag_con_init(self, id, type='scheduler'):
         # Get the good links tab for looping..
         links = self.get_links_from_type(type)
         if links is None:
-            logger.debug('Type unknown for connection! %s' % type)
+            logger.debug('Type unknown for connection! %s', type)
             return
 
+        # default timeout for daemons like pollers/reactionners/...
+        timeout = 3
+        data_timeout = 120
+
         if type == 'scheduler':
             # If sched is not active, I do not try to init
             # it is just useless
             is_active = links[id]['active']
             if not is_active:
                 return
+            # schedulers also got real timeout to respect
+            timeout = links[id]['timeout']
+            data_timeout = links[id]['data_timeout']
 
         # If we try to connect too much, we slow down our tests
         if self.is_connection_try_too_close(links[id]):
@@ -179,73 +220,69 @@ class Broker(BaseSatellite):
         running_id = links[id]['running_id']
         # DBG: print "Running id before connection", running_id
         uri = links[id]['uri']
-
         try:
-            socket.setdefaulttimeout(3)
-            links[id]['con'] = Pyro.core.getProxyForURI(uri)
-            socket.setdefaulttimeout(None)
-        except Pyro_exp_pack, exp:
+            con = links[id]['con'] = HTTPClient(uri=uri,
+                                                strong_ssl=links[id]['hard_ssl_name_check'],
+                                                timeout=timeout, data_timeout=data_timeout)
+        except HTTPExceptions, exp:
             # But the multiprocessing module is not compatible with it!
             # so we must disable it immediately after
-            socket.setdefaulttimeout(None)
-            logger.info("Connection problem to the %s %s: %s" % (type, links[id]['name'], str(exp)))
+            logger.info("Connection problem to the %s %s: %s", type, links[id]['name'], str(exp))
             links[id]['con'] = None
             return
 
 
         try:
             # initial ping must be quick
-            pyro.set_timeout(links[id]['con'], 5)
-            links[id]['con'].ping()
-            new_run_id = links[id]['con'].get_running_id()
+            con.get('ping')
+            new_run_id = con.get('get_running_id')
+            new_run_id = float(new_run_id)
             # data transfer can be longer
-            pyro.set_timeout(links[id]['con'], 120)
 
             # The schedulers have been restarted: it has a new run_id.
             # So we clear all verifs, they are obsolete now.
             if new_run_id != running_id:
-                logger.debug("[%s] New running id for the %s %s: %s (was %s)" % (self.name, type, links[id]['name'], new_run_id, running_id))
+                logger.debug("[%s] New running id for the %s %s: %s (was %s)",
+                             self.name, type, links[id]['name'], new_run_id, running_id)
                 links[id]['broks'].clear()
                 # we must ask for a new full broks if
                 # it's a scheduler
                 if type == 'scheduler':
-                    logger.debug("[%s] I ask for a broks generation to the scheduler %s" % (self.name, links[id]['name']))
-                    links[id]['con'].fill_initial_broks(self.name)
+                    logger.debug("[%s] I ask for a broks generation to the scheduler %s",
+                                 self.name, links[id]['name'])
+                    con.get('fill_initial_broks', {'bname': self.name}, wait='long')
             # Ok all is done, we can save this new running id
             links[id]['running_id'] = new_run_id
-        except Pyro_exp_pack, exp:
-            logger.info("Connection problem to the %s %s: %s" % (type, links[id]['name'], str(exp)))
+        except HTTPExceptions, exp:
+            logger.info("Connection problem to the %s %s: %s", type, links[id]['name'], str(exp))
             links[id]['con'] = None
             return
-#        except Pyro.errors.NamingError, exp:
-#            logger.info("[%s] the %s '%s' is not initialized: %s" % (self.name, type, links[id]['name'], str(exp)))
-#            links[id]['con'] = None
-#            return
         except KeyError, exp:
-            logger.info("the %s '%s' is not initialized: %s" % (type, links[id]['name'], str(exp)))
+            logger.info("the %s '%s' is not initialized: %s", type, links[id]['name'], str(exp))
             links[id]['con'] = None
             traceback.print_stack()
             return
 
-        logger.info("Connection OK to the %s %s" % (type, links[id]['name']))
+        logger.info("Connection OK to the %s %s", type, links[id]['name'])
+
 
     # Get a brok. Our role is to put it in the modules
     # DO NOT CHANGE data of b!!!
     # REF: doc/broker-modules.png (4-5)
     def manage_brok(self, b):
-        #logger.info("manage brok")
-
         # Call all modules if they catch the call
         for mod in self.modules_manager.get_internal_instances():
             try:
                 mod.manage_brok(b)
             except Exception, exp:
                 logger.debug(str(exp.__dict__))
-                logger.warning("The mod %s raise an exception: %s, I'm tagging it to restart later" % (mod.get_name(), str(exp)))
-                logger.warning("Exception type: %s" % type(exp))
-                logger.warning("Back trace of this kill: %s" % (traceback.format_exc()))
+                logger.warning("The mod %s raise an exception: %s, I'm tagging it to restart later",
+                               mod.get_name(), str(exp))
+                logger.warning("Exception type: %s", type(exp))
+                logger.warning("Back trace of this kill: %s", traceback.format_exc())
                 self.modules_manager.set_to_restart(mod)
 
+
     # Add broks (a tab) to different queues for
     # internal and external modules
     def add_broks_to_queue(self, broks):
@@ -253,6 +290,7 @@ class Broker(BaseSatellite):
         # internal modules
         self.broks.extend(broks)
 
+
     # Each turn we get all broks from
     # self.broks_internal_raised and we put them in
     # self.broks
@@ -260,19 +298,15 @@ class Broker(BaseSatellite):
         self.add_broks_to_queue(self.broks_internal_raised)
         self.broks_internal_raised = []
 
-    # Get 'objects' from external modules
-    # right now on nobody uses it, but it can be useful
-    # for modules like livestatus to raise external
-    # commands for example
-    def get_objects_from_from_queues(self):
-        for f in self.modules_manager.get_external_from_queues():
-            full_queue = True
-            while full_queue:
-                try:
-                    o = f.get(block=False)
-                    self.add(o)
-                except Empty:
-                    full_queue = False
+
+    # We will get in the broks list the broks from the arbiters,
+    # but as the arbiter_broks list can be push by arbiter without Global lock,
+    # we must protect this with he list lock
+    def interger_arbiter_broks(self):
+        with self.arbiter_broks_lock:
+            self.add_broks_to_queue(self.arbiter_broks)
+            self.arbiter_broks = []
+
 
     # We get new broks from schedulers
     # REF: doc/broker-modules.png (2)
@@ -280,7 +314,7 @@ class Broker(BaseSatellite):
         # Get the good links tab for looping..
         links = self.get_links_from_type(type)
         if links is None:
-            logger.debug('Type unknown for connection! %s' % type)
+            logger.debug('Type unknown for connection! %s', type)
             return
 
         # We check for new check in each schedulers and put
@@ -290,11 +324,21 @@ class Broker(BaseSatellite):
                 con = links[sched_id]['con']
                 if con is not None:  # None = not initialized
                     t0 = time.time()
-                    tmp_broks = con.get_broks(self.name)
-                    logger.debug("%s Broks get in %s" % (len(tmp_broks), time.time() - t0))
+                    # Before ask a call that can be long, do a simple ping to be sure it is alive
+                    con.get('ping')
+                    tmp_broks = con.get('get_broks', {'bname': self.name}, wait='long')
+                    try:
+                        _t = base64.b64decode(tmp_broks)
+                        _t = zlib.decompress(_t)
+                        tmp_broks = cPickle.loads(_t)
+                    except (TypeError, zlib.error, cPickle.PickleError), exp:
+                        logger.error('Cannot load broks data from %s : %s',
+                                     links[sched_id]['name'], exp)
+                        links[sched_id]['con'] = None
+                        continue
+                    logger.debug("%s Broks get in %s", len(tmp_broks), time.time() - t0)
                     for b in tmp_broks.values():
                         b.instance_id = links[sched_id]['instance_id']
-
                     # Ok, we can add theses broks to our queues
                     self.add_broks_to_queue(tmp_broks.values())
 
@@ -302,29 +346,22 @@ class Broker(BaseSatellite):
                     self.pynag_con_init(sched_id, type=type)
             # Ok, con is not known, so we create it
             except KeyError, exp:
-                logger.debug("Key error for get_broks : %s" % str(exp))
-                try:
-                    logger.debug(''.join(Pyro.util.getPyroTraceback(exp)))
-                except:
-                    pass
+                logger.debug("Key error for get_broks : %s", str(exp))
                 self.pynag_con_init(sched_id, type=type)
-            except Pyro.errors.ProtocolError, exp:
-                logger.warning("Connection problem to the %s %s: %s" % (type, links[sched_id]['name'], str(exp)))
+            except HTTPExceptions, exp:
+                logger.warning("Connection problem to the %s %s: %s",
+                               type, links[sched_id]['name'], str(exp))
                 links[sched_id]['con'] = None
             # scheduler must not #be initialized
             except AttributeError, exp:
-                logger.warning("The %s %s should not be initialized: %s" % (type, links[sched_id]['name'], str(exp)))
+                logger.warning("The %s %s should not be initialized: %s",
+                               type, links[sched_id]['name'], str(exp))
             # scheduler must not have checks
-            except Pyro.errors.NamingError, exp:
-                logger.warning("The %s %s should not be initialized: %s" % (type, links[sched_id]['name'], str(exp)))
-            except (Pyro.errors.ConnectionClosedError, Pyro.errors.TimeoutError), exp:
-                logger.warning("Connection problem to the %s %s: %s" % (type, links[sched_id]['name'], str(exp)))
-                links[sched_id]['con'] = None
             #  What the F**k? We do not know what happened,
             # so.. bye bye :)
             except Exception, x:
                 logger.error(str(x))
-                logger.error(''.join(Pyro.util.getPyroTraceback(x)))
+                logger.error(traceback.format_exc())
                 sys.exit(1)
 
 
@@ -357,9 +394,22 @@ class Broker(BaseSatellite):
         else:
             name = 'Unnamed broker'
         self.name = name
-        logger.load_obj(self, name)
+        self.api_key = g_conf['api_key']
+        self.secret = g_conf['secret']
+        self.http_proxy = g_conf['http_proxy']
+        self.statsd_host = g_conf['statsd_host']
+        self.statsd_port = g_conf['statsd_port']
+        self.statsd_prefix = g_conf['statsd_prefix']
+        self.statsd_enabled = g_conf['statsd_enabled']
 
-        logger.debug("[%s] Sending us configuration %s" % (self.name, conf))
+        # We got a name so we can update the logger and the stats global objects
+        logger.load_obj(self, name)
+        statsmgr.register(self, name, 'broker',
+                          api_key=self.api_key, secret=self.secret, http_proxy=self.http_proxy,
+                          statsd_host=self.statsd_host, statsd_port=self.statsd_port,
+                          statsd_prefix=self.statsd_prefix, statsd_enabled=self.statsd_enabled)
+
+        logger.debug("[%s] Sending us configuration %s", self.name, conf)
         # If we've got something in the schedulers, we do not
         # want it anymore
         # self.schedulers.clear()
@@ -390,7 +440,10 @@ class Broker(BaseSatellite):
             if s['name'] in g_conf['satellitemap']:
                 s = dict(s)  # make a copy
                 s.update(g_conf['satellitemap'][s['name']])
-            uri = pyro.create_uri(s['address'], s['port'], 'Broks', self.use_ssl)
+            proto = 'http'
+            if s['use_ssl']:
+                proto = 'https'
+            uri = '%s://%s:%s/' % (proto, s['address'], s['port'])
             self.schedulers[sched_id]['uri'] = uri
 
             self.schedulers[sched_id]['broks'] = broks
@@ -398,8 +451,10 @@ class Broker(BaseSatellite):
             self.schedulers[sched_id]['running_id'] = running_id
             self.schedulers[sched_id]['active'] = s['active']
             self.schedulers[sched_id]['last_connection'] = 0
+            self.schedulers[sched_id]['timeout'] = s['timeout']
+            self.schedulers[sched_id]['data_timeout'] = s['data_timeout']
 
-        logger.info("We have our schedulers: %s " % self.schedulers)
+        logger.info("We have our schedulers: %s ", self.schedulers)
 
         # Now get arbiter
         for arb_id in conf['arbiters']:
@@ -416,7 +471,11 @@ class Broker(BaseSatellite):
             if a['name'] in g_conf['satellitemap']:
                 a = dict(a)  # make a copy
                 a.update(g_conf['satellitemap'][a['name']])
-            uri = pyro.create_uri(a['address'], a['port'], 'Broks', self.use_ssl)
+
+            proto = 'http'
+            if a['use_ssl']:
+                proto = 'https'
+            uri = '%s://%s:%s/' % (proto, a['address'], a['port'])
             self.arbiters[arb_id]['uri'] = uri
 
             self.arbiters[arb_id]['broks'] = broks
@@ -426,7 +485,7 @@ class Broker(BaseSatellite):
 
             # We do not connect to the arbiter. Connection hangs
 
-        logger.info("We have our arbiters: %s " % self.arbiters)
+        logger.info("We have our arbiters: %s ", self.arbiters)
 
         # Now for pollers
         for pol_id in conf['pollers']:
@@ -445,7 +504,12 @@ class Broker(BaseSatellite):
             if p['name'] in g_conf['satellitemap']:
                 p = dict(p)  # make a copy
                 p.update(g_conf['satellitemap'][p['name']])
-            uri = pyro.create_uri(p['address'], p['port'], 'Broks', self.use_ssl)
+
+            proto = 'http'
+            if p['use_ssl']:
+                proto = 'https'
+
+            uri = '%s://%s:%s/' % (proto, p['address'], p['port'])
             self.pollers[pol_id]['uri'] = uri
 
             self.pollers[pol_id]['broks'] = broks
@@ -456,7 +520,7 @@ class Broker(BaseSatellite):
 #                    #And we connect to it
 #                    self.app.pynag_con_init(pol_id, 'poller')
 
-        logger.info("We have our pollers: %s" % self.pollers)
+        logger.info("We have our pollers: %s", self.pollers)
 
         # Now reactionners
         for rea_id in conf['reactionners']:
@@ -476,7 +540,11 @@ class Broker(BaseSatellite):
             if r['name'] in g_conf['satellitemap']:
                 r = dict(r)  # make a copy
                 r.update(g_conf['satellitemap'][r['name']])
-            uri = pyro.create_uri(r['address'], r['port'], 'Broks', self.use_ssl)
+
+            proto = 'http'
+            if r['use_ssl']:
+                proto = 'https'
+            uri = '%s://%s:%s/' % (proto, r['address'], r['port'])
             self.reactionners[rea_id]['uri'] = uri
 
             self.reactionners[rea_id]['broks'] = broks
@@ -487,12 +555,42 @@ class Broker(BaseSatellite):
 #                    #And we connect to it
 #                    self.app.pynag_con_init(rea_id, 'reactionner')
 
-        logger.info("We have our reactionners: %s" % self.reactionners)
+        logger.info("We have our reactionners: %s", self.reactionners)
+
+        # Now receivers
+        for rec_id in conf['receivers']:
+            # Must look if we already have it
+            already_got = rec_id in self.receivers
+            if already_got:
+                broks = self.receivers[rec_id]['broks']
+                running_id = self.schedulers[sched_id]['running_id']
+            else:
+                broks = {}
+                running_id = 0
+
+            r = conf['receivers'][rec_id]
+            self.receivers[rec_id] = r
+
+            # replacing reactionner address and port by those defined in satellitemap
+            if r['name'] in g_conf['satellitemap']:
+                r = dict(r)  # make a copy
+                r.update(g_conf['satellitemap'][r['name']])
+
+            proto = 'http'
+            if r['use_ssl']:
+                proto = 'https'
+            uri = '%s://%s:%s/' % (proto, r['address'], r['port'])
+            self.receivers[rec_id]['uri'] = uri
+
+            self.receivers[rec_id]['broks'] = broks
+            self.receivers[rec_id]['instance_id'] = 0  # No use so all to 0
+            self.receivers[rec_id]['running_id'] = running_id
+            self.receivers[rec_id]['last_connection'] = 0
 
         if not self.have_modules:
             self.modules = mods = conf['global']['modules']
             self.have_modules = True
-            logger.info("We received modules %s " % mods)
+            logger.info("We received modules %s ", mods)
 
             # Ok now start, or restart them!
             # Set modules, init them and start external ones
@@ -505,7 +603,7 @@ class Broker(BaseSatellite):
         # Set our giving timezone from arbiter
         use_timezone = conf['global']['use_timezone']
         if use_timezone != 'NOTSET':
-            logger.info("Setting our timezone to %s" % use_timezone)
+            logger.info("Setting our timezone to %s", use_timezone)
             os.environ['TZ'] = use_timezone
             time.tzset()
 
@@ -519,6 +617,7 @@ class Broker(BaseSatellite):
         for rea_id in self.reactionners:
             self.pynag_con_init(rea_id, type='reactionner')
 
+
     # An arbiter ask us to wait for a new conf, so we must clean
     # all our mess we did, and close modules too
     def clean_previous_run(self):
@@ -528,22 +627,41 @@ class Broker(BaseSatellite):
         self.reactionners.clear()
         self.broks = self.broks[:]
         self.broks_internal_raised = self.broks_internal_raised[:]
+        with self.arbiter_broks_lock:
+            self.arbiter_broks = self.arbiter_broks[:]
         self.external_commands = self.external_commands[:]
 
         # And now modules
         self.have_modules = False
         self.modules_manager.clear_instances()
 
+
+
+    # stats threads is asking us a main structure for stats
+    def get_stats_struct(self):
+        now = int(time.time())
+        # call the daemon one
+        res = super(Broker, self).get_stats_struct()
+        res.update({'name': self.name, 'type': 'broker'})
+        metrics = res['metrics']
+        # metrics specific
+        metrics.append('broker.%s.external-commands.queue %d %d' % (
+            self.name, len(self.external_commands), now))
+        metrics.append('broker.%s.broks.queue %d %d' % (self.name, len(self.broks), now))
+
+        return res
+
+
     def do_loop_turn(self):
-        logger.debug("Begin Loop: managing old broks (%d)" % len(self.broks))
+        logger.debug("Begin Loop: managing old broks (%d)", len(self.broks))
 
         # Dump modules Queues size
         insts = [inst for inst in self.modules_manager.instances if inst.is_external]
         for inst in insts:
             try:
-                logger.debug("External Queue len (%s): %s" % (inst.get_name(), inst.to_q.qsize()))
+                logger.debug("External Queue len (%s): %s", inst.get_name(), inst.to_q.qsize())
             except Exception, exp:
-                logger.debug("External Queue len (%s): Exception! %s" % (inst.get_name(), exp))
+                logger.debug("External Queue len (%s): Exception! %s", inst.get_name(), exp)
 
         # Begin to clean modules
         self.check_and_del_zombie_modules()
@@ -572,12 +690,16 @@ class Broker(BaseSatellite):
         # Maybe the last loop we raised some broks internally
         # we should integrate them in broks
         self.interger_internal_broks()
+        # Also reap broks sent from the arbiters
+        self.interger_arbiter_broks()
 
-        # And from schedulers
-        self.get_new_broks(type='scheduler')
-        # And for other satellites
-        self.get_new_broks(type='poller')
-        self.get_new_broks(type='reactionner')
+        # Main job, go get broks in our distants daemons
+        types = ['scheduler', 'poller', 'reactionner', 'receiver']
+        for _type in types:
+            _t = time.time()
+            # And from schedulers
+            self.get_new_broks(type=_type)
+            statsmgr.incr('get-new-broks.%s' % _type, time.time() - _t)
 
         # Sort the brok list by id
         self.broks.sort(sort_by_ids)
@@ -587,16 +709,31 @@ class Broker(BaseSatellite):
         # We put to external queues broks that was not already send
         t0 = time.time()
         # We are sending broks as a big list, more efficient than one by one
-        queues = self.modules_manager.get_external_to_queues()
+        ext_modules = self.modules_manager.get_external_instances()
         to_send = [b for b in self.broks if getattr(b, 'need_send_to_ext', True)]
 
-        for q in queues:
-            q.put(to_send)
+        # Send our pack to all external modules to_q queue so they can get the wole packet
+        # beware, the sub-process/queue can be die/close, so we put to restart the whole module
+        # instead of killing ourself :)
+        for mod in ext_modules:
+            try:
+                mod.to_q.put(to_send)
+            except Exception, exp:
+                # first we must find the modules
+                logger.debug(str(exp.__dict__))
+                logger.warning("The mod %s queue raise an exception: %s, "
+                               "I'm tagging it to restart later",
+                               mod.get_name(), str(exp))
+                logger.warning("Exception type: %s", type(exp))
+                logger.warning("Back trace of this kill: %s", traceback.format_exc())
+                self.modules_manager.set_to_restart(mod)
+
 
         # No more need to send them
         for b in to_send:
             b.need_send_to_ext = False
-        logger.debug("Time to send %s broks (%d secs)" % (len(to_send), time.time() - t0))
+        statsmgr.incr('core.put-to-external-queue', time.time() - t0)
+        logger.debug("Time to send %s broks (%d secs)", len(to_send), time.time() - t0)
 
         # We must had new broks at the end of the list, so we reverse the list
         self.broks.reverse()
@@ -614,7 +751,9 @@ class Broker(BaseSatellite):
             # REF: doc/broker-modules.png (4-5)
             # We un serialize the brok before consume it
             b.prepare()
+            _t = time.time()
             self.manage_brok(b)
+            statsmgr.incr('core.manage-brok', time.time() - _t)
 
             nb_broks = len(self.broks)
 
@@ -646,22 +785,32 @@ class Broker(BaseSatellite):
         # Say to modules it's a new tick :)
         self.hook_point('tick')
 
+
     #  Main function, will loop forever
     def main(self):
         try:
             self.load_config_file()
 
+            # Setting log level
+            logger.setLevel(self.log_level)
+            # Force the debug level if the daemon is said to start with such level
+            if self.debug:
+                logger.setLevel('DEBUG')
+
             for line in self.get_header():
                 logger.info(line)
 
-            logger.info("[Broker] Using working directory: %s" % os.path.abspath(self.workdir))
+            logger.info("[Broker] Using working directory: %s", os.path.abspath(self.workdir))
 
             # Look if we are enabled or not. If ok, start the daemon mode
             self.look_for_early_exit()
             self.do_daemon_init_and_start()
+            self.load_modules_manager()
 
-            self.uri2 = self.pyro_daemon.register(self.interface, "ForArbiter")
-            logger.debug("The Arbiter uri it at %s" % self.uri2)
+            self.uri2 = self.http_daemon.register(self.interface)
+            logger.debug("The Arbiter uri it at %s", self.uri2)
+
+            self.uri3 = self.http_daemon.register(self.istats)
 
             #  We wait for initial conf
             self.wait_for_initial_conf()
@@ -670,13 +819,6 @@ class Broker(BaseSatellite):
 
             self.setup_new_conf()
 
-            # We already init modules during the new conf thing
-            # Set modules, init them and start external ones
-            #self.modules_manager.set_modules(self.modules)
-            #self.do_load_modules()
-            #self.modules_manager.start_external_instances()
-
-
 
             # Do the modules part, we have our modules in self.modules
             # REF: doc/broker-modules.png (1)
@@ -686,7 +828,5 @@ class Broker(BaseSatellite):
             self.do_mainloop()
 
         except Exception, exp:
-            logger.critical("I got an unrecoverable error. I have to exit")
-            logger.critical("You can log a bug ticket at https://github.com/naparuba/shinken/issues/new to get help")
-            logger.critical("Back trace of it: %s" % (traceback.format_exc()))
+            self.print_unrecoverable(traceback.format_exc())
             raise
