@@ -1,8 +1,7 @@
 #!/usr/bin/python
-
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2009-2012:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #    Gregory Starck, g.starck@gmail.com
@@ -24,64 +23,79 @@
 # along with Shinken.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
+import signal
 import time
 import traceback
 import cPickle
-
+import zlib
+import base64
 
 from shinken.scheduler import Scheduler
 from shinken.macroresolver import MacroResolver
 from shinken.external_command import ExternalCommandManager
 from shinken.daemon import Daemon
 from shinken.property import PathProp, IntegerProp
-import shinken.pyro_wrapper as pyro
 from shinken.log import logger
 from shinken.satellite import BaseSatellite, IForArbiter as IArb, Interface
+from shinken.util import nighty_five_percent
+from shinken.stats import statsmgr
 
 # Interface for Workers
 
 class IChecks(Interface):
     """ Interface for Workers:
-They connect here and see if they are still OK with our running_id, if not, they must drop their checks """
+They connect here and see if they are still OK with our running_id,
+if not, they must drop their checks """
 
     # poller or reactionner is asking us our running_id
-    def get_running_id(self):
-        return self.running_id
+    # def get_running_id(self):
+    #    return self.running_id
 
     # poller or reactionner ask us actions
-    def get_checks(self, do_checks=False, do_actions=False, poller_tags=['None'], \
-                       reactionner_tags=['None'], worker_name='none', \
-                       module_types=['fork']):
-        #print "We ask us checks"
-        res = self.app.get_to_run_checks(do_checks, do_actions, poller_tags, reactionner_tags, worker_name, module_types)
-        #print "Sending %d checks" % len(res)
+    def get_checks(self, do_checks=False, do_actions=False, poller_tags=['None'],
+                   reactionner_tags=['None'], worker_name='none',
+                   module_types=['fork']):
+        # print "We ask us checks"
+        do_checks = (do_checks == 'True')
+        do_actions = (do_actions == 'True')
+        res = self.app.get_to_run_checks(do_checks, do_actions, poller_tags, reactionner_tags,
+                                         worker_name, module_types)
+        # print "Sending %d checks" % len(res)
         self.app.nb_checks_send += len(res)
-        return res
+
+        return base64.b64encode(zlib.compress(cPickle.dumps(res), 2))
+        # return zlib.compress(cPickle.dumps(res), 2)
+    get_checks.encode = 'raw'
+
 
     # poller or reactionner are putting us results
     def put_results(self, results):
         nb_received = len(results)
         self.app.nb_check_received += nb_received
         if nb_received != 0:
-            logger.debug("Received %d results" % nb_received)
+            logger.debug("Received %d results", nb_received)
         for result in results:
             result.set_type_active()
-        self.app.waiting_results.extend(results)
+        with self.app.waiting_results_lock:
+            self.app.waiting_results.extend(results)
 
-        #for c in results:
-        #self.sched.put_results(c)
+        # for c in results:
+        # self.sched.put_results(c)
         return True
+    put_results.method = 'post'
+    put_results.need_lock = False
 
 
 class IBroks(Interface):
     """ Interface for Brokers:
-They connect here and get all broks (data for brokers). Data must be ORDERED! (initial status BEFORE update...) """
+They connect here and get all broks (data for brokers). Data must be ORDERED!
+(initial status BEFORE update...) """
 
     # A broker ask us broks
     def get_broks(self, bname):
         # Maybe it was not registered as it should, if so,
         # do it for it
-        if not bname in self.app.brokers:
+        if bname not in self.app.brokers:
             self.fill_initial_broks(bname)
 
         # Now get the broks for this specific broker
@@ -90,8 +104,9 @@ They connect here and get all broks (data for brokers). Data must be ORDERED! (i
         self.app.nb_broks_send += len(res)
         # we do not more have a full broks in queue
         self.app.brokers[bname]['has_full_broks'] = False
-        
-        return res
+        return base64.b64encode(zlib.compress(cPickle.dumps(res), 2))
+        # return zlib.compress(cPickle.dumps(res), 2)
+    get_broks.encode = 'raw'
 
 
     # A broker is a new one, if we do not have
@@ -99,14 +114,48 @@ They connect here and get all broks (data for brokers). Data must be ORDERED! (i
     # fill it with all new values
     def fill_initial_broks(self, bname):
         if bname not in self.app.brokers:
-            logger.info("A new broker just connected : %s" % bname)
-            self.app.brokers[bname] = {'broks' : {}, 'has_full_broks' : False}
+            logger.info("A new broker just connected : %s", bname)
+            self.app.brokers[bname] = {'broks': {}, 'has_full_broks': False}
         e = self.app.brokers[bname]
         if not e['has_full_broks']:
             e['broks'].clear()
             self.app.fill_initial_broks(bname, with_logs=True)
 
 
+class IStats(Interface):
+    """
+    Interface for various stats about scheduler activity
+    """
+
+    doc = '''Get raw stats from the daemon:
+  * nb_scheduled: number of scheduled checks (to launch in the future)
+  * nb_inpoller: number of check take by the pollers
+  * nb_zombies: number of zombie checks (should be close to zero)
+  * nb_notifications: number of notifications+event handlers
+  * latency: avg,min,max latency for the services (should be <10s)
+'''
+    def get_raw_stats(self):
+        sched = self.app.sched
+        res = {}
+        res['nb_scheduled'] = len([c for c in sched.checks.values() if c.status == 'scheduled'])
+        res['nb_inpoller'] = len([c for c in sched.checks.values() if c.status == 'inpoller'])
+        res['nb_zombies'] = len([c for c in sched.checks.values() if c.status == 'zombie'])
+        res['nb_notifications'] = len(sched.actions)
+
+        # Spare scehdulers do not have such properties
+        if hasattr(sched, 'services'):
+            # Get a overview of the latencies with just
+            # a 95 percentile view, but lso min/max values
+            latencies = [s.latency for s in sched.services]
+            lat_avg, lat_min, lat_max = nighty_five_percent(latencies)
+            res['latency'] = (0.0, 0.0, 0.0)
+            if lat_avg:
+                res['latency'] = (lat_avg, lat_min, lat_max)
+        return res
+    get_raw_stats.doc = doc
+
+
+
 class IForArbiter(IArb):
     """ Interface for Arbiter. We ask him a for a conf and after that listen for instructions
         from the arbiter. The arbiter is the interface to the administrator, so we must listen
@@ -116,11 +165,13 @@ class IForArbiter(IArb):
     # it can send us global command, or specific ones
     def run_external_commands(self, cmds):
         self.app.sched.run_external_commands(cmds)
+    run_external_commands.method = 'POST'
 
 
     def put_conf(self, conf):
         self.app.sched.die()
         super(IForArbiter, self).put_conf(conf)
+    put_conf.method = 'POST'
 
 
     # Call by arbiter if it thinks we are running but we must not (like
@@ -136,13 +187,32 @@ class IForArbiter(IArb):
 
 
 
+'''
+class Injector(Interface):
+    # A broker ask us broks
+    def inject(self, bincode):
+
+        # first we need to get a real code object
+        import marshal
+        print "Calling Inject mode"
+        code = marshal.loads(bincode)
+        result = None
+        exec code
+        try:
+            return result
+        except NameError, exp:
+            return None
+'''
+
+
+
 # The main app class
 class Shinken(BaseSatellite):
 
     properties = BaseSatellite.properties.copy()
     properties.update({
         'pidfile':   PathProp(default='schedulerd.pid'),
-        'port':      IntegerProp(default='7768'),
+        'port':      IntegerProp(default=7768),
         'local_log': PathProp(default='schedulerd.log'),
     })
 
@@ -150,11 +220,13 @@ class Shinken(BaseSatellite):
     # Create a Pyro server (port = arvg 1)
     # then create the interface for arbiter
     # Then, it wait for a first configuration
-    def __init__(self, config_file, is_daemon, do_replace, debug, debug_file):
+    def __init__(self, config_file, is_daemon, do_replace, debug, debug_file, profile=''):
 
-        BaseSatellite.__init__(self, 'scheduler', config_file, is_daemon, do_replace, debug, debug_file)
+        BaseSatellite.__init__(self, 'scheduler', config_file, is_daemon, do_replace, debug,
+                               debug_file)
 
         self.interface = IForArbiter(self)
+        self.istats = IStats(self)
         self.sched = Scheduler(self)
 
         self.ichecks = None
@@ -170,23 +242,27 @@ class Shinken(BaseSatellite):
         self.pollers = {}
         self.reactionners = {}
         self.brokers = {}
-        
+
 
     def do_stop(self):
-        if self.pyro_daemon:
+        if self.http_daemon:
             if self.ibroks:
-                self.pyro_daemon.unregister(self.ibroks)
+                self.http_daemon.unregister(self.ibroks)
             if self.ichecks:
-                self.pyro_daemon.unregister(self.ichecks)
+                self.http_daemon.unregister(self.ichecks)
         super(Shinken, self).do_stop()
 
 
     def compensate_system_time_change(self, difference):
         """ Compensate a system time change of difference for all hosts/services/checks/notifs """
-        logger.warning("A system time change of %d has been detected. Compensating..." % difference)
+        logger.warning("A system time change of %d has been detected. Compensating...", difference)
         # We only need to change some value
         self.program_start = max(0, self.program_start + difference)
 
+        if not hasattr(self.sched, "conf"):
+            # Race condition where time change before getting conf
+            return
+
         # Then we compensate all host/services
         for h in self.sched.hosts:
             h.compensate_system_time_change(difference)
@@ -245,17 +321,18 @@ class Shinken(BaseSatellite):
                     c.t_to_go = new_t
 
     def manage_signal(self, sig, frame):
-        logger.warning("Received a SIGNAL %s" % sig)
+        logger.warning("Received a SIGNAL %s", sig)
         # If we got USR1, just dump memory
-        if sig == 10:
+        if sig == signal.SIGUSR1:
             self.sched.need_dump_memory = True
-        elif sig == 12: #usr2, dump objects
+        elif sig == signal.SIGUSR2:  # usr2, dump objects
             self.sched.need_objects_dump = True
         else:  # if not, die :)
             self.sched.die()
             self.must_run = False
             Daemon.manage_signal(self, sig, frame)
 
+
     def do_loop_turn(self):
         # Ok, now the conf
         self.wait_for_initial_conf()
@@ -266,6 +343,7 @@ class Shinken(BaseSatellite):
         logger.info("New configuration loaded")
         self.sched.run()
 
+
     def setup_new_conf(self):
         pk = self.new_conf
         conf_raw = pk['conf']
@@ -275,11 +353,24 @@ class Shinken(BaseSatellite):
         instance_name = pk['instance_name']
         push_flavor = pk['push_flavor']
         skip_initial_broks = pk['skip_initial_broks']
+        accept_passive_unknown_check_results = pk['accept_passive_unknown_check_results']
+        api_key = pk['api_key']
+        secret = pk['secret']
+        http_proxy = pk['http_proxy']
+        statsd_host = pk['statsd_host']
+        statsd_port = pk['statsd_port']
+        statsd_prefix = pk['statsd_prefix']
+        statsd_enabled = pk['statsd_enabled']
+
+        # horay, we got a name, we can set it in our stats objects
+        statsmgr.register(self.sched, instance_name, 'scheduler',
+                          api_key=api_key, secret=secret, http_proxy=http_proxy,
+                          statsd_host=statsd_host, statsd_port=statsd_port,
+                          statsd_prefix=statsd_prefix, statsd_enabled=statsd_enabled)
 
         t0 = time.time()
         conf = cPickle.loads(conf_raw)
-        logger.debug("Conf received at %d. Unserialized in %d secs" % (t0, time.time() - t0))
-
+        logger.debug("Conf received at %d. Unserialized in %d secs", t0, time.time() - t0)
         self.new_conf = None
 
         # Tag the conf with our data
@@ -287,12 +378,13 @@ class Shinken(BaseSatellite):
         self.conf.push_flavor = push_flavor
         self.conf.instance_name = instance_name
         self.conf.skip_initial_broks = skip_initial_broks
+        self.conf.accept_passive_unknown_check_results = accept_passive_unknown_check_results
 
         self.cur_conf = conf
         self.override_conf = override_conf
         self.modules = modules
         self.satellites = satellites
-        #self.pollers = self.app.pollers
+        # self.pollers = self.app.pollers
 
         if self.conf.human_timestamp_log:
             logger.set_human_format()
@@ -308,23 +400,45 @@ class Shinken(BaseSatellite):
                 p = dict(p)  # make a copy
                 p.update(override_conf['satellitemap'][p['name']])
 
-            uri = pyro.create_uri(p['address'], p['port'], 'Schedulers', self.use_ssl)
+            proto = 'http'
+            if p['use_ssl']:
+                proto = 'https'
+            uri = '%s://%s:%s/' % (proto, p['address'], p['port'])
             self.pollers[pol_id]['uri'] = uri
             self.pollers[pol_id]['last_connection'] = 0
 
+        # Now We create our reactionners
+        for reac_id in satellites['reactionners']:
+            # Must look if we already have it
+            already_got = reac_id in self.reactionners
+            reac = satellites['reactionners'][reac_id]
+            self.reactionners[reac_id] = reac
+
+            if reac['name'] in override_conf['satellitemap']:
+                reac = dict(reac)  # make a copy
+                reac.update(override_conf['satellitemap'][reac['name']])
+
+            proto = 'http'
+            if p['use_ssl']:
+                proto = 'https'
+            uri = '%s://%s:%s/' % (proto, reac['address'], reac['port'])
+            self.reactionners[reac_id]['uri'] = uri
+            self.reactionners[reac_id]['last_connection'] = 0
+
+
         # First mix conf and override_conf to have our definitive conf
         for prop in self.override_conf:
-            #print "Overriding the property %s with value %s" % (prop, self.override_conf[prop])
+            # print "Overriding the property %s with value %s" % (prop, self.override_conf[prop])
             val = self.override_conf[prop]
             setattr(self.conf, prop, val)
 
         if self.conf.use_timezone != '':
-            logger.debug("Setting our timezone to %s" % str(self.conf.use_timezone))
+            logger.debug("Setting our timezone to %s", str(self.conf.use_timezone))
             os.environ['TZ'] = self.conf.use_timezone
             time.tzset()
 
         if len(self.modules) != 0:
-            logger.debug("I've got %s modules" % str(self.modules))
+            logger.debug("I've got %s modules", str(self.modules))
 
         # TODO: if scheduler had previous modules instanciated it must clean them!
         self.modules_manager.set_modules(self.modules)
@@ -333,21 +447,20 @@ class Shinken(BaseSatellite):
         # give it an interface
         # But first remove previous interface if exists
         if self.ichecks is not None:
-            logger.debug("Deconnecting previous Check Interface from pyro_daemon")
-            self.pyro_daemon.unregister(self.ichecks)
+            logger.debug("Deconnecting previous Check Interface")
+            self.http_daemon.unregister(self.ichecks)
         # Now create and connect it
         self.ichecks = IChecks(self.sched)
-        self.uri = self.pyro_daemon.register(self.ichecks, "Checks")
-        logger.debug("The Checks Interface uri is: %s" % self.uri)
+        self.http_daemon.register(self.ichecks)
+        logger.debug("The Scheduler Interface uri is: %s", self.uri)
 
         # Same for Broks
         if self.ibroks is not None:
-            logger.debug("Deconnecting previous Broks Interface from pyro_daemon")
-            self.pyro_daemon.unregister(self.ibroks)
+            logger.debug("Deconnecting previous Broks Interface")
+            self.http_daemon.unregister(self.ibroks)
         # Create and connect it
         self.ibroks = IBroks(self.sched)
-        self.uri2 = self.pyro_daemon.register(self.ibroks, "Broks")
-        logger.debug("The Broks Interface uri is: %s" % self.uri2)
+        self.http_daemon.register(self.ibroks)
 
         logger.info("Loading configuration.")
         self.conf.explode_global_conf()
@@ -360,14 +473,14 @@ class Shinken(BaseSatellite):
         # We must update our Config dict macro with good value
         # from the config parameters
         self.sched.conf.fill_resource_macros_names_macros()
-        #print "DBG: got macros", self.sched.conf.macros
+        # print "DBG: got macros", self.sched.conf.macros
 
         # Creating the Macroresolver Class & unique instance
         m = MacroResolver()
         m.init(self.conf)
 
-        #self.conf.dump()
-        #self.conf.quick_debug()
+        # self.conf.dump()
+        # self.conf.quick_debug()
 
         # Now create the external commander
         # it's a applyer: it role is not to dispatch commands,
@@ -398,13 +511,25 @@ class Shinken(BaseSatellite):
     def main(self):
         try:
             self.load_config_file()
+            # Setting log level
+            logger.setLevel(self.log_level)
+            # Force the debug level if the daemon is said to start with such level
+            if self.debug:
+                logger.setLevel('DEBUG')
+
             self.look_for_early_exit()
             self.do_daemon_init_and_start()
-            self.uri2 = self.pyro_daemon.register(self.interface, "ForArbiter")
-            logger.info("[scheduler] General interface is at: %s" % self.uri2)
+            self.load_modules_manager()
+            self.http_daemon.register(self.interface)
+            self.http_daemon.register(self.istats)
+
+            # self.inject = Injector(self.sched)
+            # self.http_daemon.register(self.inject)
+
+            self.http_daemon.unregister(self.interface)
+            self.uri = self.http_daemon.uri
+            logger.info("[scheduler] General interface is at: %s", self.uri)
             self.do_mainloop()
         except Exception, exp:
-            logger.critical("I got an unrecoverable error. I have to exit")
-            logger.critical("You can log a bug ticket at https://github.com/naparuba/shinken/issues/new to get help")
-            logger.critical("Back trace of it: %s" % (traceback.format_exc()))
+            self.print_unrecoverable(traceback.format_exc())
             raise
