@@ -1,9 +1,7 @@
 #!/usr/bin/env python
-
 # -*- coding: utf-8 -*-
 
-
-# Copyright (C) 2009-2012:
+# Copyright (C) 2009-2014:
 #     Gabes Jean, naparuba@gmail.com
 #     Gerhard Lausser, Gerhard.Lausser@consol.de
 #     Gregory Starck, g.starck@gmail.com
@@ -24,7 +22,9 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with Shinken.  If not, see <http://www.gnu.org/licenses/>.
 
-import time, calendar
+import time
+import calendar
+import re
 
 from shinken.util import get_sec_from_morning, get_day, get_start_of_day, get_end_of_day
 from shinken.log import logger
@@ -60,7 +60,7 @@ def find_day_by_weekday_offset(year, month, weekday, offset):
             if nb_found == offset:
                 return cal[i][weekday_id]
         return None
-    except:
+    except Exception:
         return None
 
 
@@ -75,44 +75,54 @@ def find_day_by_offset(year, month, offset):
         return max(1, days_in_month + offset + 1)
 
 
-class Timerange:
+class Timerange(object):
 
     # entry is like 00:00-24:00
     def __init__(self, entry):
-        entries = entry.split('-')
-        start = entries[0]
-        end = entries[1]
-        sentries = start.split(':')
-        self.hstart = int(sentries[0])
-        self.mstart = int(sentries[1])
-        eentries = end.split(':')
-        self.hend = int(eentries[0])
-        self.mend = int(eentries[1])
+        pattern = r'(\d\d):(\d\d)-(\d\d):(\d\d)'
+        m = re.match(pattern, entry)
+        self.is_valid = m is not None
+        if self.is_valid:
+            self.hstart, self.mstart, self.hend, self.mend = map(int, m.groups())
 
     def __str__(self):
         return str(self.__dict__)
 
     def get_sec_from_morning(self):
-        return self.hstart*3600 + self.mstart*60
+        return self.hstart * 3600 + self.mstart * 60
 
     def get_first_sec_out_from_morning(self):
         # If start at 0:0, the min out is the end
         if self.hstart == 0 and self.mstart == 0:
-            return self.hend*3600 + self.mend*60
+            return self.hend * 3600 + self.mend * 60
         return 0
 
     def is_time_valid(self, t):
         sec_from_morning = get_sec_from_morning(t)
-        return self.hstart*3600 + self.mstart* 60  <= sec_from_morning <= self.hend*3600 + self.mend* 60
+        return (self.is_valid and
+                self.hstart * 3600 + self.mstart * 60 <=
+                sec_from_morning <=
+                self.hend * 3600 + self.mend * 60)
+
+    def is_correct(self):
+        return self.is_valid
+
 
 
 """ TODO: Add some comment about this class for the doc"""
-class Daterange:
-    weekdays = {'monday': 0, 'tuesday': 1, 'wednesday': 2, 'thursday': 3, \
-                    'friday': 4, 'saturday': 5, 'sunday': 6}
-    months = {'january': 1, 'february': 2, 'march': 3, 'april': 4, 'may': 5, \
-                  'june': 6, 'july': 7, 'august': 8, 'september': 9, \
-                  'october': 10, 'november': 11, 'december': 12}
+class Daterange(object):
+
+    weekdays = {  # NB : 0 based : 0 == monday
+        'monday': 0, 'tuesday': 1, 'wednesday': 2, 'thursday': 3,
+        'friday': 4, 'saturday': 5, 'sunday': 6
+    }
+    months = {  # NB : 1 based : 1 == january..
+        'january': 1, 'february': 2, 'march': 3, 'april': 4, 'may': 5,
+        'june': 6, 'july': 7, 'august': 8, 'september': 9,
+        'october': 10, 'november': 11, 'december': 12
+    }
+    rev_weekdays = dict((v, k) for k, v in weekdays.items())
+    rev_months = dict((v, k) for k, v in months.items())
 
     def __init__(self, syear, smon, smday, swday, swday_offset,
                  eyear, emon, emday, ewday, ewday_offset, skip_interval, other):
@@ -134,54 +144,43 @@ class Daterange:
             self.timeranges.append(Timerange(timeinterval.strip()))
 
     def __str__(self):
-        return '' # str(self.__dict__)
+        return ''  # str(self.__dict__)
+
 
-    # By default, daterange are correct
     def is_correct(self):
+        for tr in self.timeranges:
+            if not tr.is_correct():
+                return False
         return True
 
+    @classmethod
     def get_month_id(cls, month):
-        try:
-            return Daterange.months[month]
-        except:
-            return None
-    get_month_id = classmethod(get_month_id)
+        return Daterange.months[month]
 
-    # @memoized
-    def get_month_by_id(cls, id):
-        id = id % 12
-        for key in Daterange.months:
-            if id == Daterange.months[key]:
-                return key
-        return None
-    get_month_by_id = classmethod(get_month_by_id)
+    @classmethod
+    def get_month_by_id(cls, month_id):
+        return Daterange.rev_months[month_id]
 
+    @classmethod
     def get_weekday_id(cls, weekday):
-        try:
-            return Daterange.weekdays[weekday]
-        except:
-            return None
-    get_weekday_id = classmethod(get_weekday_id)
+        return Daterange.weekdays[weekday]
 
-    def get_weekday_by_id(cls, id):
-        id = id % 7
-        for key in Daterange.weekdays:
-            if id == Daterange.weekdays[key]:
-                return key
-        return None
-    get_weekday_by_id = classmethod(get_weekday_by_id)
+    @classmethod
+    def get_weekday_by_id(cls, weekday_id):
+        return Daterange.rev_weekdays[weekday_id]
 
     def get_start_and_end_time(self, ref=None):
         logger.warning("Calling function get_start_and_end_time which is not implemented")
+        raise NotImplementedError()
 
     def is_time_valid(self, t):
-        #print "****Look for time valid for", time.asctime(time.localtime(t))
+        # print "****Look for time valid for", time.asctime(time.localtime(t))
         if self.is_time_day_valid(t):
-            #print "is time day valid"
+            # print "is time day valid"
             for tr in self.timeranges:
-                #print tr, "is valid?", tr.is_time_valid(t)
+                # print tr, "is valid?", tr.is_time_valid(t)
                 if tr.is_time_valid(t):
-                    #print "return True"
+                    # print "return True"
                     return True
         return False
 
@@ -219,7 +218,7 @@ class Daterange:
             return True
 
     def get_next_future_timerange_valid(self, t):
-        #print "Look for get_next_future_timerange_valid for t", t, time.asctime(time.localtime(t))
+        # print "Look for get_next_future_timerange_valid for t", t, time.asctime(time.localtime(t))
         sec_from_morning = get_sec_from_morning(t)
         starts = []
         for tr in self.timeranges:
@@ -232,9 +231,9 @@ class Daterange:
             return None
 
     def get_next_future_timerange_invalid(self, t):
-        #print 'Call for get_next_future_timerange_invalid from ', time.asctime(time.localtime(t))
+        # print 'Call for get_next_future_timerange_invalid from ', time.asctime(time.localtime(t))
         sec_from_morning = get_sec_from_morning(t)
-        #print 'sec from morning', sec_from_morning
+        # print 'sec from morning', sec_from_morning
         ends = []
         for tr in self.timeranges:
             tr_start = tr.hstart * 3600 + tr.mstart * 60
@@ -243,7 +242,7 @@ class Daterange:
             tr_end = tr.hend * 3600 + tr.mend * 60
             if tr_end >= sec_from_morning:
                 ends.append(tr_end)
-        #print "Ends:", ends
+        # print "Ends:", ends
         # Remove the last second of the day for 00->24h"
         if 86400 in ends:
             ends.remove(86400)
@@ -255,7 +254,7 @@ class Daterange:
     def get_next_valid_day(self, t):
         if self.get_next_future_timerange_valid(t) is None:
             # this day is finish, we check for next period
-            (start_time, end_time) = self.get_start_and_end_time(get_day(t)+86400)
+            (start_time, end_time) = self.get_start_and_end_time(get_day(t) + 86400)
         else:
             (start_time, end_time) = self.get_start_and_end_time(t)
 
@@ -267,16 +266,16 @@ class Daterange:
         return None
 
     def get_next_valid_time_from_t(self, t):
-        #print "\tDR Get next valid from:", time.asctime(time.localtime(t))
-        #print "DR Get next valid from:", t
+        # print "\tDR Get next valid from:", time.asctime(time.localtime(t))
+        # print "DR Get next valid from:", t
         if self.is_time_valid(t):
             return t
 
-        #print "DR Get next valid from:", time.asctime(time.localtime(t))
+        # print "DR Get next valid from:", time.asctime(time.localtime(t))
         # First we search fot the day of t
         t_day = self.get_next_valid_day(t)
 
-        #print "DR: T next valid day", time.asctime(time.localtime(t_day))
+        # print "DR: T next valid day", time.asctime(time.localtime(t_day))
 
         # We search for the min of all tr.start > sec_from_morning
         # if it's the next day, use a start of the day search for timerange
@@ -284,7 +283,7 @@ class Daterange:
             sec_from_morning = self.get_next_future_timerange_valid(t_day)
         else:  # t is in this day, so look from t (can be in the evening or so)
             sec_from_morning = self.get_next_future_timerange_valid(t)
-        #print "DR: sec from morning", sec_from_morning
+        # print "DR: sec from morning", sec_from_morning
 
         if sec_from_morning is not None:
             if t_day is not None and sec_from_morning is not None:
@@ -302,40 +301,41 @@ class Daterange:
             return None
 
     def get_next_invalid_day(self, t):
-        #print "Look in", self.__dict__
-        #print 'DR: get_next_invalid_day for', time.asctime(time.localtime(t))
+        # print "Look in", self.__dict__
+        # print 'DR: get_next_invalid_day for', time.asctime(time.localtime(t))
         if self.is_time_day_invalid(t):
-            #print "EARLY RETURN"
+            # print "EARLY RETURN"
             return t
 
         next_future_timerange_invalid = self.get_next_future_timerange_invalid(t)
-        #print "next_future_timerange_invalid:", next_future_timerange_invalid
+        # print "next_future_timerange_invalid:", next_future_timerange_invalid
 
         # If today there is no more unavailable timerange, search the next day
         if next_future_timerange_invalid is None:
-            #print 'DR: get_next_future_timerange_invalid is None'
-            #this day is finish, we check for next period
+            # print 'DR: get_next_future_timerange_invalid is None'
+            # this day is finish, we check for next period
             (start_time, end_time) = self.get_start_and_end_time(get_day(t))
         else:
-            #print 'DR: get_next_future_timerange_invalid is', time.asctime(time.localtime(next_future_timerange_invalid))
+            # print 'DR: get_next_future_timerange_invalid is',
+            # print time.asctime(time.localtime(next_future_timerange_invalid))
             (start_time, end_time) = self.get_start_and_end_time(t)
 
-        #(start_time, end_time) = self.get_start_and_end_time(t)
+        # (start_time, end_time) = self.get_start_and_end_time(t)
 
-        #print "START", time.asctime(time.localtime(start_time)), "END", time.asctime(time.localtime(end_time))
+        # print "START", time.asctime(time.localtime(start_time)),
+        # print "END", time.asctime(time.localtime(end_time))
         # The next invalid day can be t day if there a possible
         # invalid time range (timerange is not 00->24
         if next_future_timerange_invalid is not None:
             if start_time <= t <= end_time:
-                #print "Early Return next invalid day:", time.asctime(time.localtime(get_day(t)))
+                # print "Early Return next invalid day:", time.asctime(time.localtime(get_day(t)))
                 return get_day(t)
             if start_time >= t:
-                #print "start_time >= t:", time.asctime(time.localtime(get_day(start_time)))
+                # print "start_time >= t:", time.asctime(time.localtime(get_day(start_time)))
                 return get_day(start_time)
         else:
             # Else, there is no possibility than in our start_time<->end_time we got
             # any invalid time (full period out). So it's end_time+1 sec (tomorrow of end_time)
-            # print "Full period out, got end_time", time.asctime(time.localtime(get_day(end_time +1)))
             return get_day(end_time + 1)
 
         return None
@@ -346,7 +346,7 @@ class Daterange:
 
         # First we search fot the day of t
         t_day = self.get_next_invalid_day(t)
-        #print "FUCK NEXT DAY", time.asctime(time.localtime(t_day))
+        # print "FUCK NEXT DAY", time.asctime(time.localtime(t_day))
 
         # We search for the min of all tr.start > sec_from_morning
         # if it's the next day, use a start of the day search for timerange
@@ -354,14 +354,14 @@ class Daterange:
             sec_from_morning = self.get_next_future_timerange_invalid(t_day)
         else:  # t is in this day, so look from t (can be in the evening or so)
             sec_from_morning = self.get_next_future_timerange_invalid(t)
-        #print "DR: sec from morning", sec_from_morning
+        # print "DR: sec from morning", sec_from_morning
 
         # tr can't be valid, or it will be return at the beginning
-        #sec_from_morning = self.get_next_future_timerange_invalid(t)
+        # sec_from_morning = self.get_next_future_timerange_invalid(t)
 
         # Ok we've got a next invalid day and a invalid possibility in
         # timerange, so the next invalid is this day+sec_from_morning
-        #print "T_day", t_day, "Sec from morning", sec_from_morning
+        # print "T_day", t_day, "Sec from morning", sec_from_morning
         if t_day is not None and sec_from_morning is not None:
             return t_day + sec_from_morning + 1
 
@@ -410,21 +410,23 @@ class StandardDaterange(Daterange):
     def is_correct(self):
         b = self.day in Daterange.weekdays
         if not b:
-            logger.error("Error: %s is not a valid day" % self.day)
+            logger.error("Error: %s is not a valid day", self.day)
+        # Check also if Daterange is correct.
+        b &= Daterange.is_correct(self)
         return b
 
     def get_start_and_end_time(self, ref=None):
         now = time.localtime(ref)
         self.syear = now.tm_year
         self.month = now.tm_mon
-        #month_start_id = now.tm_mon
-        #month_start = Daterange.get_month_by_id(month_start_id)
+        # month_start_id = now.tm_mon
+        # month_start = Daterange.get_month_by_id(month_start_id)
         self.wday = now.tm_wday
         day_id = Daterange.get_weekday_id(self.day)
         today_morning = get_start_of_day(now.tm_year, now.tm_mon, now.tm_mday)
         tonight = get_end_of_day(now.tm_year, now.tm_mon, now.tm_mday)
         day_diff = (day_id - now.tm_wday) % 7
-        return (today_morning + day_diff*86400, tonight + day_diff*86400)
+        return (today_morning + day_diff * 86400, tonight + day_diff * 86400)
 
 
 """ TODO: Add some comment about this class for the doc"""
@@ -435,11 +437,11 @@ class MonthWeekDayDaterange(Daterange):
         b = True
         b &= self.swday in Daterange.weekdays
         if not b:
-            logger.error("Error: %s is not a valid day" % self.swday)
+            logger.error("Error: %s is not a valid day", self.swday)
 
         b &= self.ewday in Daterange.weekdays
         if not b:
-            logger.error("Error: %s is not a valid day" % self.ewday)
+            logger.error("Error: %s is not a valid day", self.ewday)
 
         return b
 
@@ -461,18 +463,22 @@ class MonthWeekDayDaterange(Daterange):
         now_epoch = time.mktime(now)
         if start_time > end_time:  # the period is between years
             if now_epoch > end_time:  # check for next year
-                day_end = find_day_by_weekday_offset(self.eyear + 1, self.emon, self.ewday, self.ewday_offset)
+                day_end = find_day_by_weekday_offset(self.eyear + 1,
+                                                     self.emon, self.ewday, self.ewday_offset)
                 end_time = get_end_of_day(self.eyear + 1, month_end_id, day_end)
             else:
                 # it s just that the start was the last year
-                day_start = find_day_by_weekday_offset(self.syear - 1, self.smon, self.swday, self.swday_offset)
+                day_start = find_day_by_weekday_offset(self.syear - 1,
+                                                       self.smon, self.swday, self.swday_offset)
                 start_time = get_start_of_day(self.syear - 1, month_id, day_start)
         else:
             if now_epoch > end_time:
                 # just have to check for next year if necessary
-                day_start = find_day_by_weekday_offset(self.syear + 1, self.smon, self.swday, self.swday_offset)
+                day_start = find_day_by_weekday_offset(self.syear + 1,
+                                                       self.smon, self.swday, self.swday_offset)
                 start_time = get_start_of_day(self.syear + 1, month_id, day_start)
-                day_end = find_day_by_weekday_offset(self.eyear + 1, self.emon, self.ewday, self.ewday_offset)
+                day_end = find_day_by_weekday_offset(self.eyear + 1,
+                                                     self.emon, self.ewday, self.ewday_offset)
                 end_time = get_end_of_day(self.eyear + 1, month_end_id, day_end)
 
         return (start_time, end_time)
@@ -502,15 +508,15 @@ class MonthDateDaterange(Daterange):
                 end_time = get_end_of_day(self.eyear + 1, month_end_id, day_end)
             else:
                 # it s just that start was the last year
-                day_start = find_day_by_offset(self.syear-1, self.smon, self.emday)
-                start_time = get_start_of_day(self.syear-1, month_start_id, day_start)
+                day_start = find_day_by_offset(self.syear - 1, self.smon, self.emday)
+                start_time = get_start_of_day(self.syear - 1, month_start_id, day_start)
         else:
             if now_epoch > end_time:
                 # just have to check for next year if necessary
-                day_start = find_day_by_offset(self.syear+1, self.smon, self.emday)
-                start_time = get_start_of_day(self.syear+1, month_start_id, day_start)
-                day_end = find_day_by_offset(self.eyear+1, self.emon, self.emday)
-                end_time = get_end_of_day(self.eyear+1, month_end_id, day_end)
+                day_start = find_day_by_offset(self.syear + 1, self.smon, self.emday)
+                start_time = get_start_of_day(self.syear + 1, month_start_id, day_start)
+                day_end = find_day_by_offset(self.eyear + 1, self.emon, self.emday)
+                end_time = get_end_of_day(self.eyear + 1, month_end_id, day_end)
 
         return (start_time, end_time)
 
@@ -525,7 +531,8 @@ class WeekDayDaterange(Daterange):
             self.syear = now.tm_year
         month_start_id = now.tm_mon
         month_start = Daterange.get_month_by_id(month_start_id)
-        day_start = find_day_by_weekday_offset(self.syear, month_start, self.swday, self.swday_offset)
+        day_start = find_day_by_weekday_offset(self.syear,
+                                               month_start, self.swday, self.swday_offset)
         start_time = get_start_of_day(self.syear, month_start_id, day_start)
 
         # Same for end year
@@ -544,7 +551,8 @@ class WeekDayDaterange(Daterange):
                 month_end_id = 1
                 self.eyear += 1
             month_end = Daterange.get_month_by_id(month_end_id)
-            day_end = find_day_by_weekday_offset(self.eyear, month_end, self.ewday, self.ewday_offset)
+            day_end = find_day_by_weekday_offset(self.eyear,
+                                                 month_end, self.ewday, self.ewday_offset)
             end_time = get_end_of_day(self.eyear, month_end_id, day_end)
 
         now_epoch = time.mktime(now)
@@ -560,11 +568,13 @@ class WeekDayDaterange(Daterange):
                 self.syear += 1
             # First start
             month_start = Daterange.get_month_by_id(month_start_id)
-            day_start = find_day_by_weekday_offset(self.syear, month_start, self.swday, self.swday_offset)
+            day_start = find_day_by_weekday_offset(self.syear,
+                                                   month_start, self.swday, self.swday_offset)
             start_time = get_start_of_day(self.syear, month_start_id, day_start)
             # Then end
             month_end = Daterange.get_month_by_id(month_end_id)
-            day_end = find_day_by_weekday_offset(self.eyear, month_end, self.ewday, self.ewday_offset)
+            day_end = find_day_by_weekday_offset(self.eyear,
+                                                 month_end, self.ewday, self.ewday_offset)
             end_time = get_end_of_day(self.eyear, month_end_id, day_end)
 
         return (start_time, end_time)
