@@ -2,7 +2,7 @@
 
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2009-2012:
+# Copyright (C) 2009-2014:
 #     Gabes Jean, naparuba@gmail.com
 #     Gerhard Lausser, Gerhard.Lausser@consol.de
 #     Gregory Starck, g.starck@gmail.com
@@ -24,16 +24,16 @@
 # along with Shinken.  If not, see <http://www.gnu.org/licenses/>.
 
 import re
-from shinken.log import logger
 from shinken.util import filter_any, filter_none
-from shinken.util import filter_host_by_name, filter_host_by_regex, filter_host_by_group, filter_host_by_template
+from shinken.util import filter_host_by_name, filter_host_by_regex, filter_host_by_group,\
+    filter_host_by_tag
 from shinken.util import filter_service_by_name
 from shinken.util import filter_service_by_regex_name
 from shinken.util import filter_service_by_regex_host_name
 from shinken.util import filter_service_by_host_name
 from shinken.util import filter_service_by_bp_rule_label
 from shinken.util import filter_service_by_hostgroup_name
-from shinken.util import filter_service_by_host_template_name
+from shinken.util import filter_service_by_host_tag_name
 from shinken.util import filter_service_by_servicegroup_name
 from shinken.util import filter_host_by_bp_rule_label
 from shinken.util import filter_service_by_host_bp_rule_label
@@ -53,7 +53,9 @@ class DependencyNode(object):
         self.not_value = False
 
     def __str__(self):
-        return "Op:'%s' Val:'%s' Sons:'[%s]' IsNot:'%s'" % (self.operand, self.of_values, ','.join([str(s) for s in self.sons]), self.not_value)
+        return "Op:'%s' Val:'%s' Sons:'[%s]' IsNot:'%s'" % (self.operand, self.of_values,
+                                                            ','.join([str(s) for s in self.sons]),
+                                                            self.not_value)
 
 
     def get_reverse_state(self, state):
@@ -71,7 +73,7 @@ class DependencyNode(object):
     # We will get the state of this node, by looking at the state of
     # our sons, and apply our operand
     def get_state(self):
-        #print "Ask state of me", self
+        # print "Ask state of me", self
 
         # If we are a host or a service, wee just got the host/service
         # hard state
@@ -81,11 +83,11 @@ class DependencyNode(object):
             return self.get_complex_node_state()
 
 
-    # Returns a simple node direct state (such as an host or a service). No
+    # Returns a simple node direct state (such as a host or a service). No
     # calculation is needed
     def get_simple_node_state(self):
         state = self.sons[0].last_hard_state_id
-        #print "Get the hard state (%s) for the object %s" % (state, self.sons[0].get_name())
+        # print "Get the hard state (%s) for the object %s" % (state, self.sons[0].get_name())
         # Make DOWN look as CRITICAL (2 instead of 1)
         if self.operand == 'host' and state == 1:
             state = 2
@@ -162,7 +164,7 @@ class DependencyNode(object):
         nb_warn = len([s for s in states if s == 1])
         nb_crit = len([s for s in states if s == 2])
 
-        #print "NB:", nb_ok, nb_warn, nb_crit
+        # print "NB:", nb_ok, nb_warn, nb_crit
 
         # Ok and Crit apply with their own values
         # Warn can apply with warn or crit values
@@ -187,7 +189,7 @@ class DependencyNode(object):
         warn_apply = get_state_for(nb_sons, nb_warn + nb_crit, nb_search_warn)
         crit_apply = get_state_for(nb_sons, nb_crit, nb_search_crit)
 
-        #print "What apply?", ok_apply, warn_apply, crit_apply
+        # print "What apply?", ok_apply, warn_apply, crit_apply
 
         # return the worst state that apply
         if crit_apply:
@@ -209,12 +211,12 @@ class DependencyNode(object):
         # ask a simple form Xof: or a multiple one A,B,Cof:
         # the simple should give OK, the mult should give the worst state
         if self.is_of_mul:
-            #print "Is mul, send 0"
+            # print "Is mul, send 0"
             if self.not_value:
                 return self.get_reverse_state(0)
             return 0
         else:
-            #print "not mul, return worst", worse_state
+            # print "not mul, return worst", worse_state
             if 2 in states:
                 worst_state = 2
             else:
@@ -279,12 +281,12 @@ class DependencyNodeFactory(object):
     # the () will be eval in a recursiv way, only one level of ()
     def eval_cor_pattern(self, pattern, hosts, services, running=False):
         pattern = pattern.strip()
-        #print "***** EVAL ", pattern
+        # print "***** EVAL ", pattern
         complex_node = False
 
         # Look if it's a complex pattern (with rule) or
         # if it's a leaf ofit, like a host/service
-        for m in '()+&|':
+        for m in '()&|':
             if m in pattern:
                 complex_node = True
 
@@ -302,7 +304,7 @@ class DependencyNodeFactory(object):
         r = re.compile(p)
         m = r.search(pattern)
         if m is not None:
-            #print "Match the of: thing N=", m.groups()
+            # print "Match the of: thing N=", m.groups()
             node.operand = 'of:'
             g = m.groups()
             # We can have a Aof: rule, or a multiple A,B,Cof: rule.
@@ -330,14 +332,14 @@ class DependencyNodeFactory(object):
         for c in pattern:
             if c == '(':
                 stacked_par += 1
-                #print "INCREASING STACK TO", stacked_par
+                # print "INCREASING STACK TO", stacked_par
 
                 in_par = True
                 tmp = tmp.strip()
                 # Maybe we just start a par, but we got some things in tmp
                 # that should not be good in fact !
                 if stacked_par == 1 and tmp != '':
-                    #TODO : real error
+                    # TODO : real error
                     print "ERROR : bad expression near", tmp
                     continue
 
@@ -347,7 +349,7 @@ class DependencyNodeFactory(object):
                     tmp += c
 
             elif c == ')':
-                #print "Need closeing a sub expression?", tmp
+                # print "Need closeing a sub expression?", tmp
                 stacked_par -= 1
 
                 if stacked_par < 0:
@@ -356,7 +358,7 @@ class DependencyNodeFactory(object):
                     continue
 
                 if stacked_par == 0:
-                    #print "THIS is closing a sub compress expression", tmp
+                    # print "THIS is closing a sub compress expression", tmp
                     tmp = tmp.strip()
                     o = self.eval_cor_pattern(tmp, hosts, services, running)
                     # Maybe our son was notted
@@ -380,7 +382,7 @@ class DependencyNodeFactory(object):
             # Until here, we're not in par
 
             # Manage the NOT for an expression. Only allow ! at the beginning
-            # of an host or an host,service expression.
+            # of a host or a host,service expression.
             elif c == '!':
                 tmp = tmp.strip()
                 if tmp and tmp[0] != '!':
@@ -390,10 +392,10 @@ class DependencyNodeFactory(object):
                 son_is_not = True
                 # DO NOT keep the c in tmp, we consumed it
 
-            #print "MATCHING", c, pattern
+            # print "MATCHING", c, pattern
             elif c == '&' or c == '|':
                 # Oh we got a real cut in an expression, if so, cut it
-                #print "REAL & for cutting"
+                # print "REAL & for cutting"
                 tmp = tmp.strip()
                 # Look at the rule viability
                 if node.operand is not None and node.operand != 'of:' and c != node.operand:
@@ -403,7 +405,7 @@ class DependencyNodeFactory(object):
                 if node.operand != 'of:':
                     node.operand = c
                 if tmp != '':
-                    #print "Will analyse the current str", tmp
+                    # print "Will analyse the current str", tmp
                     o = self.eval_cor_pattern(tmp, hosts, services, running)
                     # Maybe our son was notted
                     if son_is_not:
@@ -419,13 +421,13 @@ class DependencyNodeFactory(object):
         # Be sure to manage the trainling part when the line is done
         tmp = tmp.strip()
         if tmp != '':
-            #print "Managing trainling part", tmp
+            # print "Managing trainling part", tmp
             o = self.eval_cor_pattern(tmp, hosts, services, running)
             # Maybe our son was notted
             if son_is_not:
                 o.not_value = True
                 son_is_not = False
-            #print "4end I've %s got new sons" % pattern , o
+            # print "4end I've %s got new sons" % pattern , o
             node.sons.append(o)
 
         # We got our nodes, so we can update 0 values of of_values
@@ -435,13 +437,13 @@ class DependencyNodeFactory(object):
         return node
 
 
-    # Evaluate a simple correlation expression, such as an host, an host + a
-    # service, or expand an host or service expression.
+    # Evaluate a simple correlation expression, such as a host, a host + a
+    # service, or expand a host or service expression.
     def eval_simple_cor_pattern(self, pattern, hosts, services, running=False):
         node = DependencyNode()
         pattern = self.eval_xof_pattern(node, pattern)
 
-        #print "Try to find?", pattern
+        # print "Try to find?", pattern
         # If it's a not value, tag the node and find
         # the name without this ! operator
         if pattern.startswith('!'):
@@ -481,7 +483,7 @@ class DependencyNodeFactory(object):
     # db1 service of the host db1, or just h1, that mean
     # the host h1.
     def find_object(self, pattern, hosts, services):
-        #print "Finding object", pattern
+        # print "Finding object", pattern
         obj = None
         error = None
         is_service = False
@@ -498,7 +500,8 @@ class DependencyNodeFactory(object):
         if is_service:
             obj = services.find_srv_by_name_and_hostname(host_name, service_description)
             if not obj:
-                error = "Business rule uses unknown service %s/%s" % (host_name, service_description)
+                error = "Business rule uses unknown service %s/%s"\
+                        % (host_name, service_description)
         else:
             obj = hosts.find_by_name(host_name)
             if not obj:
@@ -526,7 +529,7 @@ class DependencyNodeFactory(object):
                 filters.extend(self.get_srv_service_filters(service_expr))
                 items = services.find_by_filter(filters)
             else:
-                # We got an host expression
+                # We got a host expression
                 host_expr = elts[0]
                 filters.extend(self.get_host_filters(host_expr))
                 items = hosts.find_by_filter(filters)
@@ -567,7 +570,7 @@ class DependencyNodeFactory(object):
         if expr == "*":
             return [filter_any]
         match = re.search(r"^([%s]+):(.*)" % self.host_flags, expr)
-        
+
         if match is None:
             return [filter_host_by_name(expr)]
         flags, expr = match.groups()
@@ -578,7 +581,7 @@ class DependencyNodeFactory(object):
         elif "l" in flags:
             return [filter_host_by_bp_rule_label(expr)]
         elif "t" in flags:
-            return [filter_host_by_template(expr)]
+            return [filter_host_by_tag(expr)]
         else:
             return [filter_none]
 
@@ -599,7 +602,7 @@ class DependencyNodeFactory(object):
         elif "l" in flags:
             return [filter_service_by_host_bp_rule_label(expr)]
         elif "t" in flags:
-            return [filter_service_by_host_template_name(expr)]
+            return [filter_service_by_host_tag_name(expr)]
         else:
             return [filter_none]
 
