@@ -1,8 +1,7 @@
 #!/usr/bin/env python
-
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2009-2012:
+# Copyright (C) 2009-2014:
 #     Gabes Jean, naparuba@gmail.com
 #     Gerhard Lausser, Gerhard.Lausser@consol.de
 #     Gregory Starck, g.starck@gmail.com
@@ -33,7 +32,6 @@
 
 import time
 import random
-import itertools
 
 from shinken.util import alive_then_spare_then_deads
 from shinken.log import logger
@@ -54,10 +52,12 @@ class Dispatcher:
         self.realms = conf.realms
         # Direct pointer to important elements for us
 
-        for sat_type in ('arbiters', 'schedulers', 'reactionners', 'brokers', 'receivers', 'pollers'):
+        for sat_type in ('arbiters', 'schedulers', 'reactionners',
+                         'brokers', 'receivers', 'pollers'):
             setattr(self, sat_type, getattr(self.conf, sat_type))
 
-            # for each satellite, we look if current arbiter have a specific satellitemap value setted for this satellite
+            # for each satellite, we look if current arbiter have a specific
+            # satellitemap value set for this satellite.
             # if so, we give this map to the satellite (used to build satellite URI later)
             if arbiter is None:
                 continue
@@ -68,7 +68,7 @@ class Dispatcher:
                 satellite.set_arbiter_satellitemap(arbiter.satellitemap.get(sat_name, {}))
 
         self.dispatch_queue = {'schedulers': [], 'reactionners': [],
-                                'brokers': [], 'pollers': [], 'receivers': []}
+                               'brokers': [], 'pollers': [], 'receivers': []}
         self.elements = []  # all elements, sched and satellites
         self.satellites = []  # only satellites not schedulers
 
@@ -118,7 +118,7 @@ class Dispatcher:
     # checks alive elements
     def check_alive(self):
         for elt in self.elements:
-            #print "Updating elements", elt.get_name(), elt.__dict__
+            # print "Updating elements", elt.get_name(), elt.__dict__
             elt.update_infos()
 
             # Not alive needs new need_conf
@@ -131,7 +131,7 @@ class Dispatcher:
             # If not me, but not the master too
             if arb != self.arbiter and arb.spare:
                 arb.update_infos()
-                #print "Arb", arb.get_name(), "alive?", arb.alive, arb.__dict__
+                # print "Arb", arb.get_name(), "alive?", arb.alive, arb.__dict__
 
 
     # Check if all active items are still alive
@@ -144,7 +144,8 @@ class Dispatcher:
             if arb != self.arbiter and self.arbiter and not self.arbiter.spare:
                 if not arb.have_conf(self.conf.magic_hash):
                     if not hasattr(self.conf, 'whole_conf_pack'):
-                        logger.error('CRITICAL: the arbiter try to send a configureion but it is not a MASTER one?? Look at your configuration.')
+                        logger.error('CRITICAL: the arbiter try to send a configureion but '
+                                     'it is not a MASTER one?? Look at your configuration.')
                         continue
                     arb.put_conf(self.conf.whole_conf_pack)
                     # Remind it that WE are the master here!
@@ -162,22 +163,25 @@ class Dispatcher:
                 sched = r.confs[cfg_id].assigned_to
                 if sched is None:
                     if self.first_dispatch_done:
-                        logger.info("Scheduler configuration %d is unmanaged!!" % cfg_id)
+                        logger.info("Scheduler configuration %d is unmanaged!!", cfg_id)
                     self.dispatch_ok = False
                 else:
                     if not sched.alive:
                         self.dispatch_ok = False  # so we ask a new dispatching
-                        logger.warning("Scheduler %s had the configuration %d but is dead, I am not happy." % (sched.get_name(), cfg_id))
+                        logger.warning("Scheduler %s had the configuration %d but is dead, "
+                                       "I am not happy.", sched.get_name(), cfg_id)
                         sched.conf.assigned_to = None
                         sched.conf.is_assigned = False
                         sched.conf.push_flavor = 0
                         sched.push_flavor = 0
                         sched.conf = None
-                    # Maybe the scheduler restarts, so is alive but without the conf we think it was managing
-                    # so ask it what it is really managing, and if not, put the conf unassigned
+                    # Maybe the scheduler restarts, so is alive but without
+                    # the conf we think it was managing so ask it what it is
+                    # really managing, and if not, put the conf unassigned
                     if not sched.do_i_manage(cfg_id, push_flavor):
                         self.dispatch_ok = False  # so we ask a new dispatching
-                        logger.warning("Scheduler %s did not managed its configuration %d,I am not happy." % (sched.get_name(), cfg_id))
+                        logger.warning("Scheduler %s did not managed its configuration %d, "
+                                       "I am not happy.", sched.get_name(), cfg_id)
                         if sched.conf:
                             sched.conf.assigned_to = None
                             sched.conf.is_assigned = False
@@ -197,12 +201,14 @@ class Dispatcher:
                     for kind in ('reactionner', 'poller', 'broker', 'receiver'):
                         # We must have the good number of satellite or we are not happy
                         # So we are sure to raise a dispatch every loop a satellite is missing
-                        if len(r.to_satellites_managed_by[kind][cfg_id]) < r.get_nb_of_must_have_satellites(kind):
-                            logger.warning("Missing satellite %s for configuration %d:" % (kind, cfg_id))
+                        if (len(r.to_satellites_managed_by[kind][cfg_id])
+                                < r.get_nb_of_must_have_satellites(kind)):
+                            logger.warning("Missing satellite %s for configuration %d:",
+                                           kind, cfg_id)
 
                             # TODO: less violent! Must only resent to who need?
-                            # must be caught by satellite who sees that it already has the conf (hash)
-                            # and do nothing
+                            # must be caught by satellite who sees that
+                            # it already has the conf (hash) and do nothing
                             self.dispatch_ok = False  # so we will redispatch all
                             r.to_satellites_need_dispatch[kind][cfg_id] = True
                             r.to_satellites_managed_by[kind][cfg_id] = []
@@ -210,14 +216,20 @@ class Dispatcher:
                             # Maybe the sat was marked as not alive, but still in
                             # to_satellites_managed_by. That means that a new dispatch
                             # is needed
-                            # Or maybe it is alive but I thought that this reactionner managed the conf
-                            # and it doesn't. I ask a full redispatch of these cfg for both cases
-                            
+                            # Or maybe it is alive but I thought that this reactionner
+                            # managed the conf and it doesn't.
+                            # I ask a full redispatch of these cfg for both cases
+
                             if push_flavor == 0 and satellite.alive:
-                                logger.warning('[%s] The %s %s manage a unmanaged configuration' % (r.get_name(), kind, satellite.get_name()))
+                                logger.warning('[%s] The %s %s manage a unmanaged configuration',
+                                               r.get_name(), kind, satellite.get_name())
                                 continue
-                            if not satellite.alive or (satellite.reachable and not satellite.do_i_manage(cfg_id, push_flavor)):
-                                logger.warning('[%s] The %s %s seems to be down, I must re-dispatch its role to someone else.' % (r.get_name(), kind, satellite.get_name()))
+                            if not satellite.alive or (
+                                    satellite.reachable
+                                    and not satellite.do_i_manage(cfg_id, push_flavor)):
+                                logger.warning('[%s] The %s %s seems to be down, '
+                                               'I must re-dispatch its role to someone else.',
+                                               r.get_name(), kind, satellite.get_name())
                                 self.dispatch_ok = False  # so we will redispatch all
                                 r.to_satellites_need_dispatch[kind][cfg_id] = True
                                 r.to_satellites_managed_by[kind][cfg_id] = []
@@ -250,7 +262,9 @@ class Dispatcher:
                 if elt.conf is None and elt.reachable:
                     # print "Ask", elt.get_name() , 'if it got conf'
                     if elt.have_conf():
-                        logger.warning("The element %s have a conf and should not have one! I ask it to idle now" % elt.get_name())
+                        logger.warning("The element %s have a conf and should "
+                                       "not have one! I ask it to idle now",
+                                       elt.get_name())
                         elt.active = False
                         elt.wait_new_conf()
                         # I do not care about order not send or not. If not,
@@ -275,18 +289,19 @@ class Dispatcher:
                             if cfg_id in r.confs:
                                 # Ok we've got the realm, we check its to_satellites_managed_by
                                 # to see if reactionner is in. If not, we remove he sched_id for it
-                                if not satellite in r.to_satellites_managed_by[kind][cfg_id]:
+                                if satellite not in r.to_satellites_managed_by[kind][cfg_id]:
                                     id_to_delete.append(cfg_id)
                     # Maybe we removed all cfg_id of this reactionner
                     # We can put it idle, no active and wait_new_conf
                     if len(id_to_delete) == len(cfg_ids):
                         satellite.active = False
-                        logger.info("I ask %s to wait a new conf" % satellite.get_name())
+                        logger.info("I ask %s to wait a new conf", satellite.get_name())
                         satellite.wait_new_conf()
                     else:
                         # It is not fully idle, just less cfg
                         for id in id_to_delete:
-                            logger.info("I ask to remove configuration N%d from %s" % (id, satellite.get_name()))
+                            logger.info("I ask to remove configuration N%d from %s",
+                                        id, satellite.get_name())
                             satellite.remove_from_conf(id)
 
 
@@ -330,15 +345,17 @@ class Dispatcher:
                 conf_to_dispatch = [cfg for cfg in r.confs.values() if not cfg.is_assigned]
                 nb_conf = len(conf_to_dispatch)
                 if nb_conf > 0:
-                    logger.info("Dispatching Realm %s" % r.get_name())
-                    logger.info('[%s] Dispatching %d/%d configurations' % (r.get_name(), nb_conf, len(r.confs)))
+                    logger.info("Dispatching Realm %s", r.get_name())
+                    logger.info('[%s] Dispatching %d/%d configurations',
+                                r.get_name(), nb_conf, len(r.confs))
 
                 # Now we get in scheds all scheduler of this realm and upper so
                 # we will send them conf (in this order)
                 scheds = self.get_scheduler_ordered_list(r)
 
                 if nb_conf > 0:
-                    print_string = '[%s] Schedulers order: %s' % (r.get_name(), ','.join([s.get_name() for s in scheds]))
+                    print_string = '[%s] Schedulers order: %s' % (
+                        r.get_name(), ','.join([s.get_name() for s in scheds]))
                     logger.info(print_string)
 
                 # Try to send only for alive members
@@ -347,11 +364,12 @@ class Dispatcher:
                 # Now we do the real job
                 # every_one_need_conf = False
                 for conf in conf_to_dispatch:
-                    logger.info('[%s] Dispatching configuration %s' % (r.get_name(), conf.id))
+                    logger.info('[%s] Dispatching configuration %s', r.get_name(), conf.id)
 
                     # If there is no alive schedulers, not good...
                     if len(scheds) == 0:
-                        logger.info('[%s] but there a no alive schedulers in this realm!' % r.get_name())
+                        logger.info('[%s] but there a no alive schedulers in this realm!',
+                                    r.get_name())
 
                     # we need to loop until the conf is assigned
                     # or when there are no more schedulers available
@@ -368,9 +386,11 @@ class Dispatcher:
                                 r.to_satellites_managed_by[kind][cfg_id] = []
                             break
 
-                        logger.info('[%s] Trying to send conf %d to scheduler %s' % (r.get_name(), conf.id, sched.get_name()))
+                        logger.info('[%s] Trying to send conf %d to scheduler %s',
+                                    r.get_name(), conf.id, sched.get_name())
                         if not sched.need_conf:
-                            logger.info('[%s] The scheduler %s do not need conf, sorry' % (r.get_name(), sched.get_name()))
+                            logger.info('[%s] The scheduler %s do not need conf, sorry',
+                                        r.get_name(), sched.get_name())
                             continue
 
                         # We tag conf with the instance_name = scheduler_name
@@ -383,30 +403,46 @@ class Dispatcher:
                         satellites_for_sched = r.get_satellites_links_for_scheduler()
                         s_conf = r.serialized_confs[conf.id]
                         # Prepare the conf before sending it
-                        conf_package = {'conf': s_conf, 'override_conf': override_conf,
-                                        'modules': sched.modules, 'satellites': satellites_for_sched,
-                                        'instance_name': sched.scheduler_name, 'push_flavor': conf.push_flavor,
-                                        'skip_initial_broks': sched.skip_initial_broks,
-                                        }
+                        conf_package = {
+                            'conf': s_conf, 'override_conf': override_conf,
+                            'modules': sched.modules, 'satellites': satellites_for_sched,
+                            'instance_name': sched.scheduler_name, 'push_flavor': conf.push_flavor,
+                            'skip_initial_broks': sched.skip_initial_broks,
+                            'accept_passive_unknown_check_results':
+                                sched.accept_passive_unknown_check_results,
+                            # shiken.io part
+                            'api_key': self.conf.api_key,
+                            'secret': self.conf.secret,
+                            'http_proxy': self.conf.http_proxy,
+                            # statsd one too because OlivierHA love statsd
+                            # and after some years of effort he manages to make me
+                            # understand the powerfullness of metrics :)
+                            'statsd_host': self.conf.statsd_host,
+                            'statsd_port': self.conf.statsd_port,
+                            'statsd_prefix': self.conf.statsd_prefix,
+                            'statsd_enabled': self.conf.statsd_enabled,
+                        }
 
                         t1 = time.time()
                         is_sent = sched.put_conf(conf_package)
-                        logger.debug("Conf is sent in %d" % (time.time() - t1))
+                        logger.debug("Conf is sent in %d", time.time() - t1)
                         if not is_sent:
-                            logger.warning('[%s] configuration dispatching error for scheduler %s' % (r.get_name(), sched.get_name()))
+                            logger.warning('[%s] configuration dispatching error for scheduler %s',
+                                           r.get_name(), sched.get_name())
                             continue
-                        
-                        logger.info('[%s] Dispatch OK of conf in scheduler %s' % (r.get_name(), sched.get_name()))
-                        
+
+                        logger.info('[%s] Dispatch OK of conf in scheduler %s',
+                                    r.get_name(), sched.get_name())
+
                         sched.conf = conf
                         sched.push_flavor = conf.push_flavor
                         sched.need_conf = False
                         conf.is_assigned = True
                         conf.assigned_to = sched
-                        
+
                         # We update all data for this scheduler
                         sched.managed_confs = {conf.id: conf.push_flavor}
-                        
+
                         # Now we generate the conf for satellites:
                         cfg_id = conf.id
                         for kind in ('reactionner', 'poller', 'broker', 'receiver'):
@@ -422,7 +458,8 @@ class Dispatcher:
             conf_to_dispatch = [cfg for cfg in self.conf.confs.values() if not cfg.is_assigned]
             nb_missed = len(conf_to_dispatch)
             if nb_missed > 0:
-                logger.warning("All schedulers configurations are not dispatched, %d are missing" % nb_missed)
+                logger.warning("All schedulers configurations are not dispatched, %d are missing",
+                               nb_missed)
             else:
                 logger.info("OK, all schedulers configurations are dispatched :)")
                 self.dispatch_ok = True
@@ -432,7 +469,8 @@ class Dispatcher:
             if self.dispatch_ok:
                 for sched in self.schedulers.items.values():
                     if sched.conf is None:
-                        # print "Tagging sched", sched.get_name(), "so it do not ask anymore for conf"
+                        # print "Tagging sched", sched.get_name(),
+                        # "so it do not ask anymore for conf"
                         sched.need_conf = False
 
             arbiters_cfg = {}
@@ -467,56 +505,58 @@ class Dispatcher:
                                 # Should look over the list, not over
                                 if len(nospare) != 0:
                                     idx = cfg_id % len(nospare)
-                                    #print "No spare", nospare
                                     spares = [s for s in satellites if s.spare]
-                                    #print "Spare", spares
-                                    #print "Got 1", nospare[idx:]
-                                    #print "Got 2", nospare[:-idx+1]
                                     new_satellites = nospare[idx:]
-                                    for _b in nospare[:-idx+1]:
+                                    for _b in nospare[: -idx + 1]:
                                         if _b not in new_satellites:
                                             new_satellites.append(_b)
-                                    #new_satellites.extend(nospare[:-idx+1])
-                                    #print "New satellites", cfg_id, new_satellites
-                                    #for s in new_satellites:
-                                    #    print "New satellites", cfg_id, s.get_name()
                                     satellites = new_satellites
                                     satellites.extend(spares)
 
                             # Dump the order where we will send conf
-                            satellite_string = "[%s] Dispatching %s satellite with order: " % (r.get_name(), kind)
+                            satellite_string = "[%s] Dispatching %s satellite with order: " % (
+                                r.get_name(), kind)
                             for satellite in satellites:
-                                satellite_string += '%s (spare:%s), ' % (satellite.get_name(), str(satellite.spare))
+                                satellite_string += '%s (spare:%s), ' % (
+                                    satellite.get_name(), str(satellite.spare))
                             logger.info(satellite_string)
-                            
+
                             # Now we dispatch cfg to every one ask for it
                             nb_cfg_sent = 0
                             for satellite in satellites:
                                 # Send only if we need, and if we can
-                                if nb_cfg_sent < r.get_nb_of_must_have_satellites(kind) and satellite.alive:
+                                if (nb_cfg_sent < r.get_nb_of_must_have_satellites(kind) and
+                                        satellite.alive):
                                     satellite.cfg['schedulers'][cfg_id] = cfg_for_satellite_part
                                     if satellite.manage_arbiters:
                                         satellite.cfg['arbiters'] = arbiters_cfg
-                                    
+
                                     # Brokers should have poller/reactionners links too
                                     if kind == "broker":
                                         r.fill_broker_with_poller_reactionner_links(satellite)
 
                                     is_sent = False
-                                    # Maybe this satellite already got this configuration, so skip it
+                                    # Maybe this satellite already got this configuration,
+                                    # so skip it
                                     if satellite.do_i_manage(cfg_id, flavor):
-                                        logger.info('[%s] Skipping configuration %d send to the %s %s: it already got it' % (r.get_name(), cfg_id, kind, satellite.get_name()))
+                                        logger.info('[%s] Skipping configuration %d send '
+                                                    'to the %s %s: it already got it',
+                                                    r.get_name(), cfg_id, kind,
+                                                    satellite.get_name())
                                         is_sent = True
                                     else:  # ok, it really need it :)
-                                        logger.info('[%s] Trying to send configuration to %s %s' % (r.get_name(), kind, satellite.get_name()))
+                                        logger.info('[%s] Trying to send configuration to %s %s',
+                                                    r.get_name(), kind, satellite.get_name())
                                         is_sent = satellite.put_conf(satellite.cfg)
 
                                     if is_sent:
                                         satellite.active = True
-                                        logger.info('[%s] Dispatch OK of configuration %s to %s %s' % (r.get_name(), cfg_id, kind, satellite.get_name()))
+                                        logger.info('[%s] Dispatch OK of configuration %s to %s %s',
+                                                    r.get_name(), cfg_id, kind,
+                                                    satellite.get_name())
                                         # We change the satellite configuration, update our data
                                         satellite.known_conf_managed_push(cfg_id, flavor)
-                                        
+
                                         nb_cfg_sent += 1
                                         r.to_satellites_managed_by[kind][cfg_id].append(satellite)
 
@@ -524,16 +564,20 @@ class Dispatcher:
                                         # broker in a classic realm.
                                         if kind == "broker" and not r.broker_complete_links:
                                             break
-                                        
-                                        #If receiver, we must send the hostnames of this configuration
+
+                                        # If receiver, we must send the hostnames
+                                        # of this configuration
                                         if kind == 'receiver':
                                             hnames = [h.get_name() for h in cfg.hosts]
-                                            logger.debug("[%s] Sending %s hostnames to the receiver %s" % (r.get_name(), len(hnames), satellite.get_name()))
+                                            logger.debug("[%s] Sending %s hostnames to the "
+                                                         "receiver %s",
+                                                         r.get_name(), len(hnames),
+                                                         satellite.get_name())
                                             satellite.push_host_names(cfg_id, hnames)
                             # else:
                             #    #I've got enough satellite, the next ones are considered spares
                             if nb_cfg_sent == r.get_nb_of_must_have_satellites(kind):
-                                logger.info("[%s] OK, no more %s sent need" % (r.get_name(), kind))
+                                logger.info("[%s] OK, no more %s sent need", r.get_name(), kind)
                                 r.to_satellites_need_dispatch[kind][cfg_id] = False
 
             # And now we dispatch receivers. It's easier, they need ONE conf
@@ -541,15 +585,19 @@ class Dispatcher:
             for r in self.realms:
                 for rec in r.receivers:
                     if rec.need_conf:
-                        logger.info('[%s] Trying to send configuration to receiver %s' % (r.get_name(), rec.get_name()))
+                        logger.info('[%s] Trying to send configuration to receiver %s',
+                                    r.get_name(), rec.get_name())
                         is_sent = False
                         if rec.reachable:
                             is_sent = rec.put_conf(rec.cfg)
                         else:
-                            logger.info('[%s] Skyping configuration sent to offline receiver %s' % (r.get_name(), rec.get_name()))
+                            logger.info('[%s] Skyping configuration sent to offline receiver %s',
+                                        r.get_name(), rec.get_name())
                         if is_sent:
                             rec.active = True
                             rec.need_conf = False
-                            logger.info('[%s] Dispatch OK of configuration to receiver %s' % (r.get_name(), rec.get_name()))
+                            logger.info('[%s] Dispatch OK of configuration to receiver %s',
+                                        r.get_name(), rec.get_name())
                         else:
-                            logger.error('[%s] Dispatching failed for receiver %s' % (r.get_name(), rec.get_name()))
+                            logger.error('[%s] Dispatching failed for receiver %s',
+                                         r.get_name(), rec.get_name())
