@@ -1,8 +1,7 @@
 #!/usr/bin/env python
-
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2009-2012:
+# Copyright (C) 2009-2014:
 #     Gabes Jean, naparuba@gmail.com
 #     Gerhard Lausser, Gerhard.Lausser@consol.de
 #     Gregory Starck, g.starck@gmail.com
@@ -23,6 +22,7 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with Shinken.  If not, see <http://www.gnu.org/licenses/>.
 
+
 from shinken.log import logger
 
 def episode_iv():
@@ -61,11 +61,18 @@ def naheulbeuk():
     else:
         screen = aalib.AnsiScreen
     screen = screen(width=128, height=128)
-    fp = StringIO(urllib2.urlopen('http://www.penofchaos.com/warham/bd/images/NBK-win7portrait-Nain02.JPG').read())
+    fp = StringIO(urllib2.urlopen(
+        'http://www.penofchaos.com/warham/bd/images/NBK-win7portrait-Nain02.JPG').read())
     image = Image.open(fp).convert('L').resize(screen.virtual_size)
     screen.put_image((0, 0), image)
     logger.info(screen.render())
-                    
+
+
+
+def what_it_make_me_think(subject):
+    import hashlib
+    if hashlib.md5(subject.lower()).hexdigest() == '6376e9755f8047391621b577ae03966a':
+        print "Thanks to %s now I feel like this:  https://youtu.be/efTZslkr5Fs?t=60" % subject
 
 
 def dark():
@@ -126,4 +133,3 @@ def get_coffee():
 
 """
     logger.info(get_coffee.__doc__)
-
