@@ -1,8 +1,7 @@
 #!/usr/bin/python
-
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2009-2012:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #    Gregory Starck, g.starck@gmail.com
@@ -36,11 +35,11 @@ from shinken.objects.notificationway import NotificationWay, NotificationWays
 from shinken.objects.timeperiod import Timeperiod, Timeperiods
 from shinken.objects.command import Command, Commands
 from shinken.objects.config import Config
-from shinken.schedulerlink import SchedulerLink, SchedulerLinks
-from shinken.reactionnerlink import ReactionnerLink, ReactionnerLinks
-from shinken.pollerlink import PollerLink, PollerLinks
-from shinken.brokerlink import BrokerLink, BrokerLinks
-from shinken.receiverlink import ReceiverLink, ReceiverLinks
+from shinken.objects.schedulerlink import SchedulerLink, SchedulerLinks
+from shinken.objects.reactionnerlink import ReactionnerLink, ReactionnerLinks
+from shinken.objects.pollerlink import PollerLink, PollerLinks
+from shinken.objects.brokerlink import BrokerLink, BrokerLinks
+from shinken.objects.receiverlink import ReceiverLink, ReceiverLinks
 from shinken.util import safe_print
 from shinken.message import Message
 
@@ -129,14 +128,14 @@ class Regenerator(object):
     # we will skip them
     def want_brok(self, brok):
         if self.in_scheduler_mode:
-            return not brok.type in ['program_status', 'initial_host_status',
-                             'initial_hostgroup_status', 'initial_service_status',
-                             'initial_servicegroup_status', 'initial_contact_status',
-                             'initial_contactgroup_status', 'initial_timeperiod_status',
-                             'initial_command_status']
-        # Ok you are wondering why we don't add initial_broks_done? It's because the LiveSTatus modules
-        # need this part to do internal things. But don't worry, the vanilla regenerator
-        # will just skip it in all_done_linking :D
+            return brok.type not in ['program_status', 'initial_host_status',
+                                     'initial_hostgroup_status', 'initial_service_status',
+                                     'initial_servicegroup_status', 'initial_contact_status',
+                                     'initial_contactgroup_status', 'initial_timeperiod_status',
+                                     'initial_command_status']
+        # Ok you are wondering why we don't add initial_broks_done?
+        # It's because the LiveSTatus modules need this part to do internal things.
+        # But don't worry, the vanilla regenerator will just skip it in all_done_linking :D
 
         # Not in don't want? so want! :)
         return True
@@ -155,37 +154,20 @@ class Regenerator(object):
             setattr(e, prop, data[prop])
 
 
-    def create_reversed_list(self):
-        self.hosts.create_reversed_list()
-        self.hostgroups.create_reversed_list()
-        self.contacts.create_reversed_list()
-        self.contactgroups.create_reversed_list()
-        self.notificationways.create_reversed_list()
-        self.services.create_reversed_list()
-        self.servicegroups.create_reversed_list()
-        self.timeperiods.create_reversed_list()
-        #self.modules.create_reversed_list()
-        #self.resultmodulations.create_reversed_list()
-        #self.criticitymodulations.create_reversed_list()
-        #self.escalations.create_reversed_list()
-        #self.discoveryrules.create_reversed_list()
-        #self.discoveryruns.create_reversed_list()
-        self.commands.create_reversed_list()
-
-
     # Now we get all data about an instance, link all this stuff :)
     def all_done_linking(self, inst_id):
 
         # In a scheduler we are already "linked" so we can skip this
         if self.in_scheduler_mode:
-            safe_print("Regenerator: We skip the all_done_linking phase because we are in a scheduler")
+            safe_print("Regenerator: We skip the all_done_linking phase "
+                       "because we are in a scheduler")
             return
 
         start = time.time()
         safe_print("In ALL Done linking phase for instance", inst_id)
         # check if the instance is really defined, so got ALL the
         # init phase
-        if not inst_id in self.configs.keys():
+        if inst_id not in self.configs.keys():
             safe_print("Warning: the instance %d is not fully given, bailout" % inst_id)
             return
 
@@ -193,11 +175,9 @@ class Regenerator(object):
         # finding
         try:
             inp_hosts = self.inp_hosts[inst_id]
-            inp_hosts.create_reversed_list()
             inp_hostgroups = self.inp_hostgroups[inst_id]
             inp_contactgroups = self.inp_contactgroups[inst_id]
             inp_services = self.inp_services[inst_id]
-            inp_services.create_reversed_list()
             inp_servicegroups = self.inp_servicegroups[inst_id]
         except Exception, exp:
             print "Warning all done: ", exp
@@ -221,15 +201,14 @@ class Regenerator(object):
             if hg:
                 hg.members.extend(inphg.members)
             else:  # else take the new one
-                self.hostgroups[inphg.id] = inphg
-        # We can declare hostgroups done
-        self.hostgroups.create_reversed_list()
+                self.hostgroups.add_item(inphg)
 
         # Now link HOSTS with hostgroups, and commands
         for h in inp_hosts:
-            #print "Linking %s groups %s" % (h.get_name(), h.hostgroups)
+            # print "Linking %s groups %s" % (h.get_name(), h.hostgroups)
             new_hostgroups = []
             for hgname in h.hostgroups.split(','):
+                hgname = hgname.strip()
                 hg = self.hostgroups.find_by_name(hgname)
                 if hg:
                     new_hostgroups.append(hg)
@@ -249,14 +228,12 @@ class Regenerator(object):
 
             # Linkify tags
             for t in h.tags:
-                if not t in self.tags:
+                if t not in self.tags:
                     self.tags[t] = 0
                 self.tags[t] += 1
 
             # We can really declare this host OK now
-            self.hosts[h.id] = h
-
-        self.hosts.create_reversed_list()
+            self.hosts.add_item(h)
 
         # Link SERVICEGROUPS with services
         for sg in inp_servicegroups:
@@ -268,6 +245,7 @@ class Regenerator(object):
                 new_members.append(s)
             sg.members = new_members
 
+
         # Merge SERVICEGROUPS with real ones
         for inpsg in inp_servicegroups:
             sgname = inpsg.servicegroup_name
@@ -277,14 +255,13 @@ class Regenerator(object):
             if sg:
                 sg.members.extend(inpsg.members)
             else:  # else take the new one
-                self.servicegroups[inpsg.id] = inpsg
-        # We can declare servicegroups done
-        self.servicegroups.create_reversed_list()
+                self.servicegroups.add_item(inpsg)
 
         # Now link SERVICES with hosts, servicesgroups, and commands
         for s in inp_services:
             new_servicegroups = []
             for sgname in s.servicegroups.split(','):
+                sgname = sgname.strip()
                 sg = self.servicegroups.find_by_name(sgname)
                 if sg:
                     new_servicegroups.append(sg)
@@ -310,13 +287,12 @@ class Regenerator(object):
 
             # Linkify services tags
             for t in s.tags:
-                if not t in self.services_tags:
+                if t not in self.services_tags:
                     self.services_tags[t] = 0
                 self.services_tags[t] += 1
 
             # We can really declare this host OK now
-            self.services[s.id] = s
-        self.services.optimize_service_search(self.hosts)
+            self.services.add_item(s, index=True)
 
 
         # Add realm of theses hosts. Only the first is useful
@@ -369,12 +345,11 @@ class Regenerator(object):
             # contacts into it
             if cg:
                 cg.members.extend(inpcg.members)
+                cg.members = list(set(cg.members))
             else:  # else take the new one
-                self.contactgroups[inpcg.id] = inpcg
-        # We can declare contactgroups done
-        self.contactgroups.create_reversed_list()
+                self.contactgroups.add_item(inpcg)
 
-        safe_print("ALL LINKING TIME"*10, time.time() - start)
+        safe_print("ALL LINKING TIME" * 10, time.time() - start)
 
         # clean old objects
         del self.inp_hosts[inst_id]
@@ -453,7 +428,7 @@ class Regenerator(object):
             setattr(o, prop, [])
 
         new_v = []
-        #print "Linkify Dict SRV/Host", v, o.get_name(), prop
+        # print "Linkify Dict SRV/Host", v, o.get_name(), prop
         for name in v['services']:
             elts = name.split('/')
             hname = elts[0]
@@ -480,7 +455,9 @@ class Regenerator(object):
                 new_v.append(h)
         setattr(o, prop, new_v)
 
-############### Brok management part
+###############
+# Brok management part
+###############
 
     def before_after_hook(self, brok, obj):
         """
@@ -491,7 +468,9 @@ class Regenerator(object):
         """
         pass
 
-####### INITIAL PART
+#######
+# INITIAL PART
+#######
 
     def manage_program_status_brok(self, b):
         data = b.data
@@ -513,7 +492,7 @@ class Regenerator(object):
         # And we save it
         self.configs[c_id] = c
 
-        ## Clean the old "hard" objects
+        # Clean the old "hard" objects
 
         # We should clean all previously added hosts and services
         safe_print("Clean hosts/service of", c_id)
@@ -541,9 +520,6 @@ class Regenerator(object):
         for sg in self.servicegroups:
             sg.members = [s for s in sg.members if s.instance_id != c_id]
 
-        # We now regenerate reversed list so the client will find only real objects
-        self.create_reversed_list()
-
 
     # Get a new host. Add in in in progress tab
     def manage_initial_host_status_brok(self, b):
@@ -557,7 +533,7 @@ class Regenerator(object):
         except Exception, exp:  # not good. we will cry in theprogram update
             print "Not good!", exp
             return
-        #safe_print("Creating an host: %s in instance %d" % (hname, inst_id))
+        # safe_print("Creating a host: %s in instance %d" % (hname, inst_id))
 
         h = Host({})
         self.update_element(h, data)
@@ -570,7 +546,7 @@ class Regenerator(object):
         inp_hosts[h.id] = h
 
 
-    # From now we only create an hostgroup in the in prepare
+    # From now we only create a hostgroup in the in prepare
     # part. We will link at the end.
     def manage_initial_hostgroup_status_brok(self, b):
         data = b.data
@@ -584,7 +560,7 @@ class Regenerator(object):
             print "Not good!", exp
             return
 
-        safe_print("Creating an hostgroup: %s in instance %d" % (hgname, inst_id))
+        safe_print("Creating a hostgroup: %s in instance %d" % (hgname, inst_id))
 
         # With void members
         hg = Hostgroup([])
@@ -609,7 +585,7 @@ class Regenerator(object):
         except Exception, exp:  # not good. we will cry in theprogram update
             print "Not good!", exp
             return
-        #safe_print("Creating a service: %s/%s in instance %d" % (hname, sdesc, inst_id))
+        # safe_print("Creating a service: %s/%s in instance %d" % (hname, sdesc, inst_id))
 
         s = Service({})
         self.update_element(s, data)
@@ -664,7 +640,7 @@ class Regenerator(object):
             safe_print("Creating Contact:", cname)
             c = Contact({})
             self.update_element(c, data)
-            self.contacts[c.id] = c
+            self.contacts.add_item(c)
 
         # Delete some useless contact values
         del c.host_notification_commands
@@ -684,7 +660,7 @@ class Regenerator(object):
             if not nw:
                 safe_print("Creating notif way", nwname)
                 nw = NotificationWay([])
-                self.notificationways[nw.id] = nw
+                self.notificationways.add_item(nw)
             # Now update it
             for prop in NotificationWay.properties:
                 if hasattr(cnw, prop):
@@ -702,13 +678,8 @@ class Regenerator(object):
 
         c.notificationways = new_notifways
 
-        # Ok, declare this contact now :)
-        # And notif ways too
-        self.contacts.create_reversed_list()
-        self.notificationways.create_reversed_list()
 
-
-    # From now we only create an hostgroup with unlink data in the
+    # From now we only create a hostgroup with unlink data in the
     # in prepare list. We will link all of them at the end.
     def manage_initial_contactgroup_status_brok(self, b):
         data = b.data
@@ -740,7 +711,7 @@ class Regenerator(object):
     # if not: create it and declare it in our main commands
     def manage_initial_timeperiod_status_brok(self, b):
         data = b.data
-        #print "Creating timeperiod", data
+        # print "Creating timeperiod", data
         tpname = data['timeperiod_name']
 
         tp = self.timeperiods.find_by_name(tpname)
@@ -748,12 +719,10 @@ class Regenerator(object):
             # print "Already existing timeperiod", tpname
             self.update_element(tp, data)
         else:
-            #print "Creating Timeperiod:", tpname
+            # print "Creating Timeperiod:", tpname
             tp = Timeperiod({})
             self.update_element(tp, data)
-            self.timeperiods[tp.id] = tp
-            # We add a timeperiod, we update the reversed list
-            self.timeperiods.create_reversed_list()
+            self.timeperiods.add_item(tp)
 
 
     # For command we got 2 cases: do we already got the command or not.
@@ -765,15 +734,13 @@ class Regenerator(object):
 
         c = self.commands.find_by_name(cname)
         if c:
-            #print "Already existing command", cname, "updating it"
+            # print "Already existing command", cname, "updating it"
             self.update_element(c, data)
         else:
-            #print "Creating a new command", cname
+            # print "Creating a new command", cname
             c = Command({})
             self.update_element(c, data)
-            self.commands[c.id] = c
-            # Ok, we can regenerate the reversed list so
-            self.commands.create_reversed_list()
+            self.commands.add_item(c)
 
 
     def manage_initial_scheduler_status_brok(self, b):
@@ -784,7 +751,7 @@ class Regenerator(object):
         print "Created a new scheduler", sched
         self.update_element(sched, data)
         print "Updated scheduler"
-        #print "CMD:", c
+        # print "CMD:", c
         self.schedulers[scheduler_name] = sched
         print "scheduler added"
 
@@ -797,7 +764,7 @@ class Regenerator(object):
         print "Created a new poller", poller
         self.update_element(poller, data)
         print "Updated poller"
-        #print "CMD:", c
+        # print "CMD:", c
         self.pollers[poller_name] = poller
         print "poller added"
 
@@ -810,7 +777,7 @@ class Regenerator(object):
         print "Created a new reactionner", reac
         self.update_element(reac, data)
         print "Updated reactionner"
-        #print "CMD:", c
+        # print "CMD:", c
         self.reactionners[reactionner_name] = reac
         print "reactionner added"
 
@@ -823,7 +790,7 @@ class Regenerator(object):
         print "Created a new broker", broker
         self.update_element(broker, data)
         print "Updated broker"
-        #print "CMD:", c
+        # print "CMD:", c
         self.brokers[broker_name] = broker
         print "broker added"
 
@@ -836,7 +803,7 @@ class Regenerator(object):
         print "Created a new receiver", receiver
         self.update_element(receiver, data)
         print "Updated receiver"
-        #print "CMD:", c
+        # print "CMD:", c
         self.receivers[receiver_name] = receiver
         print "receiver added"
 
@@ -850,7 +817,9 @@ class Regenerator(object):
         self.all_done_linking(inst_id)
 
 
-################# Status Update part
+#################
+# Status Update part
+#################
 
 # A scheduler send us a "I'm alive" brok. If we never
 # heard about this one, we got some problem and we
@@ -861,7 +830,7 @@ class Regenerator(object):
 
         # If we got an update about an unknown instance, cry and ask for a full
         # version!
-        if not c_id in self.configs.keys():
+        if c_id not in self.configs.keys():
             # Do not ask data too quickly, very dangerous
             # one a minute
             if time.time() - self.last_need_data_send > 60 and self.from_q is not None:
@@ -1005,12 +974,14 @@ class Regenerator(object):
         try:
             s = self.schedulers[scheduler_name]
             self.update_element(s, data)
-            #print "S:", s
+            # print "S:", s
         except Exception:
             pass
 
 
-################# Check result and schedule part
+#################
+# Check result and schedule part
+#################
     def manage_host_check_result_brok(self, b):
         data = b.data
         hname = data['host_name']
