@@ -2,7 +2,7 @@
 
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2009-2012:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #    Gregory Starck, g.starck@gmail.com
@@ -51,14 +51,17 @@ class Contactgroup(Itemgroup):
     }
 
     def get_contacts(self):
-        return getattr(self, 'members', '')
+        if getattr(self, 'members', None) is not None:
+            return [m for m in self.members]
+        else:
+            return []
 
     def get_name(self):
         return getattr(self, 'contactgroup_name', 'UNNAMED-CONTACTGROUP')
 
     def get_contactgroup_members(self):
         if self.has('contactgroup_members'):
-            return self.contactgroup_members.split(',')
+            return [m.strip() for m in self.contactgroup_members.split(',')]
         else:
             return []
 
@@ -75,7 +78,8 @@ class Contactgroup(Itemgroup):
         # so if True here, it must be a loop in HG
         # calls... not GOOD!
         if self.rec_tag:
-            logger.error("[contactgroup::%s] got a loop in contactgroup definition" % self.get_name())
+            logger.error("[contactgroup::%s] got a loop in contactgroup definition",
+                         self.get_name())
             if self.has('members'):
                 return self.members
             else:
@@ -107,7 +111,7 @@ class Contactgroups(Itemgroups):
         return cg.get_contacts()
 
     def add_contactgroup(self, cg):
-        self.items[cg.id] = cg
+        self.add_item(cg)
 
     def linkify(self, contacts):
         self.linkify_cg_by_cont(contacts)
@@ -121,12 +125,15 @@ class Contactgroups(Itemgroups):
             # The new member list, in id
             new_mbrs = []
             for mbr in mbrs:
+                mbr = mbr.strip()  # protect with strip at the begining so don't care about spaces
+                if mbr == '':  # void entry, skip this
+                    continue
                 m = contacts.find_by_name(mbr)
                 # Maybe the contact is missing, if so, must be put in unknown_members
                 if m is not None:
                     new_mbrs.append(m)
                 else:
-                    cg.unknown_members.append(mbr)
+                    cg.add_string_unknown_member(mbr)
 
             # Make members uniq
             new_mbrs = list(set(new_mbrs))
