@@ -2,7 +2,7 @@
 
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2009-2012:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #    Gregory Starck, g.starck@gmail.com
@@ -49,9 +49,9 @@ class Hostdependency(Item):
         'dependent_hostgroup_name':      StringProp(default=''),
         'host_name':                     StringProp(),
         'hostgroup_name':                StringProp(default=''),
-        'inherits_parent':               BoolProp(default='0'),
-        'execution_failure_criteria':    ListProp(default='n'),
-        'notification_failure_criteria': ListProp(default='n'),
+        'inherits_parent':               BoolProp(default=False),
+        'execution_failure_criteria':    ListProp(default=['n'], split_on_coma=True),
+        'notification_failure_criteria': ListProp(default=['n'], split_on_coma=True),
         'dependency_period':             StringProp(default='')
     })
 
@@ -60,7 +60,9 @@ class Hostdependency(Item):
     def get_name(self):
         dependent_host_name = 'unknown'
         if getattr(self, 'dependent_host_name', None):
-            dependent_host_name = getattr(getattr(self, 'dependent_host_name'), 'host_name', 'unknown')
+            dependent_host_name = getattr(
+                getattr(self, 'dependent_host_name'), 'host_name', 'unknown'
+            )
         host_name = 'unknown'
         if getattr(self, 'host_name', None):
             host_name = getattr(getattr(self, 'host_name'), 'host_name', 'unknown')
@@ -68,6 +70,8 @@ class Hostdependency(Item):
 
 
 class Hostdependencies(Items):
+    inner_class = Hostdependency  # use for know what is in items
+
     def delete_hostsdep_by_id(self, ids):
         for id in ids:
             del self[id]
@@ -83,40 +87,37 @@ class Hostdependencies(Items):
         hostdeps = self.items.keys()
         for id in hostdeps:
             hd = self.items[id]
-            if hd.is_tpl():  # Exploding template is useless
-                continue
-
             # We explode first the dependent (son) part
             dephnames = []
             if hasattr(hd, 'dependent_hostgroup_name'):
-                dephg_names = hd.dependent_hostgroup_name.split(',')
-                dephg_names = [hg_name.strip() for hg_name in dephg_names]
+                dephg_names = [n.strip() for n in hd.dependent_hostgroup_name.split(',')]
                 for dephg_name in dephg_names:
                     dephg = hostgroups.find_by_name(dephg_name)
                     if dephg is None:
-                        err = "ERROR: the hostdependency got an unknown dependent_hostgroup_name '%s'" % dephg_name
+                        err = "ERROR: the hostdependency got " \
+                              "an unknown dependent_hostgroup_name '%s'" % dephg_name
                         hd.configuration_errors.append(err)
                         continue
-                    dephnames.extend(dephg.members.split(','))
+                    dephnames.extend([m.strip() for m in dephg.members])
 
             if hasattr(hd, 'dependent_host_name'):
-                dephnames.extend(hd.dependent_host_name.split(','))
+                dephnames.extend([n.strip() for n in hd.dependent_host_name.split(',')])
 
             # Ok, and now the father part :)
             hnames = []
             if hasattr(hd, 'hostgroup_name'):
-                hg_names = hd.hostgroup_name.split(',')
-                hg_names = [hg_name.strip() for hg_name in hg_names]
+                hg_names = [n.strip() for n in hd.hostgroup_name.split(',')]
                 for hg_name in hg_names:
                     hg = hostgroups.find_by_name(hg_name)
                     if hg is None:
-                        err = "ERROR: the hostdependency got an unknown hostgroup_name '%s'" % hg_name
+                        err = "ERROR: the hostdependency got" \
+                              " an unknown hostgroup_name '%s'" % hg_name
                         hd.configuration_errors.append(err)
                         continue
-                    hnames.extend(hg.members.split(','))
+                    hnames.extend([m.strip() for m in hg.members])
 
             if hasattr(hd, 'host_name'):
-                hnames.extend(hd.host_name.split(','))
+                hnames.extend([n.strip() for n in hd.host_name.split(',')])
 
             # Loop over all sons and fathers to get S*F host deps
             for dephname in dephnames:
@@ -125,7 +126,7 @@ class Hostdependencies(Items):
                     new_hd = hd.copy()
                     new_hd.dependent_host_name = dephname
                     new_hd.host_name = hname
-                    self.items[new_hd.id] = new_hd
+                    self.add_item(new_hd)
             hstdep_to_remove.append(id)
 
         self.delete_hostsdep_by_id(hstdep_to_remove)
@@ -146,7 +147,8 @@ class Hostdependencies(Items):
                     hd.configuration_errors.append(err)
                 dh = hosts.find_by_name(dh_name)
                 if dh is None:
-                    err = "Error: the host dependency got a bad dependent_host_name definition '%s'" % dh_name
+                    err = "Error: the host dependency got " \
+                          "a bad dependent_host_name definition '%s'" % dh_name
                     hd.configuration_errors.append(err)
                 hd.host_name = h
                 hd.dependent_host_name = dh
@@ -163,31 +165,25 @@ class Hostdependencies(Items):
                 tp = timeperiods.find_by_name(tp_name)
                 hd.dependency_period = tp
             except AttributeError, exp:
-                logger.error("[hostdependency] fail to linkify by timeperiod: %s" % exp)
+                logger.error("[hostdependency] fail to linkify by timeperiod: %s", exp)
 
     # We backport host dep to host. So HD is not need anymore
     def linkify_h_by_hd(self):
         for hd in self:
-            # Link template is useless
-            if hd.is_tpl():
-                continue
             # if the host dep conf is bad, pass this one
-            if getattr(hd, 'host_name', None) is None or getattr(hd, 'dependent_host_name', None) is None:
+            if getattr(hd, 'host_name', None) is None or\
+                    getattr(hd, 'dependent_host_name', None) is None:
                 continue
             # Ok, link!
             depdt_hname = hd.dependent_host_name
             dp = getattr(hd, 'dependency_period', None)
-            depdt_hname.add_host_act_dependency(hd.host_name, hd.notification_failure_criteria, dp, hd.inherits_parent)
-            depdt_hname.add_host_chk_dependency(hd.host_name, hd.execution_failure_criteria, dp, hd.inherits_parent)
+            depdt_hname.add_host_act_dependency(
+                hd.host_name, hd.notification_failure_criteria, dp, hd.inherits_parent
+            )
+            depdt_hname.add_host_chk_dependency(
+                hd.host_name, hd.execution_failure_criteria, dp, hd.inherits_parent
+            )
 
-    # Apply inheritance for all properties
-    def apply_inheritance(self):
-        # We check for all Host properties if the host has it
-        # if not, it check all host templates for a value
-        for prop in Hostdependency.properties:
-            self.apply_partial_inheritance(prop)
-
-        # Then implicit inheritance
-        # self.apply_implicit_inheritance(hosts)
-        for h in self:
-            h.get_customs_properties_by_inheritance(self)
+    def is_correct(self):
+        r = super(Hostdependencies, self).is_correct()
+        return r and self.no_loop_in_parents("host_name", "dependent_host_name")
