@@ -2,7 +2,7 @@
 
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2009-2012:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #    Gregory Starck, g.starck@gmail.com
@@ -31,7 +31,7 @@ import time
 
 from item import Item, Items
 
-from shinken.property import StringProp, ListProp
+from shinken.property import StringProp, IntegerProp, IntListProp
 
 
 class Resultmodulation(Item):
@@ -41,8 +41,8 @@ class Resultmodulation(Item):
     properties = Item.properties.copy()
     properties.update({
         'resultmodulation_name': StringProp(),
-        'exit_codes_match':      ListProp(default=''),
-        'exit_code_modulation':  StringProp(default=None),
+        'exit_codes_match':      IntListProp(default=[]),
+        'exit_code_modulation':  IntegerProp(default=None),
         'modulation_period':     StringProp(default=None),
     })
 
@@ -66,7 +66,7 @@ class Resultmodulation(Item):
     # to be do at running
     def pythonize(self):
         # First apply Item pythonize
-        super(self.__class__, self).pythonize()
+        super(Resultmodulation, self).pythonize()
 
         # Then very special cases
         # Intify the exit_codes_match, and make list
@@ -95,7 +95,8 @@ class Resultmodulations(Items):
             mtp = timeperiods.find_by_name(mtp_name)
 
             if mtp_name != '' and mtp is None:
-                err = "Error: the result modulation '%s' got an unknown modulation_period '%s'" % (rm.get_name(), mtp_name)
+                err = "Error: the result modulation '%s' got an unknown modulation_period '%s'" % \
+                      (rm.get_name(), mtp_name)
                 rm.configuration_errors.append(err)
 
             rm.modulation_period = mtp
