@@ -1,8 +1,7 @@
 #!/usr/bin/python
-
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2009-2012:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #    Gregory Starck, g.starck@gmail.com
@@ -23,10 +22,13 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with Shinken.  If not, see <http://www.gnu.org/licenses/>.
 
-from item import Item, Items
+
 from shinken.property import BoolProp, StringProp, ListProp
 from shinken.log import logger
 
+from .item import Item, Items
+from .service import Service
+
 
 class Servicedependency(Item):
     id = 0
@@ -50,26 +52,32 @@ class Servicedependency(Item):
         'host_name':                     StringProp(),
         'hostgroup_name':                StringProp(default=''),
         'service_description':           StringProp(),
-        'inherits_parent':               BoolProp(default='0'),
-        'execution_failure_criteria':    ListProp(default='n'),
-        'notification_failure_criteria': ListProp(default='n'),
+        'inherits_parent':               BoolProp(default=False),
+        'execution_failure_criteria':    ListProp(default=['n'], split_on_coma=True),
+        'notification_failure_criteria': ListProp(default=['n'], split_on_coma=True),
         'dependency_period':             StringProp(default=''),
-        'explode_hostgroup':             BoolProp(default='0')
+        'explode_hostgroup':             BoolProp(default=False)
     })
 
     # Give a nice name output, for debugging purpose
     # (Yes, debugging CAN happen...)
     def get_name(self):
-        return getattr(self, 'dependent_host_name', '') + '/' + getattr(self, 'dependent_service_description', '') + '..' + getattr(self, 'host_name', '') + '/' + getattr(self, 'service_description', '')
+        return getattr(self, 'dependent_host_name', '') + '/'\
+            + getattr(self, 'dependent_service_description', '') \
+            + '..' + getattr(self, 'host_name', '') + '/' \
+            + getattr(self, 'service_description', '')
 
 
 class Servicedependencies(Items):
+    inner_class = Servicedependency  # use for know what is in items
+
     def delete_servicesdep_by_id(self, ids):
         for id in ids:
             del self[id]
 
     # Add a simple service dep from another (dep -> par)
-    def add_service_dependency(self, dep_host_name, dep_service_description, par_host_name, par_service_description):
+    def add_service_dependency(self, dep_host_name, dep_service_description,
+                               par_host_name, par_service_description):
         # We create a "standard" service_dep
         prop = {
             'dependent_host_name':           dep_host_name,
@@ -80,20 +88,21 @@ class Servicedependencies(Items):
             'inherits_parent': '1',
         }
         sd = Servicedependency(prop)
-        self.items[sd.id] = sd
+        self.add_item(sd)
 
-    # If we have explode_hostgroup parameter we have to create a service dependency for each host of the hostgroup
+    # If we have explode_hostgroup parameter we have to create a
+    # service dependency for each host of the hostgroup
     def explode_hostgroup(self, sd, hostgroups):
         # We will create a service dependency for each host part of the host group
 
         # First get services
-        snames = sd.service_description.split(',')
+        snames = [d.strip() for d in sd.service_description.split(',')]
 
         # And dep services
-        dep_snames = sd.dependent_service_description.split(',')
+        dep_snames = [d.strip() for d in sd.dependent_service_description.split(',')]
 
         # Now for each host into hostgroup we will create a service dependency object
-        hg_names = sd.hostgroup_name.split(',')
+        hg_names = [n.strip() for n in sd.hostgroup_name.split(',')]
         for hg_name in hg_names:
             hg = hostgroups.find_by_name(hg_name)
             if hg is None:
@@ -101,7 +110,7 @@ class Servicedependencies(Items):
                 self.configuration_errors.append(err)
                 continue
             hnames = []
-            hnames.extend(hg.members.split(','))
+            hnames.extend([m.strip() for m in hg.members])
             for hname in hnames:
                 for dep_sname in dep_snames:
                     for sname in snames:
@@ -110,7 +119,7 @@ class Servicedependencies(Items):
                         new_sd.service_description = sname
                         new_sd.dependent_host_name = hname
                         new_sd.dependent_service_description = dep_sname
-                        self.items[new_sd.id] = new_sd
+                        self.add_item(new_sd)
 
     # We create new servicedep if necessary (host groups and co)
     def explode(self, hostgroups):
@@ -123,11 +132,9 @@ class Servicedependencies(Items):
         servicedeps = self.items.keys()
         for id in servicedeps:
             sd = self.items[id]
-            if sd.is_tpl():  # Exploding template is useless
-                continue
-
             # Have we to explode the hostgroup into many service?
-            if hasattr(sd, 'explode_hostgroup') and hasattr(sd, 'hostgroup_name'):
+            if bool(getattr(sd, 'explode_hostgroup', 0)) and \
+               hasattr(sd, 'hostgroup_name'):
                 self.explode_hostgroup(sd, hostgroups)
                 srvdep_to_remove.append(id)
                 continue
@@ -135,22 +142,23 @@ class Servicedependencies(Items):
             # Get the list of all FATHER hosts and service deps
             hnames = []
             if hasattr(sd, 'hostgroup_name'):
-                hg_names = sd.hostgroup_name.split(',')
+                hg_names = [n.strip() for n in sd.hostgroup_name.split(',')]
                 hg_names = [hg_name.strip() for hg_name in hg_names]
                 for hg_name in hg_names:
                     hg = hostgroups.find_by_name(hg_name)
                     if hg is None:
-                        err = "ERROR: the servicedependecy got an unknown hostgroup_name '%s'" % hg_name
+                        err = "ERROR: the servicedependecy got an" \
+                              " unknown hostgroup_name '%s'" % hg_name
                         hg.configuration_errors.append(err)
                         continue
-                    hnames.extend(hg.members.split(','))
+                    hnames.extend([m.strip() for m in hg.members])
 
             if not hasattr(sd, 'host_name'):
                 sd.host_name = ''
 
             if sd.host_name != '':
-                hnames.extend(sd.host_name.split(','))
-            snames = sd.service_description.split(',')
+                hnames.extend([n.strip() for n in sd.host_name.split(',')])
+            snames = [d.strip() for d in sd.service_description.split(',')]
             couples = []
             for hname in hnames:
                 for sname in snames:
@@ -162,22 +170,23 @@ class Servicedependencies(Items):
             # Now the dep part (the sons)
             dep_hnames = []
             if hasattr(sd, 'dependent_hostgroup_name'):
-                hg_names = sd.dependent_hostgroup_name.split(',')
+                hg_names = [n.strip() for n in sd.dependent_hostgroup_name.split(',')]
                 hg_names = [hg_name.strip() for hg_name in hg_names]
                 for hg_name in hg_names:
                     hg = hostgroups.find_by_name(hg_name)
                     if hg is None:
-                        err = "ERROR: the servicedependecy got an unknown dependent_hostgroup_name '%s'" % hg_name
+                        err = "ERROR: the servicedependecy got an " \
+                              "unknown dependent_hostgroup_name '%s'" % hg_name
                         hg.configuration_errors.append(err)
                         continue
-                    dep_hnames.extend(hg.members.split(','))
+                    dep_hnames.extend([m.strip() for m in hg.members])
 
             if not hasattr(sd, 'dependent_host_name'):
                 sd.dependent_host_name = getattr(sd, 'host_name', '')
 
             if sd.dependent_host_name != '':
-                dep_hnames.extend(sd.dependent_host_name.split(','))
-            dep_snames = sd.dependent_service_description.split(',')
+                dep_hnames.extend([n.strip() for n in sd.dependent_host_name.split(',')])
+            dep_snames = [d.strip() for d in sd.dependent_service_description.split(',')]
             dep_couples = []
             for dep_hname in dep_hnames:
                 for dep_sname in dep_snames:
@@ -191,7 +200,7 @@ class Servicedependencies(Items):
                     new_sd.service_description = sname
                     new_sd.dependent_host_name = dep_hname
                     new_sd.dependent_service_description = dep_sname
-                    self.items[new_sd.id] = new_sd
+                    self.add_item(new_sd)
                 # Ok so we can remove the old one
                 srvdep_to_remove.append(id)
 
@@ -205,6 +214,9 @@ class Servicedependencies(Items):
     # We just search for each srvdep the id of the srv
     # and replace the name by the id
     def linkify_sd_by_s(self, hosts, services):
+        to_del = []
+        errors = self.configuration_errors
+        warns = self.configuration_warnings
         for sd in self:
             try:
                 s_name = sd.dependent_service_description
@@ -212,6 +224,16 @@ class Servicedependencies(Items):
 
                 # The new member list, in id
                 s = services.find_srv_by_name_and_hostname(hst_name, s_name)
+                if s is None:
+                    host = hosts.find_by_name(hst_name)
+                    if not (host and host.is_excluded_for_sdesc(s_name)):
+                        errors.append("Service %s not found for host %s" % (s_name, hst_name))
+                    elif host:
+                        warns.append("Service %s is excluded from host %s ; "
+                                     "removing this servicedependency as it's unusuable."
+                                     % (s_name, hst_name))
+                    to_del.append(sd)
+                    continue
                 sd.dependent_service_description = s
 
                 s_name = sd.service_description
@@ -219,10 +241,24 @@ class Servicedependencies(Items):
 
                 # The new member list, in id
                 s = services.find_srv_by_name_and_hostname(hst_name, s_name)
+                if s is None:
+                    host = hosts.find_by_name(hst_name)
+                    if not (host and host.is_excluded_for_sdesc(s_name)):
+                        errors.append("Service %s not found for host %s" % (s_name, hst_name))
+                    elif host:
+                        warns.append("Service %s is excluded from host %s ; "
+                                     "removing this servicedependency as it's unusuable."
+                                     % (s_name, hst_name))
+                    to_del.append(sd)
+                    continue
                 sd.service_description = s
 
-            except AttributeError, exp:
-                logger.error("[servicedependency] fail to linkify by service %s: %s" % (sd, exp))
+            except AttributeError as err:
+                logger.error("[servicedependency] fail to linkify by service %s: %s", sd, err)
+                to_del.append(sd)
+
+        for sd in to_del:
+            self.remove_item(sd)
 
     # We just search for each srvdep the id of the srv
     # and replace the name by the id
@@ -233,28 +269,20 @@ class Servicedependencies(Items):
                 tp = timeperiods.find_by_name(tp_name)
                 sd.dependency_period = tp
             except AttributeError, exp:
-                logger.error("[servicedependency] fail to linkify by timeperiods: %s" % exp)
+                logger.error("[servicedependency] fail to linkify by timeperiods: %s", exp)
 
     # We backport service dep to service. So SD is not need anymore
     def linkify_s_by_sd(self):
         for sd in self:
-            if sd.is_tpl():
-                continue
             dsc = sd.dependent_service_description
             sdval = sd.service_description
             if dsc is not None and sdval is not None:
                 dp = getattr(sd, 'dependency_period', None)
-                dsc.add_service_act_dependency(sdval, sd.notification_failure_criteria, dp, sd.inherits_parent)
-                dsc.add_service_chk_dependency(sdval, sd.execution_failure_criteria, dp, sd.inherits_parent)
+                dsc.add_service_act_dependency(sdval, sd.notification_failure_criteria,
+                                               dp, sd.inherits_parent)
+                dsc.add_service_chk_dependency(sdval, sd.execution_failure_criteria,
+                                               dp, sd.inherits_parent)
 
-    # Apply inheritance for all properties
-    def apply_inheritance(self, hosts):
-        # We check for all Host properties if the host has it
-        # if not, it check all host templates for a value
-        for prop in Servicedependency.properties:
-            self.apply_partial_inheritance(prop)
-
-        # Then implicit inheritance
-        # self.apply_implicit_inheritance(hosts)
-        for s in self:
-            s.get_customs_properties_by_inheritance(self)
+    def is_correct(self):
+        r = super(Servicedependencies, self).is_correct()
+        return r and self.no_loop_in_parents("service_description", "dependent_service_description")
