@@ -2,7 +2,7 @@
 
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2009-2012:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #    Gregory Starck, g.starck@gmail.com
@@ -40,11 +40,13 @@ class Serviceescalation(Item):
         'service_description':   StringProp(),
         'first_notification':    IntegerProp(),
         'last_notification':     IntegerProp(),
-        'notification_interval': IntegerProp(default='30'), # like Nagios value
+        'notification_interval': IntegerProp(default=30),  # like Nagios value
         'escalation_period':     StringProp(default=''),
-        'escalation_options':    ListProp(default='d,u,r,w,c'),
+        'escalation_options':    ListProp(default=['d', 'u', 'r', 'w', 'c'], split_on_coma=True),
         'contacts':              StringProp(),
         'contact_groups':        StringProp(),
+        'first_notification_time': IntegerProp(),
+        'last_notification_time': IntegerProp(),
     })
 
     # For debugging purpose only (nice name)
@@ -66,6 +68,6 @@ class Serviceescalations(Items):
             for prop in properties:
                 if hasattr(es, prop):
                     creation_dict[prop] = getattr(es, prop)
-            #print "Creation an escalation with:", creation_dict
+            # print "Creation an escalation with:", creation_dict
             s = Escalation(creation_dict)
             escalations.add_escalation(s)
