@@ -2,7 +2,7 @@
 
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2009-2012:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #    Gregory Starck, g.starck@gmail.com
@@ -87,7 +87,6 @@
 
 import time
 import re
-import string
 
 from item import Item, Items
 
@@ -97,7 +96,7 @@ from shinken.daterange import MonthDateDaterange, WeekDayDaterange
 from shinken.daterange import MonthDayDaterange
 from shinken.brok import Brok
 from shinken.property import IntegerProp, StringProp, ListProp, BoolProp
-from shinken.log import logger, console_logger
+from shinken.log import logger, naglog_result
 
 
 class Timeperiod(Item):
@@ -108,13 +107,13 @@ class Timeperiod(Item):
     properties.update({
         'timeperiod_name':  StringProp(fill_brok=['full_status']),
         'alias':            StringProp(default='', fill_brok=['full_status']),
-        'use':              StringProp(default=''),
-        'register':         IntegerProp(default='1'),
+        'use':              StringProp(default=None),
+        'register':         IntegerProp(default=1),
 
         # These are needed if a broker module calls methods on timeperiod objects
         'dateranges':       ListProp(fill_brok=['full_status'], default=[]),
         'exclude':          ListProp(fill_brok=['full_status'], default=[]),
-        'is_active':        BoolProp(default='0')
+        'is_active':        BoolProp(default=False)
     })
     running_properties = Item.running_properties.copy()
 
@@ -136,8 +135,12 @@ class Timeperiod(Item):
                 else:
                     params[key] = ''
 
-            if key in ['name', 'alias', 'timeperiod_name', 'exclude', 'use', 'register', 'imported_from', 'is_active', 'dateranges']:
-                setattr(self, key, params[key])
+            if key in [
+                    'name', 'alias', 'timeperiod_name', 'exclude',
+                    'use', 'register', 'imported_from', 'is_active', 'dateranges']:
+                setattr(self, key, self.properties[key].pythonize(params[key]))
+            elif key.startswith('_'):
+                self.customs[key.upper()] = params[key]
             else:
                 self.unresolved.append(key + ' ' + params[key])
 
@@ -233,8 +236,10 @@ class Timeperiod(Item):
                 _to = 1
 
             # Now raise the log
-            console_logger.info('TIMEPERIOD TRANSITION: %s;%d;%d'
-                                % (self.get_name(), _from, _to))
+            naglog_result(
+                'info', 'TIMEPERIOD TRANSITION: %s;%d;%d'
+                % (self.get_name(), _from, _to)
+            )
 
     # clean the get_next_valid_time_from_t cache
     # The entries are a dict on t. t < now are useless
@@ -262,7 +267,8 @@ class Timeperiod(Item):
         t = int(t)
         original_t = t
 
-        #logger.debug("[%s] Check valid time for %s" % ( self.get_name(), time.asctime(time.localtime(t)))
+        # logger.debug("[%s] Check valid time for %s" %
+        #  ( self.get_name(), time.asctime(time.localtime(t)))
 
         res_from_cache = self.find_next_valid_time_from_cache(t)
         if res_from_cache is not None:
@@ -312,7 +318,7 @@ class Timeperiod(Item):
             else:
                 t = local_min
                 # No loop more than one year
-                if t > original_t + 3600*24*366 + 1:
+                if t > original_t + 3600 * 24 * 366 + 1:
                     still_loop = False
                     local_min = None
 
@@ -321,7 +327,8 @@ class Timeperiod(Item):
         return local_min
 
     def get_next_invalid_time_from_t(self, t):
-        #print '\n\n', self.get_name(), 'Search for next invalid from', time.asctime(time.localtime(t)), t
+        # print '\n\n', self.get_name(), 'Search for next invalid from',
+        # time.asctime(time.localtime(t)), t
         t = int(t)
         original_t = t
         still_loop = True
@@ -339,76 +346,84 @@ class Timeperiod(Item):
         res = None
         # Loop for all minutes...
         while still_loop:
-            #print "Invalid loop with", time.asctime(time.localtime(local_min))
+            # print "Invalid loop with", time.asctime(time.localtime(local_min))
 
             dr_mins = []
-            #val_valids = []
-            #val_inval = []
+            # val_valids = []
+            # val_inval = []
             # But maybe we can find a better solution with next invalid of standard dateranges
-            #print self.get_name(), "After valid of exclude, local_min =", time.asctime(time.localtime(local_min))
+            # print self.get_name(),
+            # "After valid of exclude, local_min =", time.asctime(time.localtime(local_min))
             for dr in self.dateranges:
-                #print self.get_name(), "Search a next invalid from DR", time.asctime(time.localtime(local_min))
-                #print dr.__dict__
+                # print self.get_name(),
+                # "Search a next invalid from DR", time.asctime(time.localtime(local_min))
+                # print dr.__dict__
                 m = dr.get_next_invalid_time_from_t(local_min)
 
-                #print self.get_name(), "Dr", dr.__dict__,  "give me next invalid", time.asctime(time.localtime(m))
+                # print self.get_name(), "Dr", dr.__dict__,
+                # "give me next invalid", time.asctime(time.localtime(m))
                 if m is not None:
                     # But maybe it's invalid for this dr, but valid for other ones.
-                    #if not self.is_time_valid(m):
+                    # if not self.is_time_valid(m):
                     #     print "Final: Got a next invalid at", time.asctime(time.localtime(m))
                     dr_mins.append(m)
-                    #if not self.is_time_valid(m):
+                    # if not self.is_time_valid(m):
                     #    val_inval.append(m)
-                    #else:
+                    # else:
                     #    val_valids.append(m)
                     #    print "Add a m", time.asctime(time.localtime(m))
-                    #else:
+                    # else:
                     #     print dr.__dict__
                     #     print "FUCK bad result\n\n\n"
-            #print "Inval"
-            #for v in val_inval:
+            # print "Inval"
+            # for v in val_inval:
             #    print "\t", time.asctime(time.localtime(v))
-            #print "Valid"
-            #for v in val_valids:
+            # print "Valid"
+            # for v in val_valids:
             #    print "\t", time.asctime(time.localtime(v))
 
             if dr_mins != []:
                 local_min = min(dr_mins)
                 # Take the minimum valid as lower for next search
-                #local_min_valid = 0
-                #if val_valids != []:
+                # local_min_valid = 0
+                # if val_valids != []:
                 #    local_min_valid = min(val_valids)
-                #if local_min_valid != 0:
+                # if local_min_valid != 0:
                 #    local_min = local_min_valid
-                #else:
+                # else:
                 #    local_min = min(dr_mins)
-                #print "UPDATE After dr: found invalid local min:", time.asctime(time.localtime(local_min)), "is valid", self.is_time_valid(local_min)
+                # print "UPDATE After dr: found invalid local min:",
+                #  time.asctime(time.localtime(local_min)),
+                #  "is valid", self.is_time_valid(local_min)
 
-            #print self.get_name(), 'Invalid: local min', local_min #time.asctime(time.localtime(local_min))
+            # print self.get_name(),
+            # 'Invalid: local min', local_min #time.asctime(time.localtime(local_min))
             # We do not loop unless the local_min is not valid
             if not self.is_time_valid(local_min):
                 still_loop = False
             else:  # continue until we reach too far..., in one minute
                 # After one month, go quicker...
-                if local_min > original_t + 3600*24*30:
+                if local_min > original_t + 3600 * 24 * 30:
                     local_min += 3600
                 else:  # else search for 1min precision
                     local_min += 60
                 # after one year, stop.
-                if local_min > original_t + 3600*24*366 + 1:  # 60*24*366 + 1:
+                if local_min > original_t + 3600 * 24 * 366 + 1:  # 60*24*366 + 1:
                     still_loop = False
-            #print "Loop?", still_loop
+            # print "Loop?", still_loop
             # if we've got a real value, we check it with the exclude
             if local_min is not None:
                 # Now check if local_min is not valid
                 for tp in self.exclude:
-                    #print self.get_name(),"we check for invalid", time.asctime(time.localtime(local_min)), 'with tp', tp.name
+                    # print self.get_name(),
+                    # "we check for invalid",
+                    # time.asctime(time.localtime(local_min)), 'with tp', tp.name
                     if tp.is_time_valid(local_min):
                         still_loop = True
                         # local_min + 60
-                        local_min = tp.get_next_invalid_time_from_t(local_min+60)
+                        local_min = tp.get_next_invalid_time_from_t(local_min + 60)
                         # No loop more than one year
-                        if local_min > original_t + 60*24*366 + 1:
+                        if local_min > original_t + 60 * 24 * 366 + 1:
                             still_loop = False
                             res = None
 
@@ -417,7 +432,7 @@ class Timeperiod(Item):
                 if res is None or local_min < res:
                     res = local_min
 
-        #print "Finished Return the next invalid", time.asctime(time.localtime(local_min))
+        # print "Finished Return the next invalid", time.asctime(time.localtime(local_min))
         # Ok, we update the cache...
         self.invalid_cache[original_t] = local_min
         return local_min
@@ -430,11 +445,14 @@ class Timeperiod(Item):
     def is_correct(self):
         b = True
         for dr in self.dateranges:
-            b &= dr.is_correct()
+            d = dr.is_correct()
+            if not d:
+                logger.error("[timeperiod::%s] invalid daterange ", self.get_name())
+            b &= d
 
         # Warn about non correct entries
         for e in self.invalid_entries:
-            logger.warning("[timeperiod::%s] invalid entry '%s'" % (self.get_name(), e))
+            logger.warning("[timeperiod::%s] invalid entry '%s'", self.get_name(), e)
         return b
 
     def __str__(self):
@@ -453,140 +471,205 @@ class Timeperiod(Item):
         return s
 
     def resolve_daterange(self, dateranges, entry):
-        #print "Trying to resolve ", entry
+        # print "Trying to resolve ", entry
 
-        res = re.search('(\d{4})-(\d{2})-(\d{2}) - (\d{4})-(\d{2})-(\d{2}) / (\d+)[\s\t]*([0-9:, -]+)', entry)
+        res = re.search(
+            '(\d{4})-(\d{2})-(\d{2}) - (\d{4})-(\d{2})-(\d{2}) / (\d+)[\s\t]*([0-9:, -]+)', entry
+        )
         if res is not None:
-            #print "Good catch 1"
+            # print "Good catch 1"
             (syear, smon, smday, eyear, emon, emday, skip_interval, other) = res.groups()
-            dateranges.append(CalendarDaterange(syear, smon, smday, 0, 0, eyear, emon, emday, 0, 0, skip_interval, other))
+            dateranges.append(
+                CalendarDaterange(
+                    syear, smon, smday, 0, 0, eyear, emon,
+                    emday, 0, 0, skip_interval, other
+                )
+            )
             return
 
         res = re.search('(\d{4})-(\d{2})-(\d{2}) / (\d+)[\s\t]*([0-9:, -]+)', entry)
         if res is not None:
-            #print "Good catch 2"
+            # print "Good catch 2"
             (syear, smon, smday, skip_interval, other) = res.groups()
             eyear = syear
             emon = smon
             emday = smday
-            dateranges.append(CalendarDaterange(syear, smon, smday, 0, 0, eyear, emon, emday, 0, 0, skip_interval, other))
+            dateranges.append(
+                CalendarDaterange(syear, smon, smday, 0, 0, eyear,
+                                  emon, emday, 0, 0, skip_interval, other)
+            )
             return
 
-        res = re.search('(\d{4})-(\d{2})-(\d{2}) - (\d{4})-(\d{2})-(\d{2})[\s\t]*([0-9:, -]+)', entry)
+        res = re.search(
+            '(\d{4})-(\d{2})-(\d{2}) - (\d{4})-(\d{2})-(\d{2})[\s\t]*([0-9:, -]+)', entry
+        )
         if res is not None:
-            #print "Good catch 3"
+            # print "Good catch 3"
             (syear, smon, smday, eyear, emon, emday, other) = res.groups()
-            dateranges.append(CalendarDaterange(syear, smon, smday, 0, 0, eyear, emon, emday, 0, 0, 0, other))
+            dateranges.append(
+                CalendarDaterange(syear, smon, smday, 0, 0, eyear, emon, emday, 0, 0, 0, other)
+            )
             return
 
         res = re.search('(\d{4})-(\d{2})-(\d{2})[\s\t]*([0-9:, -]+)', entry)
         if res is not None:
-            #print "Good catch 4"
+            # print "Good catch 4"
             (syear, smon, smday, other) = res.groups()
             eyear = syear
             emon = smon
             emday = smday
-            dateranges.append(CalendarDaterange(syear, smon, smday, 0, 0, eyear, emon, emday, 0, 0, 0, other))
+            dateranges.append(
+                CalendarDaterange(syear, smon, smday, 0, 0, eyear, emon, emday, 0, 0, 0, other)
+            )
             return
 
-        res = re.search('([a-z]*) ([\d-]+) ([a-z]*) - ([a-z]*) ([\d-]+) ([a-z]*) / (\d+)[\s\t]*([0-9:, -]+)', entry)
+        res = re.search(
+            '([a-z]*) ([\d-]+) ([a-z]*) - ([a-z]*) ([\d-]+) ([a-z]*) / (\d+)[\s\t]*([0-9:, -]+)',
+            entry
+        )
         if res is not None:
-            #print "Good catch 5"
-            (swday, swday_offset, smon, ewday, ewday_offset, emon, skip_interval, other) = res.groups()
-            dateranges.append(MonthWeekDayDaterange(0, smon, 0, swday, swday_offset, 0, emon, 0, ewday, ewday_offset, skip_interval, other))
+            # print "Good catch 5"
+            (swday, swday_offset, smon, ewday,
+             ewday_offset, emon, skip_interval, other) = res.groups()
+            dateranges.append(
+                MonthWeekDayDaterange(0, smon, 0, swday, swday_offset, 0,
+                                      emon, 0, ewday, ewday_offset, skip_interval, other)
+            )
             return
 
         res = re.search('([a-z]*) ([\d-]+) - ([a-z]*) ([\d-]+) / (\d+)[\s\t]*([0-9:, -]+)', entry)
         if res is not None:
-            #print "Good catch 6"
+            # print "Good catch 6"
             (t0, smday, t1, emday, skip_interval, other) = res.groups()
             if t0 in Daterange.weekdays and t1 in Daterange.weekdays:
                 swday = t0
                 ewday = t1
                 swday_offset = smday
                 ewday_offset = emday
-                dateranges.append(WeekDayDaterange(0, 0, 0, swday, swday_offset, 0, 0, 0, ewday, ewday_offset, skip_interval, other))
+                dateranges.append(
+                    WeekDayDaterange(0, 0, 0, swday, swday_offset,
+                                     0, 0, 0, ewday, ewday_offset, skip_interval, other)
+                )
                 return
             elif t0 in Daterange.months and t1 in Daterange.months:
                 smon = t0
                 emon = t1
-                dateranges.append(MonthDateDaterange(0, smon, smday, 0, 0, 0, emon, emday, 0, 0, skip_interval, other))
+                dateranges.append(
+                    MonthDateDaterange(0, smon, smday, 0, 0, 0,
+                                       emon, emday, 0, 0, skip_interval, other)
+                )
                 return
             elif t0 == 'day' and t1 == 'day':
-                dateranges.append(MonthDayDaterange(0, 0, smday, 0, 0, 0, 0, emday, 0, 0, skip_interval, other))
+                dateranges.append(
+                    MonthDayDaterange(0, 0, smday, 0, 0, 0, 0,
+                                      emday, 0, 0, skip_interval, other)
+                )
                 return
 
         res = re.search('([a-z]*) ([\d-]+) - ([\d-]+) / (\d+)[\s\t]*([0-9:, -]+)', entry)
         if res is not None:
-            #print "Good catch 7"
+            # print "Good catch 7"
             (t0, smday, emday, skip_interval, other) = res.groups()
             if t0 in Daterange.weekdays:
                 swday = t0
                 swday_offset = smday
                 ewday = swday
                 ewday_offset = emday
-                dateranges.append(WeekDayDaterange(0, 0, 0, swday, swday_offset, 0, 0, 0, ewday, ewday_offset, skip_interval, other))
+                dateranges.append(
+                    WeekDayDaterange(0, 0, 0, swday, swday_offset,
+                                     0, 0, 0, ewday, ewday_offset, skip_interval, other)
+                )
                 return
             elif t0 in Daterange.months:
                 smon = t0
                 emon = smon
-                dateranges.append(MonthDateDaterange(0, smon, smday, 0, 0, 0, emon, emday, 0, 0, skip_interval, other))
+                dateranges.append(
+                    MonthDateDaterange(0, smon, smday, 0, 0, 0, emon,
+                                       emday, 0, 0, skip_interval, other)
+                )
                 return
             elif t0 == 'day':
-                dateranges.append(MonthDayDaterange(0, 0, smday, 0, 0, 0, 0, emday, 0, 0, skip_interval, other))
+                dateranges.append(
+                    MonthDayDaterange(0, 0, smday, 0, 0, 0, 0,
+                                      emday, 0, 0, skip_interval, other)
+                )
                 return
 
-        res = re.search('([a-z]*) ([\d-]+) ([a-z]*) - ([a-z]*) ([\d-]+) ([a-z]*) [\s\t]*([0-9:, -]+)', entry)
+        res = re.search(
+            '([a-z]*) ([\d-]+) ([a-z]*) - ([a-z]*) ([\d-]+) ([a-z]*) [\s\t]*([0-9:, -]+)', entry
+        )
         if res is not None:
-            #print "Good catch 8"
+            # print "Good catch 8"
             (swday, swday_offset, smon, ewday, ewday_offset, emon, other) = res.groups()
-            #print "Debug:", (swday, swday_offset, smon, ewday, ewday_offset, emon, other)
-            dateranges.append(MonthWeekDayDaterange(0, smon, 0, swday, swday_offset, 0, emon, 0, ewday, ewday_offset, 0, other))
+            # print "Debug:", (swday, swday_offset, smon, ewday, ewday_offset, emon, other)
+            dateranges.append(
+                MonthWeekDayDaterange(0, smon, 0, swday, swday_offset,
+                                      0, emon, 0, ewday, ewday_offset, 0, other)
+            )
             return
 
         res = re.search('([a-z]*) ([\d-]+) - ([\d-]+)[\s\t]*([0-9:, -]+)', entry)
         if res is not None:
-            #print "Good catch 9"
+            # print "Good catch 9"
             (t0, smday, emday, other) = res.groups()
             if t0 in Daterange.weekdays:
                 swday = t0
                 swday_offset = smday
                 ewday = swday
                 ewday_offset = emday
-                dateranges.append(WeekDayDaterange(0, 0, 0, swday, swday_offset, 0, 0, 0, ewday, ewday_offset, 0, other))
+                dateranges.append(
+                    WeekDayDaterange(
+                        0, 0, 0, swday, swday_offset, 0, 0, 0,
+                        ewday, ewday_offset, 0, other)
+                )
                 return
             elif t0 in Daterange.months:
                 smon = t0
                 emon = smon
-                dateranges.append(MonthDateDaterange(0, smon, smday, 0, 0, 0, emon, emday, 0, 0, 0, other))
+                dateranges.append(
+                    MonthDateDaterange(0, smon, smday, 0, 0, 0,
+                                       emon, emday, 0, 0, 0, other)
+                )
                 return
             elif t0 == 'day':
-                dateranges.append(MonthDayDaterange(0, 0, smday, 0, 0, 0, 0, emday, 0, 0, 0, other))
+                dateranges.append(
+                    MonthDayDaterange(0, 0, smday, 0, 0, 0, 0,
+                                      emday, 0, 0, 0, other)
+                )
                 return
 
         res = re.search('([a-z]*) ([\d-]+) - ([a-z]*) ([\d-]+)[\s\t]*([0-9:, -]+)', entry)
         if res is not None:
-            #print "Good catch 10"
+            # print "Good catch 10"
             (t0, smday, t1, emday, other) = res.groups()
             if t0 in Daterange.weekdays and t1 in Daterange.weekdays:
                 swday = t0
                 ewday = t1
                 swday_offset = smday
                 ewday_offset = emday
-                dateranges.append(WeekDayDaterange(0, 0, 0, swday, swday_offset, 0, 0, 0, ewday, ewday_offset, 0, other))
+                dateranges.append(
+                    WeekDayDaterange(0, 0, 0, swday, swday_offset, 0,
+                                     0, 0, ewday, ewday_offset, 0, other)
+                )
                 return
             elif t0 in Daterange.months and t1 in Daterange.months:
                 smon = t0
                 emon = t1
-                dateranges.append(MonthDateDaterange(0, smon, smday, 0, 0, 0, emon, emday, 0, 0, 0, other))
+                dateranges.append(
+                    MonthDateDaterange(0, smon, smday, 0, 0,
+                                       0, emon, emday, 0, 0, 0, other)
+                )
                 return
             elif t0 == 'day' and t1 == 'day':
-                dateranges.append(MonthDayDaterange(0, 0, smday, 0, 0, 0, 0, emday, 0, 0, 0, other))
+                dateranges.append(
+                    MonthDayDaterange(0, 0, smday, 0, 0, 0,
+                                      0, emday, 0, 0, 0, other)
+                )
                 return
 
         res = re.search('([a-z]*) ([\d-]+) ([a-z]*)[\s\t]*([0-9:, -]+)', entry)
         if res is not None:
-            #print "Good catch 11"
+            # print "Good catch 11"
             (t0, swday_offset, t1, other) = res.groups()
             if t0 in Daterange.weekdays and t1 in Daterange.months:
                 swday = t0
@@ -594,40 +677,52 @@ class Timeperiod(Item):
                 emon = smon
                 ewday = swday
                 ewday_offset = swday_offset
-                dateranges.append(MonthWeekDayDaterange(0, smon, 0, swday, swday_offset, 0, emon, 0, ewday, ewday_offset, 0, other))
+                dateranges.append(
+                    MonthWeekDayDaterange(0, smon, 0, swday, swday_offset, 0, emon,
+                                          0, ewday, ewday_offset, 0, other)
+                )
                 return
 
         res = re.search('([a-z]*) ([\d-]+)[\s\t]+([0-9:, -]+)', entry)
         if res is not None:
-            #print "Good catch 12"
+            # print "Good catch 12"
             (t0, smday, other) = res.groups()
             if t0 in Daterange.weekdays:
                 swday = t0
                 swday_offset = smday
                 ewday = swday
                 ewday_offset = swday_offset
-                dateranges.append(WeekDayDaterange(0, 0, 0, swday, swday_offset, 0, 0, 0, ewday, ewday_offset, 0, other))
+                dateranges.append(
+                    WeekDayDaterange(0, 0, 0, swday, swday_offset, 0,
+                                     0, 0, ewday, ewday_offset, 0, other)
+                )
                 return
             if t0 in Daterange.months:
                 smon = t0
                 emon = smon
                 emday = smday
-                dateranges.append(MonthDateDaterange(0, smon, smday, 0, 0, 0, emon, emday, 0, 0, 0, other))
+                dateranges.append(
+                    MonthDateDaterange(
+                        0, smon, smday, 0, 0, 0, emon, emday, 0, 0, 0, other)
+                )
                 return
             if t0 == 'day':
                 emday = smday
-                dateranges.append(MonthDayDaterange(0, 0, smday, 0, 0, 0, 0, emday, 0, 0, 0, other))
+                dateranges.append(
+                    MonthDayDaterange(0, 0, smday, 0, 0, 0,
+                                      0, emday, 0, 0, 0, other)
+                )
                 return
 
         res = re.search('([a-z]*)[\s\t]+([0-9:, -]+)', entry)
         if res is not None:
-            #print "Good catch 13"
+            # print "Good catch 13"
             (t0, other) = res.groups()
             if t0 in Daterange.weekdays:
                 day = t0
                 dateranges.append(StandardDaterange(day, other))
                 return
-        logger.info("[timeentry::%s] no match for %s" % (self.get_name(), entry))
+        logger.info("[timeentry::%s] no match for %s", self.get_name(), entry)
         self.invalid_entries.append(entry)
 
     def apply_inheritance(self):
@@ -636,28 +731,28 @@ class Timeperiod(Item):
     # create daterange from unresolved param
     def explode(self, timeperiods):
         for entry in self.unresolved:
-            #print "Revolving entry", entry
+            # print "Revolving entry", entry
             self.resolve_daterange(self.dateranges, entry)
         self.unresolved = []
 
     # Will make tp in exclude with id of the timeperiods
     def linkify(self, timeperiods):
         new_exclude = []
-        if self.has('exclude') and self.exclude != '':
-            logger.debug("[timeentry::%s] have excluded %s" % (self.get_name(), self.exclude))
-            excluded_tps = self.exclude.split(',')
-            #print "I will exclude from:", excluded_tps
+        if self.has('exclude') and self.exclude != []:
+            logger.debug("[timeentry::%s] have excluded %s", self.get_name(), self.exclude)
+            excluded_tps = self.exclude
+            # print "I will exclude from:", excluded_tps
             for tp_name in excluded_tps:
                 tp = timeperiods.find_by_name(tp_name.strip())
                 if tp is not None:
                     new_exclude.append(tp)
                 else:
-                    logger.error("[timeentry::%s] unknown %s timeperiod" % (self.get_name(), tp_name))
+                    logger.error("[timeentry::%s] unknown %s timeperiod", self.get_name(), tp_name)
         self.exclude = new_exclude
 
     def check_exclude_rec(self):
         if self.rec_tag:
-            logger.error("[timeentry::%s] is in a loop in exclude parameter" % self.get_name())
+            logger.error("[timeentry::%s] is in a loop in exclude parameter", self.get_name())
             return False
         self.rec_tag = True
         for tp in self.exclude:
@@ -669,22 +764,13 @@ class Timeperiod(Item):
         # Now config properties
         for prop, entry in cls.properties.items():
             # Is this property intended for broking?
-            #if 'fill_brok' in entry:
+            # if 'fill_brok' in entry:
             if brok_type in entry.fill_brok:
                 if hasattr(self, prop):
                     data[prop] = getattr(self, prop)
                 elif entry.has_default:
                     data[prop] = entry.default
 
-    # Get a brok with initial status
-    def get_initial_status_brok(self):
-        cls = self.__class__
-        my_type = cls.my_type
-        data = {'id': self.id}
-
-        self.fill_data_brok_from(data, 'full_status')
-        b = Brok('initial_' + my_type + '_status', data)
-        return b
 
 
 class Timeperiods(Items):
@@ -705,7 +791,7 @@ class Timeperiods(Items):
         # The only interesting property to inherit is exclude
         self.apply_partial_inheritance('exclude')
         for i in self:
-            i.get_customs_properties_by_inheritance(self)
+            i.get_customs_properties_by_inheritance(0)
 
         # And now apply inheritance for unresolved properties
         # like the dateranges in fact
@@ -777,18 +863,18 @@ if __name__ == '__main__':
         t = Timeperiod()
         t.timeperiod_name = ''
         t.resolve_daterange(t.dateranges, entry)
-        #t.exclude = []
-        #t.resolve_daterange(t.exclude, 'monday 00:00-19:00')
-        #t.check_valid_for_today()
+        # t.exclude = []
+        # t.resolve_daterange(t.exclude, 'monday 00:00-19:00')
+        # t.check_valid_for_today()
         now = time.time()
-        #print "Is valid NOW?", t.is_time_valid(now)
-        t_next = t.get_next_valid_time_from_t(now + 5*60)
+        # print "Is valid NOW?", t.is_time_valid(now)
+        t_next = t.get_next_valid_time_from_t(now + 5 * 60)
         if t_next is not None:
             print "Get next valid for now + 5 min ==>", time.asctime(time.localtime(t_next)), "<=="
         else:
             print "===> No future time!!!"
-        #print "End date:", t.get_end_time()
-        #print "Next valid", time.asctime(time.localtime(t.get_next_valid_time()))
+        # print "End date:", t.get_end_time()
+        # print "Next valid", time.asctime(time.localtime(t.get_next_valid_time()))
         print str(t) + '\n\n'
 
     print "*************************************************************"
