@@ -1,8 +1,7 @@
 #!/usr/bin/env python
-
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2009-2012:
+# Copyright (C) 2009-2014:
 #     Gabes Jean, naparuba@gmail.com
 #     Gerhard Lausser, Gerhard.Lausser@consol.de
 #     Gregory Starck, g.starck@gmail.com
@@ -54,15 +53,12 @@ else:
 import os
 import copy
 import time
-import sys
 import cPickle
 import traceback
-import socket
 import zlib
 import base64
 import threading
 
-from shinken.http_daemon import HTTPDaemon
 from shinken.http_client import HTTPClient, HTTPExceptions
 
 from shinken.message import Message
@@ -70,7 +66,7 @@ from shinken.worker import Worker
 from shinken.load import Load
 from shinken.daemon import Daemon, Interface
 from shinken.log import logger
-
+from shinken.stats import statsmgr
 
 
 # Class to tell that we are facing a non worker module
@@ -83,7 +79,7 @@ class NotWorkerMod(Exception):
 # It gives us our conf
 class IForArbiter(Interface):
 
-    doc = 'Remove a scheduler connexion (internal)'
+    doc = 'Remove a scheduler connection (internal)'
     # Arbiter ask us to do not manage a scheduler_id anymore
     # I do it and don't ask why
     def remove_from_conf(self, sched_id):
@@ -92,17 +88,17 @@ class IForArbiter(Interface):
         except KeyError:
             pass
     remove_from_conf.doc = doc
-    
-    
+
+
     doc = 'Return the managed configuration ids (internal)'
     # Arbiter ask me which sched_id I manage, If it is not ok with it
     # It will ask me to remove one or more sched_id
     def what_i_managed(self):
-        logger.debug("The arbiter asked me what I manage. It's %s" % self.app.what_i_managed())
+        logger.debug("The arbiter asked me what I manage. It's %s", self.app.what_i_managed())
         return self.app.what_i_managed()
     what_i_managed.need_lock = False
     what_i_managed.doc = doc
-    
+
     doc = 'Ask the daemon to drop its configuration and wait for a new one'
     # Call by arbiter if it thinks we are running but we must do not (like
     # if I was a spare that take a conf but the master returns, I must die
@@ -128,8 +124,7 @@ class IForArbiter(Interface):
     # We are using a Lock just for NOT lock this call from the arbiter :)
     push_broks.need_lock = False
     push_broks.doc = doc
-    
-    
+
     doc = 'Get the external commands from the daemon (internal)'
     # The arbiter ask us our external commands in queue
     # Same than push_broks, we will not using Global lock here,
@@ -142,9 +137,9 @@ class IForArbiter(Interface):
     get_external_commands.need_lock = False
     get_external_commands.doc = doc
 
-    
+
     doc = 'Does the daemon got configuration (receiver)'
-    ### NB: only useful for receiver
+    # NB: only useful for receiver
     def got_conf(self):
         return self.app.cur_conf is not None
     got_conf.need_lock = False
@@ -164,7 +159,7 @@ class ISchedulers(Interface):
     If we are passive, they connect to this and send/get actions
 
     """
-    
+
     doc = 'Push new actions to the scheduler (internal)'
     # A Scheduler send me actions to do
     def push_actions(self, actions, sched_id):
@@ -175,9 +170,9 @@ class ISchedulers(Interface):
     doc = 'Get the returns of the actions (internal)'
     # A scheduler ask us the action return value
     def get_returns(self, sched_id):
-        #print "A scheduler ask me the returns", sched_id
+        # print "A scheduler ask me the returns", sched_id
         ret = self.app.get_return_for_passive(int(sched_id))
-        #print "Send mack", len(ret), "returns"
+        # print "Send mack", len(ret), "returns"
         return cPickle.dumps(ret)
     get_returns.doc = doc
 
@@ -198,7 +193,7 @@ class IBroks(Interface):
 
 
 class IStats(Interface):
-    """ 
+    """
     Interface for various stats about poller/reactionner activity
     """
 
@@ -206,7 +201,7 @@ class IStats(Interface):
     def get_raw_stats(self):
         app = self.app
         res = {}
-        
+
         for sched_id in app.schedulers:
             sched = app.schedulers[sched_id]
             lst = []
@@ -214,11 +209,12 @@ class IStats(Interface):
             for mod in app.q_by_mod:
                 # In workers we've got actions send to queue - queue size
                 for (i, q) in app.q_by_mod[mod].items():
-                    lst.append( {'scheduler_name' : sched['name'],
-                                 'module' : mod,
-                                 'queue_number' : i,
-                                 'queue_size' :q.qsize(),
-                                 'return_queue_len' : app.get_returns_queue_len() } )
+                    lst.append({
+                        'scheduler_name': sched['name'],
+                        'module': mod,
+                        'queue_number': i,
+                        'queue_size': q.qsize(),
+                        'return_queue_len': app.get_returns_queue_len()})
         return res
     get_raw_stats.doc = doc
 
@@ -229,8 +225,8 @@ class BaseSatellite(Daemon):
     """Please Add a Docstring to describe the class here"""
 
     def __init__(self, name, config_file, is_daemon, do_replace, debug, debug_file):
-        super(BaseSatellite, self).__init__(name, config_file, is_daemon, \
-                                                do_replace, debug, debug_file)
+        super(BaseSatellite, self).__init__(name, config_file, is_daemon,
+                                            do_replace, debug, debug_file)
         # Ours schedulers
         self.schedulers = {}
 
@@ -254,7 +250,7 @@ class BaseSatellite(Daemon):
 
     def do_stop(self):
         if self.http_daemon and self.interface:
-            logger.info("[%s] Stopping all network connections" % self.name)
+            logger.info("[%s] Stopping all network connections", self.name)
             self.http_daemon.unregister(self.interface)
         super(BaseSatellite, self).do_stop()
 
@@ -305,9 +301,16 @@ class Satellite(BaseSatellite):
         self.q_by_mod = {}
 
 
-    
-    # Initialize or re-initialize connection with scheduler """
+    # Wrapper function for the true con init
     def pynag_con_init(self, id):
+        _t = time.time()
+        r = self.do_pynag_con_init(id)
+        statsmgr.incr('con-init.scheduler', time.time() - _t)
+        return r
+
+
+    # Initialize or re-initialize connection with scheduler """
+    def do_pynag_con_init(self, id):
         sched = self.schedulers[id]
 
         # If sched is not active, I do not try to init
@@ -318,41 +321,49 @@ class Satellite(BaseSatellite):
         sname = sched['name']
         uri = sched['uri']
         running_id = sched['running_id']
-        logger.info("[%s] Init connection with %s at %s" % (self.name, sname, uri))
+        timeout = sched['timeout']
+        data_timeout = sched['data_timeout']
+        logger.info("[%s] Init connection with %s at %s (%ss,%ss)",
+                    self.name, sname, uri, timeout, data_timeout)
 
         try:
-            sch_con = sched['con'] = HTTPClient(uri=uri, strong_ssl=sched['hard_ssl_name_check'])
+            sch_con = sched['con'] = HTTPClient(
+                uri=uri, strong_ssl=sched['hard_ssl_name_check'],
+                timeout=timeout, data_timeout=data_timeout)
         except HTTPExceptions, exp:
-            logger.warning("[%s] Scheduler %s is not initialized or has network problem: %s" % (self.name, sname, str(exp)))
+            logger.warning("[%s] Scheduler %s is not initialized or has network problem: %s",
+                           self.name, sname, str(exp))
             sched['con'] = None
             return
 
-        # timeout of 120 s
+        # timeout of 3s by default (short one)
         # and get the running id
         try:
             new_run_id = sch_con.get('get_running_id')
             new_run_id = float(new_run_id)
         except (HTTPExceptions, cPickle.PicklingError, KeyError), exp:
-            logger.warning("[%s] Scheduler %s is not initialized or has network problem: %s" % (self.name, sname, str(exp)))
+            logger.warning("[%s] Scheduler %s is not initialized or has network problem: %s",
+                           self.name, sname, str(exp))
             sched['con'] = None
             return
 
         # The schedulers have been restarted: it has a new run_id.
         # So we clear all verifs, they are obsolete now.
         if sched['running_id'] != 0 and new_run_id != running_id:
-            logger.info("[%s] The running id of the scheduler %s changed, we must clear its actions"
-                        % (self.name, sname))
+            logger.info("[%s] The running id of the scheduler %s changed, "
+                        "we must clear its actions",
+                        self.name, sname)
             sched['wait_homerun'].clear()
         sched['running_id'] = new_run_id
-        logger.info("[%s] Connection OK with scheduler %s" % (self.name, sname))
+        logger.info("[%s] Connection OK with scheduler %s", self.name, sname)
 
 
     # Manage action returned from Workers
     # We just put them into the corresponding sched
     # and we clean unused properties like sched_id
     def manage_action_return(self, action):
-       # Maybe our workers end us something else than an action
-       # if so, just add this in other queues and return
+        # Maybe our workers end us something else than an action
+        # if so, just add this in other queues and return
         cls_type = action.__class__.my_type
         if cls_type not in ['check', 'notification', 'eventhandler']:
             self.add(action)
@@ -378,16 +389,24 @@ class Satellite(BaseSatellite):
         # We tag it as "return wanted", and move it in the wait return queue
         # Stop, if it is "timeout" we need this information later
         # in the scheduler
-        #action.status = 'waitforhomerun'
+        # action.status = 'waitforhomerun'
         try:
             self.schedulers[sched_id]['wait_homerun'][action.get_id()] = action
         except KeyError:
             pass
 
+
+    # Wrapper function for stats
+    def manage_returns(self):
+        _t = time.time()
+        r = self.do_manage_returns()
+        statsmgr.incr('core.manage-returns', time.time() - _t)
+        return r
+
+
     # Return the chk to scheduler and clean them
     # REF: doc/shinken-action-queues.png (6)
-    def manage_returns(self):
-        #return
+    def do_manage_returns(self):
         # For all schedulers, we check for waitforhomerun
         # and we send back results
         for sched_id in self.schedulers:
@@ -402,17 +421,16 @@ class Satellite(BaseSatellite):
                 try:
                     con = sched['con']
                     if con is not None:  # None = not initialized
-                        send_ok = con.post('put_results', {'results':ret})
-
-                # Not connected or sched is gone
+                        send_ok = con.post('put_results', {'results': ret})
+                        # Not connected or sched is gone
                 except (HTTPExceptions, KeyError), exp:
-                    logger.error('manage_returns exception:: %s,%s ' % (type(exp), str(exp)))
+                    logger.error('manage_returns exception:: %s,%s ', type(exp), str(exp))
                     self.pynag_con_init(sched_id)
                     return
                 except AttributeError, exp:  # the scheduler must  not be initialized
-                    logger.error('manage_returns exception:: %s,%s ' % (type(exp), str(exp)))
+                    logger.error('manage_returns exception:: %s,%s ', type(exp), str(exp))
                 except Exception, exp:
-                    logger.error("A satellite raised an unknown exception: %s (%s)" % (exp, type(exp)))
+                    logger.error("A satellite raised an unknown exception: %s (%s)", exp, type(exp))
                     raise
 
             # We clean ONLY if the send is OK
@@ -422,16 +440,17 @@ class Satellite(BaseSatellite):
                 self.pynag_con_init(sched_id)
                 logger.warning("Sent failed!")
 
+
     # Get all returning actions for a call from a
     # scheduler
     def get_return_for_passive(self, sched_id):
         # I do not know this scheduler?
         if sched_id not in self.schedulers:
-            logger.debug("I do not know this scheduler: %s" % sched_id)
+            logger.debug("I do not know this scheduler: %s", sched_id)
             return []
 
         sched = self.schedulers[sched_id]
-        logger.debug("Preparing to return %s" % str(sched['wait_homerun'].values()))
+        logger.debug("Preparing to return %s", str(sched['wait_homerun'].values()))
 
         # prepare our return
         ret = copy.copy(sched['wait_homerun'].values())
@@ -441,6 +460,7 @@ class Satellite(BaseSatellite):
 
         return ret
 
+
     # Create and launch a new worker, and put it into self.workers
     # It can be mortal or not
     def create_and_launch_worker(self, module_name='fork', mortal=True):
@@ -457,7 +477,7 @@ class Satellite(BaseSatellite):
             if exp.errno == 38 and os.name == 'posix':
                 logger.critical("Got an exception (%s). If you are under Linux, "
                                 "please check that your /dev/shm directory exists and"
-                                " is read-write." % (str(exp)))
+                                " is read-write.", str(exp))
             raise
 
         # If we are in the fork module, we do not specify a target
@@ -475,23 +495,25 @@ class Satellite(BaseSatellite):
                 return
         # We want to give to the Worker the name of the daemon (poller or reactionner)
         cls_name = self.__class__.__name__.lower()
-        w = Worker(1, q, self.returns_queue, self.processes_by_worker, \
-                   mortal=mortal, max_plugins_output_length=self.max_plugins_output_length, target=target, loaded_into=cls_name, http_daemon=self.http_daemon)
+        w = Worker(1, q, self.returns_queue, self.processes_by_worker,
+                   mortal=mortal, max_plugins_output_length=self.max_plugins_output_length,
+                   target=target, loaded_into=cls_name, http_daemon=self.http_daemon)
         w.module_name = module_name
         # save this worker
         self.workers[w.id] = w
 
         # And save the Queue of this worker, with key = worker id
         self.q_by_mod[module_name][w.id] = q
-        logger.info("[%s] Allocating new %s Worker: %s" % (self.name, module_name, w.id))
+        logger.info("[%s] Allocating new %s Worker: %s", self.name, module_name, w.id)
 
         # Ok, all is good. Start it!
         w.start()
 
+
     # The main stop of this daemon. Stop all workers
     # modules and sockets
     def do_stop(self):
-        logger.info("[%s] Stopping all workers" % (self.name))
+        logger.info("[%s] Stopping all workers", self.name)
         for w in self.workers.values():
             try:
                 w.terminate()
@@ -499,7 +521,7 @@ class Satellite(BaseSatellite):
             # A already dead worker or in a worker
             except (AttributeError, AssertionError):
                 pass
-        # Close the pyro server socket if it was opened
+        # Close the server socket if it was opened
         if self.http_daemon:
             if self.brok_interface:
                 self.http_daemon.unregister(self.brok_interface)
@@ -509,7 +531,6 @@ class Satellite(BaseSatellite):
         super(Satellite, self).do_stop()
 
 
-
     # A simple function to add objects in self
     # like broks in self.broks, etc
     # TODO: better tag ID?
@@ -521,7 +542,7 @@ class Satellite(BaseSatellite):
             self.broks[elt.id] = elt
             return
         elif cls_type == 'externalcommand':
-            logger.debug("Enqueuing an external command '%s'" % str(elt.__dict__))
+            logger.debug("Enqueuing an external command '%s'", str(elt.__dict__))
             with self.external_commands_lock:
                 self.external_commands.append(elt)
 
@@ -552,7 +573,7 @@ class Satellite(BaseSatellite):
             # good: we can think that we have a worker and it's not True
             # So we del it
             if not w.is_alive():
-                logger.warning("[%s] The worker %s goes down unexpectedly!" % (self.name, w.id))
+                logger.warning("[%s] The worker %s goes down unexpectedly!", self.name, w.id)
                 # Terminate immediately
                 w.terminate()
                 w.join(timeout=1)
@@ -577,17 +598,18 @@ class Satellite(BaseSatellite):
             # So now we can really forgot it
             del self.workers[id]
 
+        
 
     # Here we create new workers if the queue load (len of verifs) is too long
     def adjust_worker_number_by_load(self):
         to_del = []
         logger.debug("[%s] Trying to adjust worker number."
-                     " Actual number : %d, min per module : %d, max per module : %d"
-                     % (self.name, len(self.workers), self.min_workers, self.max_workers))
+                     " Actual number : %d, min per module : %d, max per module : %d",
+                     self.name, len(self.workers), self.min_workers, self.max_workers)
 
         # I want at least min_workers by module then if I can, I add worker for load balancing
         for mod in self.q_by_mod:
-            #At least min_workers
+            # At least min_workers
             while len(self.q_by_mod[mod]) < self.min_workers:
                 try:
                     self.create_and_launch_worker(module_name=mod)
@@ -613,10 +635,11 @@ class Satellite(BaseSatellite):
 
         for mod in to_del:
             logger.debug("[%s] The module %s is not a worker one, "
-                         "I remove it from the worker list" % (self.name, mod))
+                         "I remove it from the worker list", self.name, mod)
             del self.q_by_mod[mod]
         # TODO: if len(workers) > 2*wish, maybe we can kill a worker?
 
+        
     # Get the Queue() from an action by looking at which module
     # it wants with a round robin way to scale the load between
     # workers
@@ -660,12 +683,17 @@ class Satellite(BaseSatellite):
             q.put(msg)
 
 
+    # Wrapper function for the real function
+    def get_new_actions(self):
+        _t = time.time()
+        self.do_get_new_actions()
+        statsmgr.incr('core.get-new-actions', time.time() - _t)
+
+
     # We get new actions from schedulers, we create a Message and we
     # put it in the s queue (from master to slave)
     # REF: doc/shinken-action-queues.png (1)
-    def get_new_actions(self):
-        #now = time.time()  #Unused
-
+    def do_get_new_actions(self):
         # Here are the differences between a
         # poller and a reactionner:
         # Poller will only do checks,
@@ -686,20 +714,22 @@ class Satellite(BaseSatellite):
                 except KeyError:
                     con = None
                 if con is not None:  # None = not initialized
-                    #pyro.set_timeout(con, 120)
                     # OK, go for it :)
                     # Before ask a call that can be long, do a simple ping to be sure it is alive
                     con.get('ping')
-                    tmp = con.get('get_checks', {'do_checks':do_checks, 'do_actions':do_actions,
-                                                          'poller_tags':self.poller_tags,
-                                                          'reactionner_tags':self.reactionner_tags,
-                                                          'worker_name':self.name,
-                                                          'module_types':self.q_by_mod.keys()}, wait='long')
+                    tmp = con.get('get_checks', {
+                        'do_checks': do_checks, 'do_actions': do_actions,
+                        'poller_tags': self.poller_tags,
+                        'reactionner_tags': self.reactionner_tags,
+                        'worker_name': self.name,
+                        'module_types': self.q_by_mod.keys()
+                    },
+                        wait='long')
                     # Explicit pickle load
                     tmp = base64.b64decode(tmp)
                     tmp = zlib.decompress(tmp)
                     tmp = cPickle.loads(str(tmp))
-                    logger.debug("Ask actions to %d, got %d" % (sched_id, len(tmp)))
+                    logger.debug("Ask actions to %d, got %d", sched_id, len(tmp))
                     # We 'tag' them with sched_id and put into queue for workers
                     # REF: doc/shinken-action-queues.png (2)
                     self.add_actions(tmp, sched_id)
@@ -708,39 +738,28 @@ class Satellite(BaseSatellite):
             # Ok, con is unknown, so we create it
             # Or maybe is the connection lost, we recreate it
             except (HTTPExceptions, KeyError), exp:
-                logger.debug('get_new_actions exception:: %s,%s ' % (type(exp), str(exp)))
+                logger.debug('get_new_actions exception:: %s,%s ', type(exp), str(exp))
                 self.pynag_con_init(sched_id)
             # scheduler must not be initialized
             # or scheduler must not have checks
             except AttributeError, exp:
-                logger.debug('get_new_actions exception:: %s,%s ' % (type(exp), str(exp)))
+                logger.debug('get_new_actions exception:: %s,%s ', type(exp), str(exp))
             # What the F**k? We do not know what happened,
             # log the error message if possible.
             except Exception, exp:
-                logger.error("A satellite raised an unknown exception: %s (%s)" % (exp, type(exp)))
+                logger.error("A satellite raised an unknown exception: %s (%s)", exp, type(exp))
                 raise
 
+
     # In android we got a Queue, and a manager list for others
     def get_returns_queue_len(self):
         return self.returns_queue.qsize()
 
+
     # In android we got a Queue, and a manager list for others
     def get_returns_queue_item(self):
         return self.returns_queue.get()
 
-    # Get 'objects' from external modules
-    # from now nobody use it, but it can be useful
-    # for a module like livestatus to raise external
-    # commands for example
-    def get_objects_from_from_queues(self):
-        for f in self.modules_manager.get_external_from_queues():
-            full_queue = True
-            while full_queue:
-                try:
-                    o = f.get(block=False)
-                    self.add(o)
-                except Empty:
-                    full_queue = False
 
     # An arbiter ask us to wait a new conf, so we must clean
     # all the mess we did, and close modules too
@@ -798,9 +817,11 @@ class Satellite(BaseSatellite):
             for mod in self.q_by_mod:
                 # In workers we've got actions send to queue - queue size
                 for (i, q) in self.q_by_mod[mod].items():
-                    logger.debug("[%d][%s][%s] Stats: Workers:%d (Queued:%d TotalReturnWait:%d)" %
-                                (sched_id, sched['name'], mod,
-                                 i, q.qsize(), self.get_returns_queue_len()))
+                    logger.debug("[%d][%s][%s] Stats: Workers:%d (Queued:%d TotalReturnWait:%d)",
+                                 sched_id, sched['name'], mod,
+                                 i, q.qsize(), self.get_returns_queue_len())
+                    # also update the stats module
+                    statsmgr.incr('core.worker-%s.queue-size' % mod, q.qsize())
 
         # Before return or get new actions, see how we manage
         # old ones: are they still in queue (s)? If True, we
@@ -813,20 +834,22 @@ class Satellite(BaseSatellite):
         if total_q != 0 and wait_ratio < 2 * self.polling_interval:
             logger.debug("I decide to up wait ratio")
             self.wait_ratio.update_load(wait_ratio * 2)
-            #self.wait_ratio.update_load(self.polling_interval)
+            # self.wait_ratio.update_load(self.polling_interval)
         else:
             # Go to self.polling_interval on normal run, if wait_ratio
             # was >2*self.polling_interval,
             # it make it come near 2 because if < 2, go up :)
             self.wait_ratio.update_load(self.polling_interval)
         wait_ratio = self.wait_ratio.get_load()
-        logger.debug("Wait ratio: %f" % wait_ratio)
+        logger.debug("Wait ratio: %f", wait_ratio)
+        statsmgr.incr('core.wait-ratio', wait_ratio)
 
         # We can wait more than 1s if needed,
         # no more than 5s, but no less than 1
         timeout = self.timeout * wait_ratio
         timeout = max(self.polling_interval, timeout)
         self.timeout = min(5 * self.polling_interval, timeout)
+        statsmgr.incr('core.timeout', wait_ratio)
 
         # Maybe we do not have enough workers, we check for it
         # and launch the new ones if needed
@@ -837,6 +860,7 @@ class Satellite(BaseSatellite):
         while self.get_returns_queue_len() != 0:
             self.manage_action_return(self.get_returns_queue_item())
 
+
         # If we are passive, we do not initiate the check getting
         # and return
         if not self.passive:
@@ -853,15 +877,15 @@ class Satellite(BaseSatellite):
         # Say to modules it's a new tick :)
         self.hook_point('tick')
 
+
     # Do this satellite (poller or reactionner) post "daemonize" init:
     # we must register our interfaces for 3 possible callers: arbiter,
     # schedulers or brokers.
     def do_post_daemon_init(self):
-
         # And we register them
-        self.uri2 = self.http_daemon.register(self.interface)#, "ForArbiter")
-        self.uri3 = self.http_daemon.register(self.brok_interface)#, "Broks")
-        self.uri4 = self.http_daemon.register(self.scheduler_interface)#, "Schedulers")
+        self.uri2 = self.http_daemon.register(self.interface)
+        self.uri3 = self.http_daemon.register(self.brok_interface)
+        self.uri4 = self.http_daemon.register(self.scheduler_interface)
         self.uri5 = self.http_daemon.register(self.istats)
 
         # self.s = Queue() # Global Master -> Slave
@@ -886,7 +910,7 @@ class Satellite(BaseSatellite):
     # Setup the new received conf from arbiter
     def setup_new_conf(self):
         conf = self.new_conf
-        logger.debug("[%s] Sending us a configuration %s" % (self.name, conf))
+        logger.debug("[%s] Sending us a configuration %s", self.name, conf)
         self.new_conf = None
         self.cur_conf = conf
         g_conf = conf['global']
@@ -899,10 +923,31 @@ class Satellite(BaseSatellite):
         else:
             name = 'Unnamed satellite'
         self.name = name
+        # kernel.io part
+        self.api_key = g_conf['api_key']
+        self.secret = g_conf['secret']
+        self.http_proxy = g_conf['http_proxy']
+        # local statsd
+        self.statsd_host = g_conf['statsd_host']
+        self.statsd_port = g_conf['statsd_port']
+        self.statsd_prefix = g_conf['statsd_prefix']
+        self.statsd_enabled = g_conf['statsd_enabled']
+
+        # we got a name, we can now say it to our statsmgr
+        if 'poller_name' in g_conf:
+            statsmgr.register(self, self.name, 'poller',
+                              api_key=self.api_key, secret=self.secret, http_proxy=self.http_proxy,
+                              statsd_host=self.statsd_host, statsd_port=self.statsd_port,
+                              statsd_prefix=self.statsd_prefix, statsd_enabled=self.statsd_enabled)
+        else:
+            statsmgr.register(self, self.name, 'reactionner',
+                              api_key=self.api_key, secret=self.secret,
+                              statsd_host=self.statsd_host, statsd_port=self.statsd_port,
+                              statsd_prefix=self.statsd_prefix, statsd_enabled=self.statsd_enabled)
 
         self.passive = g_conf['passive']
         if self.passive:
-            logger.info("[%s] Passive mode enabled." % self.name)
+            logger.info("[%s] Passive mode enabled.", self.name)
 
         # If we've got something in the schedulers, we do not want it anymore
         for sched_id in conf['schedulers']:
@@ -921,8 +966,8 @@ class Satellite(BaseSatellite):
                     already_got = True
 
             if already_got:
-                logger.info("[%s] We already got the conf %d (%s)"
-                            % (self.name, sched_id, conf['schedulers'][sched_id]['name']))
+                logger.info("[%s] We already got the conf %d (%s)",
+                            self.name, sched_id, conf['schedulers'][sched_id]['name'])
                 wait_homerun = self.schedulers[sched_id]['wait_homerun']
                 actions = self.schedulers[sched_id]['actions']
 
@@ -945,6 +990,8 @@ class Satellite(BaseSatellite):
                 self.schedulers[sched_id]['actions'] = {}
             self.schedulers[sched_id]['running_id'] = 0
             self.schedulers[sched_id]['active'] = s['active']
+            self.schedulers[sched_id]['timeout'] = s['timeout']
+            self.schedulers[sched_id]['data_timeout'] = s['data_timeout']
 
             # Do not connect if we are a passive satellite
             if not self.passive and not already_got:
@@ -959,14 +1006,14 @@ class Satellite(BaseSatellite):
                 self.max_workers = cpu_count()
             except NotImplementedError:
                 self.max_workers = 4
-        logger.info("[%s] Using max workers: %s" % (self.name, self.max_workers))
+        logger.info("[%s] Using max workers: %s", self.name, self.max_workers)
         self.min_workers = g_conf['min_workers']
         if self.min_workers == 0 and not is_android:
             try:
                 self.min_workers = cpu_count()
             except NotImplementedError:
                 self.min_workers = 4
-        logger.info("[%s] Using min workers: %s" % (self.name, self.min_workers))
+        logger.info("[%s] Using min workers: %s", self.name, self.min_workers)
 
         self.processes_by_worker = g_conf['processes_by_worker']
         self.polling_interval = g_conf['polling_interval']
@@ -981,23 +1028,42 @@ class Satellite(BaseSatellite):
         # Set our giving timezone from arbiter
         use_timezone = g_conf['use_timezone']
         if use_timezone != 'NOTSET':
-            logger.info("[%s] Setting our timezone to %s" % (self.name, use_timezone))
+            logger.info("[%s] Setting our timezone to %s", self.name, use_timezone)
             os.environ['TZ'] = use_timezone
             time.tzset()
 
-        logger.info("We have our schedulers: %s" % (str(self.schedulers)))
+        logger.info("We have our schedulers: %s", str(self.schedulers))
 
         # Now manage modules
         # TODO: check how to better handle this with modules_manager..
         mods = g_conf['modules']
         for module in mods:
             # If we already got it, bypass
-            if not module.module_type in self.q_by_mod:
-                logger.debug("Add module object %s" % str(module))
+            if module.module_type not in self.q_by_mod:
+                logger.debug("Add module object %s", str(module))
                 self.modules_manager.modules.append(module)
-                logger.info("[%s] Got module: %s " % (self.name, module.module_type))
+                logger.info("[%s] Got module: %s ", self.name, module.module_type)
                 self.q_by_mod[module.module_type] = {}
 
+
+    # stats threads is asking us a main structure for stats
+    def get_stats_struct(self):
+        now = int(time.time())
+        # call the daemon one
+        res = super(Satellite, self).get_stats_struct()
+        _type = self.__class__.my_type
+        res.update({'name': self.name, 'type': _type})
+        # The receiver do nto have a passie prop
+        if hasattr(self, 'passive'):
+            res['passive'] = self.passive
+        metrics = res['metrics']
+        # metrics specific
+        metrics.append('%s.%s.external-commands.queue %d %d' % (
+            _type, self.name, len(self.external_commands), now))
+
+        return res
+
+
     def main(self):
         try:
             for line in self.get_header():
@@ -1005,6 +1071,12 @@ class Satellite(BaseSatellite):
 
             self.load_config_file()
 
+            # Setting log level
+            logger.setLevel(self.log_level)
+            # Force the debug level if the daemon is said to start with such level
+            if self.debug:
+                logger.setLevel('DEBUG')
+
             # Look if we are enabled or not. If ok, start the daemon mode
             self.look_for_early_exit()
             self.do_daemon_init_and_start()
@@ -1038,14 +1110,11 @@ class Satellite(BaseSatellite):
 
                 for mod in to_del:
                     logger.debug("The module %s is not a worker one, "
-                                 "I remove it from the worker list" % mod)
+                                 "I remove it from the worker list", mod)
                     del self.q_by_mod[mod]
 
             # Now main loop
             self.do_mainloop()
         except Exception:
-            logger.critical("I got an unrecoverable error. I have to exit")
-            logger.critical("You can log a bug ticket at "
-                            "https://github.com/naparuba/shinken/issues/new to get help")
-            logger.critical("Back trace of it: %s" % (traceback.format_exc()))
+            self.print_unrecoverable(traceback.format_exc())
             raise
