@@ -5,14 +5,20 @@
 #
 
 import sys
+from sys import __stdout__
+from functools import partial
+
 import time
 import datetime
 import os
 import string
 import re
 import random
-import unittest
 import copy
+import locale
+
+import unittest2 as unittest
+
 
 # import the shinken library from the parent directory
 import __import_shinken ; del __import_shinken
@@ -30,39 +36,94 @@ from shinken.macroresolver import MacroResolver
 from shinken.external_command import ExternalCommandManager, ExternalCommand
 from shinken.check import Check
 from shinken.message import Message
-from shinken.arbiterlink import ArbiterLink
-from shinken.schedulerlink import SchedulerLink
-from shinken.pollerlink import PollerLink
-from shinken.reactionnerlink import ReactionnerLink
-from shinken.brokerlink import BrokerLink
-from shinken.satellitelink import SatelliteLink
+from shinken.objects.arbiterlink import ArbiterLink
+from shinken.objects.schedulerlink import SchedulerLink
+from shinken.objects.pollerlink import PollerLink
+from shinken.objects.reactionnerlink import ReactionnerLink
+from shinken.objects.brokerlink import BrokerLink
+from shinken.objects.satellitelink import SatelliteLink
 from shinken.notification import Notification
 from shinken.modulesmanager import ModulesManager
 from shinken.basemodule import BaseModule
 
 from shinken.brok import Brok
+from shinken.misc.common import DICT_MODATTR
 
 from shinken.daemons.schedulerdaemon import Shinken
 from shinken.daemons.brokerdaemon import Broker
 from shinken.daemons.arbiterdaemon import Arbiter
+from shinken.daemons.receiverdaemon import Receiver
+from logging import ERROR
 
 # Modules are by default on the ../modules
 myself = os.path.abspath(__file__)
 
 global modules_dir
-modules_dir = "modules"
+modules_dir = os.environ.get('SHINKEN_MODULES_DIR', "modules")
 
-def define_modules_dir(val):
-    global modules_dir
-    modules_dir = val
 
 class __DUMMY:
     def add(self, obj):
         pass
 
 logger.load_obj(__DUMMY())
-#logger.set_level(logger.ERROR)
+logger.setLevel(ERROR)
 
+#############################################################################
+
+def guess_sys_stdout_encoding():
+    ''' Return the best guessed encoding to be used for printing on sys.stdout. '''
+    return (
+           getattr(sys.stdout, 'encoding', None)
+        or getattr(__stdout__, 'encoding', None)
+        or locale.getpreferredencoding()
+        or sys.getdefaultencoding()
+        or 'ascii'
+    )
+
+
+
+def safe_print(*args, **kw):
+    """" "print" args to sys.stdout,
+    If some of the args aren't unicode then convert them first to unicode,
+        using keyword argument 'in_encoding' if provided (else default to UTF8)
+        and replacing bad encoded bytes.
+    Write to stdout using 'out_encoding' if provided else best guessed encoding,
+        doing xmlcharrefreplace on errors.
+    """
+    in_bytes_encoding = kw.pop('in_encoding', 'UTF-8')
+    out_encoding = kw.pop('out_encoding', guess_sys_stdout_encoding())
+    if kw:
+        raise ValueError('unhandled named/keyword argument(s): %r' % kw)
+    #
+    make_in_data_gen = lambda: ( a if isinstance(a, unicode)
+                                else
+                            unicode(str(a), in_bytes_encoding, 'replace')
+                        for a in args )
+
+    possible_codings = ( out_encoding, )
+    if out_encoding != 'ascii':
+        possible_codings += ( 'ascii', )
+
+    for coding in possible_codings:
+        data = u' '.join(make_in_data_gen()).encode(coding, 'xmlcharrefreplace')
+        try:
+            sys.stdout.write(data)
+            break
+        except UnicodeError as err:
+            # there might still have some problem with the underlying sys.stdout.
+            # it might be a StringIO whose content could be decoded/encoded in this same process
+            # and have encode/decode errors because we could have guessed a bad encoding with it.
+            # in such case fallback on 'ascii'
+            if coding == 'ascii':
+                raise
+            sys.stderr.write('Error on write to sys.stdout with %s encoding: err=%s\nTrying with ascii' % (
+                coding, err))
+    sys.stdout.write(b'\n')
+
+
+
+#############################################################################
 
 # We overwrite the functions time() and sleep()
 # This way we can modify sleep() so that it immediately returns although
@@ -112,41 +173,13 @@ class Pluginconf(object):
     pass
 
 
-class _Unittest2CompatMixIn:
-    """
-    Mixin for simulating methods new in unittest2 resp. Python 2.7.
 
-    Every test-case should inherit this *after* unittest.TestCase to
-    make the compatiblity-methods available if they are not defined in
-    unittest.TestCase already. Example::
-
-       class MyTestCase(unittest.TestCase, Unittest2CompatMixIn):
-           ...
-    In our case, it's better to always inherit from ShinkenTest
-
-    """
-    def assertNotIn(self, member, container, msg=None):
-       self.assertTrue(member not in container)
-
-    def assertIn(self, member, container, msg=None):
-        self.assertTrue(member in container)
-
-    def assertIsInstance(self, obj, cls, msg=None):
-        self.assertTrue(isinstance(obj, cls))
-
-    def assertRegexpMatches(self, line, pattern):
-        r = re.search(pattern, line)
-        self.assertTrue(r is not None)
-
-    def assertIs(self, obj, cmp, msg=None):
-        self.assertTrue(obj is cmp)
-
-
-class ShinkenTest(unittest.TestCase, _Unittest2CompatMixIn):
+class ShinkenTest(unittest.TestCase):
     def setUp(self):
         self.setup_with_file('etc/shinken_1r_1h_1s.cfg')
 
     def setup_with_file(self, path):
+        time_hacker.set_my_time()
         self.print_header()
         # i am arbiter-like
         self.broks = {}
@@ -160,30 +193,48 @@ class ShinkenTest(unittest.TestCase, _Unittest2CompatMixIn):
         self.conf.create_objects_for_type(raw_objects, 'arbiter')
         self.conf.create_objects_for_type(raw_objects, 'module')
         self.conf.early_arbiter_linking()
+
+        # If we got one arbiter defined here (before default) we should be in a case where
+        # the tester want to load/test a module, so we simulate an arbiter daemon
+        # and the modules loading phase. As it has its own modulesmanager, should
+        # not impact scheduler modules ones, especially we are asking for arbiter type :)
+        if len(self.conf.arbiters) == 1:
+            arbdaemon = Arbiter([''],[''], False, False, None, None)
+            # only load if the module_dir is reallyexisting, so was set explicitly
+            # in the test configuration
+            if os.path.exists(getattr(self.conf, 'modules_dir', '')):
+                arbdaemon.modules_dir = self.conf.modules_dir
+                arbdaemon.load_modules_manager()
+            
+                # we request the instances without them being *started*
+                # (for those that are concerned ("external" modules):
+                # we will *start* these instances after we have been daemonized (if requested)
+                me = None
+                for arb in self.conf.arbiters:
+                    me = arb
+                    arbdaemon.modules_manager.set_modules(arb.modules)
+                    arbdaemon.do_load_modules()
+                    arbdaemon.load_modules_configuration_objects(raw_objects)
+
         self.conf.create_objects(raw_objects)
-        self.conf.old_properties_names_to_new()
         self.conf.instance_id = 0
         self.conf.instance_name = 'test'
         # Hack push_flavor, that is set by the dispatcher
         self.conf.push_flavor = 0
         self.conf.load_triggers()
+        #import pdb;pdb.set_trace()
         self.conf.linkify_templates()
+        #import pdb;pdb.set_trace()
         self.conf.apply_inheritance()
+        #import pdb;pdb.set_trace()
         self.conf.explode()
         #print "Aconf.services has %d elements" % len(self.conf.services)
-        self.conf.create_reversed_list()
-        self.conf.remove_twins()
         self.conf.apply_implicit_inheritance()
         self.conf.fill_default()
         self.conf.remove_templates()
         self.conf.compute_hash()
         #print "conf.services has %d elements" % len(self.conf.services)
-        self.conf.create_reversed_list()
         self.conf.override_properties()
-        self.conf.pythonize()
-        count = self.conf.remove_exclusions()
-        if count > 0:
-            self.conf.create_reversed_list()
         self.conf.linkify()
         self.conf.apply_dependencies()
         self.conf.explode_global_conf()
@@ -193,6 +244,7 @@ class ShinkenTest(unittest.TestCase, _Unittest2CompatMixIn):
         self.conf.is_correct()
         if not self.conf.conf_is_correct:
             print "The conf is not correct, I stop here"
+            self.conf.dump()
             return
         self.conf.clean()
 
@@ -202,9 +254,8 @@ class ShinkenTest(unittest.TestCase, _Unittest2CompatMixIn):
         self.dispatcher = Dispatcher(self.conf, self.me)
 
         scheddaemon = Shinken(None, False, False, False, None, None)
-        self.sched = Scheduler(scheddaemon)
-
-        scheddaemon.sched = self.sched
+        self.scheddaemon = scheddaemon
+        self.sched = scheddaemon.sched
         scheddaemon.modules_dir = modules_dir
         scheddaemon.load_modules_manager()
         # Remember to clean the logs we just created before launching tests
@@ -218,6 +269,7 @@ class ShinkenTest(unittest.TestCase, _Unittest2CompatMixIn):
         e2 = ExternalCommandManager(self.conf, 'dispatcher')
         e2.load_arbiter(self)
         self.external_command_dispatcher = e2
+        self.sched.conf.accept_passive_unknown_check_results = False
 
         self.sched.schedule()
 
@@ -309,16 +361,25 @@ class ShinkenTest(unittest.TestCase, _Unittest2CompatMixIn):
 
     def show_logs(self):
         print "--- logs <<<----------------------------------"
-        for brok in sorted(self.sched.broks.values(), lambda x, y: x.id - y.id):
+        if hasattr(self, "sched"):
+            broks = self.sched.broks
+        else:
+            broks = self.broks
+        for brok in sorted(broks.values(), lambda x, y: x.id - y.id):
             if brok.type == 'log':
                 brok.prepare()
-                print "LOG:", brok.data['log']
+                safe_print("LOG: ", brok.data['log'])
+
         print "--- logs >>>----------------------------------"
 
 
     def show_actions(self):
         print "--- actions <<<----------------------------------"
-        for a in sorted(self.sched.actions.values(), lambda x, y: x.id - y.id):
+        if hasattr(self, "sched"):
+            actions = self.sched.actions
+        else:
+            actions = self.actions
+        for a in sorted(actions.values(), lambda x, y: x.id - y.id):
             if a.is_a == 'notification':
                 if a.ref.my_type == "host":
                     ref = "host: %s" % a.ref.get_name()
@@ -341,50 +402,91 @@ class ShinkenTest(unittest.TestCase, _Unittest2CompatMixIn):
 
 
     def count_logs(self):
-        return len([b for b in self.sched.broks.values() if b.type == 'log'])
+        if hasattr(self, "sched"):
+            broks = self.sched.broks
+        else:
+            broks = self.broks
+        return len([b for b in broks.values() if b.type == 'log'])
 
 
     def count_actions(self):
-        return len(self.sched.actions.values())
+        if hasattr(self, "sched"):
+            actions = self.sched.actions
+        else:
+            actions = self.actions
+        return len(actions.values())
 
 
     def clear_logs(self):
+        if hasattr(self, "sched"):
+            broks = self.sched.broks
+        else:
+            broks = self.broks
         id_to_del = []
-        for b in self.sched.broks.values():
+        for b in broks.values():
             if b.type == 'log':
                 id_to_del.append(b.id)
         for id in id_to_del:
-            del self.sched.broks[id]
+            del broks[id]
 
 
     def clear_actions(self):
-        self.sched.actions = {}
-
-
-    def log_match(self, index, pattern):
-        # log messages are counted 1...n, so index=1 for the first message
-        if index > self.count_logs():
-            return False
+        if hasattr(self, "sched"):
+            self.sched.actions = {}
         else:
-            regex = re.compile(pattern)
-            lognum = 1
-            for brok in sorted(self.sched.broks.values(), lambda x, y: x.id - y.id):
-                if brok.type == 'log':
-                    brok.prepare()
-                    if index == lognum:
-                        if re.search(regex, brok.data['log']):
-                            return True
-                    lognum += 1
-        return False
+            self.actions = {}
 
-    def any_log_match(self, pattern):
+
+    def assert_log_match(self, index, pattern, no_match=False):
+        # log messages are counted 1...n, so index=1 for the first message
+        if not no_match:
+            self.assertGreaterEqual(self.count_logs(), index)
         regex = re.compile(pattern)
-        for brok in sorted(self.sched.broks.values(), lambda x, y: x.id - y.id):
+        lognum = 1
+        broks = sorted(self.sched.broks.values(), key=lambda x: x.id)
+        for brok in broks:
+            if brok.type == 'log':
+                brok.prepare()
+                if index == lognum:
+                    if re.search(regex, brok.data['log']):
+                        return
+                lognum += 1
+        self.assertTrue(no_match, "%s found a matched log line in broks :\n"
+                               "index=%s pattern=%r\n"
+                               "broks_logs=[[[\n%s\n]]]" % (
+            '*HAVE*' if no_match else 'Not',
+            index, pattern, '\n'.join(
+                '\t%s=%s' % (idx, b.strip())
+                for idx, b in enumerate(
+                    (b.data['log'] for b in broks if b.type == 'log'),
+                    1)
+            )
+        ))
+
+    def _any_log_match(self, pattern, assert_not):
+        regex = re.compile(pattern)
+        broks = getattr(self, 'sched', self).broks
+        broks = sorted(broks.values(), lambda x, y: x.id - y.id)
+        for brok in broks:
             if brok.type == 'log':
                 brok.prepare()
                 if re.search(regex, brok.data['log']):
-                    return True
-        return False
+                    self.assertTrue(not assert_not,
+                                    "Found matching log line:\n"
+                                    "pattern = %r\nbrok log = %r" % (pattern, brok.data['log'])
+                    )
+                    return
+        self.assertTrue(assert_not,
+            "No matching log line found:\n"
+            "pattern = %r\n" "broks = %r" % (pattern, broks)
+        )
+
+    def assert_any_log_match(self, pattern):
+        self._any_log_match(pattern, assert_not=False)
+
+    def assert_no_log_match(self, pattern):
+        self._any_log_match(pattern, assert_not=True)
+
 
     def get_log_match(self, pattern):
         regex = re.compile(pattern)
@@ -402,7 +504,7 @@ class ShinkenTest(unittest.TestCase, _Unittest2CompatMixIn):
 
     def xtest_conf_is_correct(self):
         self.print_header()
-        self.assert_(self.conf.conf_is_correct)
+        self.assertTrue(self.conf.conf_is_correct)
 
 
 
