@@ -2,7 +2,7 @@
 
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #    Sebastien Coavoux, s.coavoux@free.fr
@@ -34,12 +34,10 @@ class TestBadServiceDependencies(ShinkenTest):
         self.setup_with_file('etc/shinken_bad_servicedependencies.cfg')
 
     def test_bad_conf(self):
-        #
-        # Config is not correct because of a wrong inexisting service in dependency
-        # in the host configuration
-        #
-        self.assert_(not self.conf.conf_is_correct)
-
+        self.assertFalse(self.conf.conf_is_correct)
+        self.assert_any_log_match("hostdependencies conf incorrect!!")
+        self.assert_any_log_match("servicedependencies conf incorrect!!")
+        self.assert_any_log_match("The host object 'fake host'  is part of a circular parent/child chain!")
 
 if __name__ == '__main__':
     unittest.main()
\ No newline at end of file
