@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -24,6 +24,7 @@
 
 import os
 import tempfile
+import shutil
 
 from shinken_test import *
 
@@ -75,6 +76,9 @@ run = 0   # We will open some ports but not close them (yes it's not good) and
 
 class template_Daemon_Bad_Start():
 
+    def setUp(self):
+        time_hacker.set_real_time()
+
     def get_login_and_group(self, p):
         try:
             p.user = get_cur_user()
@@ -101,48 +105,51 @@ class template_Daemon_Bad_Start():
         self.get_login_and_group(d)
         return d
 
+
     def test_bad_piddir(self):
         print "Testing bad pidfile ..."
         d = self.get_daemon()
         d.workdir = tempfile.mkdtemp()
-        d.pidfile = os.path.join('/DONOTEXISTS', "daemon.pid")
-        #f = open(d.pidfile, "w")
-        #f.close()
-        #os.chmod(d.pidfile, 0)
-        self.assertRaises(InvalidPidFile, d.do_daemon_init_and_start)
-        #os.unlink(d.pidfile)
-        os.rmdir(d.workdir)
+        d.pidfile = os.path.join('/proc/DONOTEXISTS', "daemon.pid")
+        prev_dir = os.getcwd()
+        self.assertRaises(InvalidPidFile, d.do_daemon_init_and_start, fake=True)
+        shutil.rmtree(d.workdir)
+        os.chdir(prev_dir)
 
     def test_bad_workdir(self):
         print("Testing bad workdir ... mypid=%d" % (os.getpid()))
         d = self.get_daemon()
-        d.workdir = '/DONOTEXISTS'
-        #os.chmod(d.workdir, 0)
-        self.assertRaises(InvalidWorkDir, d.do_daemon_init_and_start)
+        d.workdir = '/proc/DONOTEXISTS'
+        prev_dir = os.getcwd()
+        self.assertRaises(InvalidWorkDir, d.do_daemon_init_and_start, fake=True)
         d.do_stop()
-        #os.rmdir(d.workdir)
+        os.chdir(prev_dir)
 
     def test_port_not_free(self):
         print("Testing port not free ... mypid=%d" % (os.getpid()))
         d1 = self.get_daemon()
         d1.workdir = tempfile.mkdtemp()
-        d1.do_daemon_init_and_start()
-        os.unlink(d1.pidfile)  ## so that second poller will not see first started poller
+        prev_dir = os.getcwd()  # We have to remember where we are to get back after
+        d1.do_daemon_init_and_start(fake=True)
+        new_dir = os.getcwd()  # We have to remember this one also
+        os.chdir(prev_dir)
+        os.unlink(os.path.join(new_dir, d1.pidfile))  ## so that second poller will not see first started poller
         d2 = self.get_daemon()
         d2.workdir = d1.workdir
         # TODO: find a way in Pyro4 to get the port
         if hasattr(d1.http_daemon, 'port'):
             d2.port = d1.http_daemon.port
-            self.assertRaises(PortNotFree, d2.do_daemon_init_and_start)
+            self.assertRaises(PortNotFree, d2.do_daemon_init_and_start, fake=True)
             d2.do_stop()
         d1.do_stop()
         try:
             os.unlink(d1.pidfile)
-        except:
+        except Exception:
             pass
         if hasattr(d1, 'local_log'):
             os.unlink(os.path.join(d1.workdir, d1.local_log))
-        os.rmdir(d1.workdir)
+        shutil.rmtree(d1.workdir)
+        os.chdir(prev_dir)  # Back to previous dir for next test!
 
 
 class Test_Broker_Bad_Start(template_Daemon_Bad_Start, ShinkenTest):
