@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -30,14 +30,12 @@ class TestConfig(ShinkenTest):
     def setUp(self):
         self.setup_with_file('etc/shinken_bad_timeperiods.cfg')
 
-    def test_dummy(self):
-        #
-        # Config is not correct because of a wrong relative path
-        # in the main config file
-        #
+    def test_bad_timeperiod(self):
         print "Get the bad timeperiod"
         tp = self.conf.timeperiods.find_by_name("24x7")
-        self.assert_(tp.is_correct() == True)
+        self.assertEqual(True, tp.is_correct())
+        tp = self.conf.timeperiods.find_by_name("24x7_bad")
+        self.assertEqual(False, tp.is_correct())
 
 
 if __name__ == '__main__':
