@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -28,10 +28,10 @@ from shinken_test import *
 class TestBusinessRulesBadRealmConf(ShinkenTest):
 
     def setUp(self):
-        self.setup_with_file('etc/nagios_business_rules_bad_realm_conf.cfg')
+        self.setup_with_file('etc/shinken_business_rules_bad_realm_conf.cfg')
 
     def test_bad_conf(self):
-        self.assert_(not self.conf.is_correct)
+        self.assertFalse(self.conf.conf_is_correct)
 
 if __name__ == '__main__':
     unittest.main()
