@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -35,9 +35,9 @@ class TestContactgroupWitoutMembers(ShinkenTest):
     def test_contactgroup_nomember(self):
         # Look for the members of the test_contact_nomember
         cg = self.sched.conf.contactgroups.find_by_name('test_contact_nomember')
-        self.assert_(cg is not None)
+        self.assertIsNot(cg, None)
         print cg.members
-        self.assert_(cg.members == [])
+        self.assertEqual([], cg.members)
 
 
 if __name__ == '__main__':
