@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -135,34 +135,34 @@ class TestDispatcher(ShinkenTest):
 
         print "Preparing schedulers"
         scheduler1 = self.conf.schedulers.find_by_name('scheduler-all-1')
-        self.assert_(scheduler1 is not None)
+        self.assertIsNot(scheduler1, None)
         scheduler1.__class__ = GoodScheduler
         scheduler2 = self.conf.schedulers.find_by_name('scheduler-all-2')
-        self.assert_(scheduler2 is not None)
+        self.assertIsNot(scheduler2, None)
         scheduler2.__class__ = BadScheduler
 
         print "Preparing pollers"
         poller1 = self.conf.pollers.find_by_name('poller-all-1')
-        self.assert_(poller1 is not None)
+        self.assertIsNot(poller1, None)
         poller1.__class__ = GoodPoller
         poller2 = self.conf.pollers.find_by_name('poller-all-2')
-        self.assert_(poller2 is not None)
+        self.assertIsNot(poller2, None)
         poller2.__class__ = BadPoller
 
         print "Preparing reactionners"
         reactionner1 = self.conf.reactionners.find_by_name('reactionner-all-1')
-        self.assert_(reactionner1 is not None)
+        self.assertIsNot(reactionner1, None)
         reactionner1.__class__ = GoodReactionner
         reactionner2 = self.conf.reactionners.find_by_name('reactionner-all-2')
-        self.assert_(reactionner2 is not None)
+        self.assertIsNot(reactionner2, None)
         reactionner2.__class__ = BadReactionner
 
         print "Preparing brokers"
         broker1 = self.conf.brokers.find_by_name('broker-all-1')
-        self.assert_(broker1 is not None)
+        self.assertIsNot(broker1, None)
         broker1.__class__ = GoodBroker
         broker2 = self.conf.brokers.find_by_name('broker-all-2')
-        self.assert_(broker2 is not None)
+        self.assertIsNot(broker2, None)
         broker2.__class__ = BadBroker
 
         # Ping all elements. Should have 1 as OK, 2 as
@@ -170,40 +170,40 @@ class TestDispatcher(ShinkenTest):
         self.dispatcher.check_alive()
 
         # Check good values
-        self.assert_(scheduler1.alive == True)
-        self.assert_(scheduler1.attempt == 0)
-        self.assert_(scheduler1.reachable == True)
+        self.assertEqual(True, scheduler1.alive)
+        self.assertEqual(0, scheduler1.attempt)
+        self.assertEqual(True, scheduler1.reachable)
         # still alive, just unreach
-        self.assert_(scheduler2.alive == True)
-        self.assert_(scheduler2.attempt == 1)
-        self.assert_(scheduler2.reachable == False)
+        self.assertEqual(True, scheduler2.alive)
+        self.assertEqual(1, scheduler2.attempt)
+        self.assertEqual(False, scheduler2.reachable)
 
         # and others satellites too
-        self.assert_(poller1.alive == True)
-        self.assert_(poller1.attempt == 0)
-        self.assert_(poller1.reachable == True)
+        self.assertEqual(True, poller1.alive)
+        self.assertEqual(0, poller1.attempt)
+        self.assertEqual(True, poller1.reachable)
         # still alive, just unreach
-        self.assert_(poller2.alive == True)
-        self.assert_(poller2.attempt == 1)
-        self.assert_(poller2.reachable == False)
+        self.assertEqual(True, poller2.alive)
+        self.assertEqual(1, poller2.attempt)
+        self.assertEqual(False, poller2.reachable)
 
         # and others satellites too
-        self.assert_(reactionner1.alive == True)
-        self.assert_(reactionner1.attempt == 0)
-        self.assert_(reactionner1.reachable == True)
+        self.assertEqual(True, reactionner1.alive)
+        self.assertEqual(0, reactionner1.attempt)
+        self.assertEqual(True, reactionner1.reachable)
         # still alive, just unreach
-        self.assert_(reactionner2.alive == True)
-        self.assert_(reactionner2.attempt == 1)
-        self.assert_(reactionner2.reachable == False)
+        self.assertEqual(True, reactionner2.alive)
+        self.assertEqual(1, reactionner2.attempt)
+        self.assertEqual(False, reactionner2.reachable)
 
         # and others satellites too
-        self.assert_(broker1.alive == True)
-        self.assert_(broker1.attempt == 0)
-        self.assert_(broker1.reachable == True)
+        self.assertEqual(True, broker1.alive)
+        self.assertEqual(0, broker1.attempt)
+        self.assertEqual(True, broker1.reachable)
         # still alive, just unreach
-        self.assert_(broker2.alive == True)
-        self.assert_(broker2.attempt == 1)
-        self.assert_(broker2.reachable == False)
+        self.assertEqual(True, broker2.alive)
+        self.assertEqual(1, broker2.attempt)
+        self.assertEqual(False, broker2.reachable)
         ### Now add another attempt, still alive, but attemp=2/3
 
         print "CheckAlive " * 10
@@ -215,40 +215,40 @@ class TestDispatcher(ShinkenTest):
         self.dispatcher.check_alive()
 
         # Check good values
-        self.assert_(scheduler1.alive == True)
-        self.assert_(scheduler1.attempt == 0)
-        self.assert_(scheduler1.reachable == True)
+        self.assertEqual(True, scheduler1.alive)
+        self.assertEqual(0, scheduler1.attempt)
+        self.assertEqual(True, scheduler1.reachable)
         # still alive, just unreach
-        self.assert_(scheduler2.alive == True)
-        self.assert_(scheduler2.attempt == 2)
-        self.assert_(scheduler2.reachable == False)
+        self.assertEqual(True, scheduler2.alive)
+        self.assertEqual(2, scheduler2.attempt)
+        self.assertEqual(False, scheduler2.reachable)
 
         # and others satellites too
-        self.assert_(poller1.alive == True)
-        self.assert_(poller1.attempt == 0)
-        self.assert_(poller1.reachable == True)
+        self.assertEqual(True, poller1.alive)
+        self.assertEqual(0, poller1.attempt)
+        self.assertEqual(True, poller1.reachable)
         # still alive, just unreach
-        self.assert_(poller2.alive == True)
-        self.assert_(poller2.attempt == 2)
-        self.assert_(poller2.reachable == False)
+        self.assertEqual(True, poller2.alive)
+        self.assertEqual(2, poller2.attempt)
+        self.assertEqual(False, poller2.reachable)
 
         # and others satellites too
-        self.assert_(reactionner1.alive == True)
-        self.assert_(reactionner1.attempt == 0)
-        self.assert_(reactionner1.reachable == True)
+        self.assertEqual(True, reactionner1.alive)
+        self.assertEqual(0, reactionner1.attempt)
+        self.assertEqual(True, reactionner1.reachable)
         # still alive, just unreach
-        self.assert_(reactionner2.alive == True)
-        self.assert_(reactionner2.attempt == 2)
-        self.assert_(reactionner2.reachable == False)
+        self.assertEqual(True, reactionner2.alive)
+        self.assertEqual(2, reactionner2.attempt)
+        self.assertEqual(False, reactionner2.reachable)
 
         # and others satellites too
-        self.assert_(broker1.alive == True)
-        self.assert_(broker1.attempt == 0)
-        self.assert_(broker1.reachable == True)
+        self.assertEqual(True, broker1.alive)
+        self.assertEqual(0, broker1.attempt)
+        self.assertEqual(True, broker1.reachable)
         # still alive, just unreach
-        self.assert_(broker2.alive == True)
-        self.assert_(broker2.attempt == 2)
-        self.assert_(broker2.reachable == False)
+        self.assertEqual(True, broker2.alive)
+        self.assertEqual(2, broker2.attempt)
+        self.assertEqual(False, broker2.reachable)
 
         ### Now we get BAD, We go DEAD for N2!
         print "CheckAlive " * 10
@@ -259,59 +259,59 @@ class TestDispatcher(ShinkenTest):
         self.dispatcher.check_alive()
 
         # Check good values
-        self.assert_(scheduler1.alive == True)
-        self.assert_(scheduler1.attempt == 0)
-        self.assert_(scheduler1.reachable == True)
+        self.assertEqual(True, scheduler1.alive)
+        self.assertEqual(0, scheduler1.attempt)
+        self.assertEqual(True, scheduler1.reachable)
         # still alive, just unreach
-        self.assert_(scheduler2.alive == False)
-        self.assert_(scheduler2.attempt == 3)
-        self.assert_(scheduler2.reachable == False)
+        self.assertEqual(False, scheduler2.alive)
+        self.assertEqual(3, scheduler2.attempt)
+        self.assertEqual(False, scheduler2.reachable)
 
         # and others satellites too
-        self.assert_(poller1.alive == True)
-        self.assert_(poller1.attempt == 0)
-        self.assert_(poller1.reachable == True)
+        self.assertEqual(True, poller1.alive)
+        self.assertEqual(0, poller1.attempt)
+        self.assertEqual(True, poller1.reachable)
         # still alive, just unreach
-        self.assert_(poller2.alive == False)
-        self.assert_(poller2.attempt == 3)
-        self.assert_(poller2.reachable == False)
+        self.assertEqual(False, poller2.alive)
+        self.assertEqual(3, poller2.attempt)
+        self.assertEqual(False, poller2.reachable)
 
         # and others satellites too
-        self.assert_(reactionner1.alive == True)
-        self.assert_(reactionner1.attempt == 0)
-        self.assert_(reactionner1.reachable == True)
+        self.assertEqual(True, reactionner1.alive)
+        self.assertEqual(0, reactionner1.attempt)
+        self.assertEqual(True, reactionner1.reachable)
         # still alive, just unreach
-        self.assert_(reactionner2.alive == False)
-        self.assert_(reactionner2.attempt == 3)
-        self.assert_(reactionner2.reachable == False)
+        self.assertEqual(False, reactionner2.alive)
+        self.assertEqual(3, reactionner2.attempt)
+        self.assertEqual(False, reactionner2.reachable)
 
         # and others satellites too
-        self.assert_(broker1.alive == True)
-        self.assert_(broker1.attempt == 0)
-        self.assert_(broker1.reachable == True)
+        self.assertEqual(True, broker1.alive)
+        self.assertEqual(0, broker1.attempt)
+        self.assertEqual(True, broker1.reachable)
         # still alive, just unreach
-        self.assert_(broker2.alive == False)
-        self.assert_(broker2.attempt == 3)
-        self.assert_(broker2.reachable == False)
+        self.assertEqual(False, broker2.alive)
+        self.assertEqual(3, broker2.attempt)
+        self.assertEqual(False, broker2.reachable)
 
         # Now we check how we should dispatch confs
         self.dispatcher.check_dispatch()
         # the conf should not be in a good shape
-        self.assert_(self.dispatcher.dispatch_ok == False)
+        self.assertEqual(False, self.dispatcher.dispatch_ok)
 
         # Now we really dispatch them!
         self.dispatcher.dispatch()
-        self.assert_(self.any_log_match('Dispatch OK of conf in scheduler scheduler-all-1'))
-        self.assert_(self.any_log_match('Dispatch OK of configuration 0 to reactionner reactionner-all-1'))
-        self.assert_(self.any_log_match('Dispatch OK of configuration 0 to poller poller-all-1'))
-        self.assert_(self.any_log_match('Dispatch OK of configuration 0 to broker broker-all-1'))
+        self.assert_any_log_match('Dispatch OK of conf in scheduler scheduler-all-1')
+        self.assert_any_log_match('Dispatch OK of configuration 0 to reactionner reactionner-all-1')
+        self.assert_any_log_match('Dispatch OK of configuration 0 to poller poller-all-1')
+        self.assert_any_log_match('Dispatch OK of configuration 0 to broker broker-all-1')
         self.clear_logs()
 
         # And look if we really dispatch conf as we should
         for r in self.conf.realms:
             for cfg in r.confs.values():
-                self.assert_(cfg.is_assigned == True)
-                self.assert_(cfg.assigned_to == scheduler1)
+                self.assertEqual(True, cfg.is_assigned)
+                self.assertEqual(scheduler1, cfg.assigned_to)
 
 
 class TestDispatcherMultiBroker(ShinkenTest):
@@ -326,34 +326,34 @@ class TestDispatcherMultiBroker(ShinkenTest):
             a.__class__ = GoodArbiter
         print "Preparing schedulers"
         scheduler1 = self.conf.schedulers.find_by_name('scheduler-all-1')
-        self.assert_(scheduler1 is not None)
+        self.assertIsNot(scheduler1, None)
         scheduler1.__class__ = GoodScheduler
         scheduler2 = self.conf.schedulers.find_by_name('scheduler-all-2')
-        self.assert_(scheduler2 is not None)
+        self.assertIsNot(scheduler2, None)
         scheduler2.__class__ = GoodScheduler
 
         print "Preparing pollers"
         poller1 = self.conf.pollers.find_by_name('poller-all-1')
-        self.assert_(poller1 is not None)
+        self.assertIsNot(poller1, None)
         poller1.__class__ = GoodPoller
         poller2 = self.conf.pollers.find_by_name('poller-all-2')
-        self.assert_(poller2 is not None)
+        self.assertIsNot(poller2, None)
         poller2.__class__ = BadPoller
 
         print "Preparing reactionners"
         reactionner1 = self.conf.reactionners.find_by_name('reactionner-all-1')
-        self.assert_(reactionner1 is not None)
+        self.assertIsNot(reactionner1, None)
         reactionner1.__class__ = GoodReactionner
         reactionner2 = self.conf.reactionners.find_by_name('reactionner-all-2')
-        self.assert_(reactionner2 is not None)
+        self.assertIsNot(reactionner2, None)
         reactionner2.__class__ = BadReactionner
 
         print "Preparing brokers"
         broker1 = self.conf.brokers.find_by_name('broker-all-1')
-        self.assert_(broker1 is not None)
+        self.assertIsNot(broker1, None)
         broker1.__class__ = GoodBroker
         broker2 = self.conf.brokers.find_by_name('broker-all-2')
-        self.assert_(broker2 is not None)
+        self.assertIsNot(broker2, None)
         broker2.__class__ = GoodBroker
 
         # Ping all elements. Should have 1 as OK, 2 as
@@ -361,40 +361,40 @@ class TestDispatcherMultiBroker(ShinkenTest):
         self.dispatcher.check_alive()
 
         # Check good values
-        self.assert_(scheduler1.alive == True)
-        self.assert_(scheduler1.attempt == 0)
-        self.assert_(scheduler1.reachable == True)
+        self.assertEqual(True, scheduler1.alive)
+        self.assertEqual(0, scheduler1.attempt)
+        self.assertEqual(True, scheduler1.reachable)
         # still alive, just unreach
-        self.assert_(scheduler2.alive == True)
-        self.assert_(scheduler2.attempt == 0)
-        self.assert_(scheduler2.reachable == True)
+        self.assertEqual(True, scheduler2.alive)
+        self.assertEqual(0, scheduler2.attempt)
+        self.assertEqual(True, scheduler2.reachable)
 
         # and others satellites too
-        self.assert_(poller1.alive == True)
-        self.assert_(poller1.attempt == 0)
-        self.assert_(poller1.reachable == True)
+        self.assertEqual(True, poller1.alive)
+        self.assertEqual(0, poller1.attempt)
+        self.assertEqual(True, poller1.reachable)
         # still alive, just unreach
-        self.assert_(poller2.alive == True)
-        self.assert_(poller2.attempt == 1)
-        self.assert_(poller2.reachable == False)
+        self.assertEqual(True, poller2.alive)
+        self.assertEqual(1, poller2.attempt)
+        self.assertEqual(False, poller2.reachable)
 
         # and others satellites too
-        self.assert_(reactionner1.alive == True)
-        self.assert_(reactionner1.attempt == 0)
-        self.assert_(reactionner1.reachable == True)
+        self.assertEqual(True, reactionner1.alive)
+        self.assertEqual(0, reactionner1.attempt)
+        self.assertEqual(True, reactionner1.reachable)
         # still alive, just unreach
-        self.assert_(reactionner2.alive == True)
-        self.assert_(reactionner2.attempt == 1)
-        self.assert_(reactionner2.reachable == False)
+        self.assertEqual(True, reactionner2.alive)
+        self.assertEqual(1, reactionner2.attempt)
+        self.assertEqual(False, reactionner2.reachable)
 
         # and others satellites too
-        self.assert_(broker1.alive == True)
-        self.assert_(broker1.attempt == 0)
-        self.assert_(broker1.reachable == True)
+        self.assertEqual(True, broker1.alive)
+        self.assertEqual(0, broker1.attempt)
+        self.assertEqual(True, broker1.reachable)
         # still alive, just unreach
-        self.assert_(broker2.alive == True)
-        self.assert_(broker2.attempt == 0)
-        self.assert_(broker2.reachable == True)
+        self.assertEqual(True, broker2.alive)
+        self.assertEqual(0, broker2.attempt)
+        self.assertEqual(True, broker2.reachable)
 
         ### Now add another attempt, still alive, but attemp=2/3
         print "CheckAlive " * 10
@@ -405,40 +405,40 @@ class TestDispatcherMultiBroker(ShinkenTest):
         self.dispatcher.check_alive()
 
         # Check good values
-        self.assert_(scheduler1.alive == True)
-        self.assert_(scheduler1.attempt == 0)
-        self.assert_(scheduler1.reachable == True)
+        self.assertEqual(True, scheduler1.alive)
+        self.assertEqual(0, scheduler1.attempt)
+        self.assertEqual(True, scheduler1.reachable)
         # still alive, just unreach
-        self.assert_(scheduler2.alive == True)
-        self.assert_(scheduler2.attempt == 0)
-        self.assert_(scheduler2.reachable == True)
+        self.assertEqual(True, scheduler2.alive)
+        self.assertEqual(0, scheduler2.attempt)
+        self.assertEqual(True, scheduler2.reachable)
 
         # and others satellites too
-        self.assert_(poller1.alive == True)
-        self.assert_(poller1.attempt == 0)
-        self.assert_(poller1.reachable == True)
+        self.assertEqual(True, poller1.alive)
+        self.assertEqual(0, poller1.attempt)
+        self.assertEqual(True, poller1.reachable)
         # still alive, just unreach
-        self.assert_(poller2.alive == True)
-        self.assert_(poller2.attempt == 2)
-        self.assert_(poller2.reachable == False)
+        self.assertEqual(True, poller2.alive)
+        self.assertEqual(2, poller2.attempt)
+        self.assertEqual(False, poller2.reachable)
 
         # and others satellites too
-        self.assert_(reactionner1.alive == True)
-        self.assert_(reactionner1.attempt == 0)
-        self.assert_(reactionner1.reachable == True)
+        self.assertEqual(True, reactionner1.alive)
+        self.assertEqual(0, reactionner1.attempt)
+        self.assertEqual(True, reactionner1.reachable)
         # still alive, just unreach
-        self.assert_(reactionner2.alive == True)
-        self.assert_(reactionner2.attempt == 2)
-        self.assert_(reactionner2.reachable == False)
+        self.assertEqual(True, reactionner2.alive)
+        self.assertEqual(2, reactionner2.attempt)
+        self.assertEqual(False, reactionner2.reachable)
 
         # and others satellites too
-        self.assert_(broker1.alive == True)
-        self.assert_(broker1.attempt == 0)
-        self.assert_(broker1.reachable == True)
+        self.assertEqual(True, broker1.alive)
+        self.assertEqual(0, broker1.attempt)
+        self.assertEqual(True, broker1.reachable)
         # still alive, just unreach
-        self.assert_(broker2.alive == True)
-        self.assert_(broker2.attempt == 0)
-        self.assert_(broker2.reachable == True)
+        self.assertEqual(True, broker2.alive)
+        self.assertEqual(0, broker2.attempt)
+        self.assertEqual(True, broker2.reachable)
 
         ### Now we get BAD, We go DEAD for N2!
         print "CheckAlive " * 10
@@ -449,62 +449,62 @@ class TestDispatcherMultiBroker(ShinkenTest):
         self.dispatcher.check_alive()
 
         # Check good values
-        self.assert_(scheduler1.alive == True)
-        self.assert_(scheduler1.attempt == 0)
-        self.assert_(scheduler1.reachable == True)
+        self.assertEqual(True, scheduler1.alive)
+        self.assertEqual(0, scheduler1.attempt)
+        self.assertEqual(True, scheduler1.reachable)
         # still alive, just unreach
-        self.assert_(scheduler2.alive == True)
-        self.assert_(scheduler2.attempt == 0)
-        self.assert_(scheduler2.reachable == True)
+        self.assertEqual(True, scheduler2.alive)
+        self.assertEqual(0, scheduler2.attempt)
+        self.assertEqual(True, scheduler2.reachable)
 
         # and others satellites too
-        self.assert_(poller1.alive == True)
-        self.assert_(poller1.attempt == 0)
-        self.assert_(poller1.reachable == True)
+        self.assertEqual(True, poller1.alive)
+        self.assertEqual(0, poller1.attempt)
+        self.assertEqual(True, poller1.reachable)
         # still alive, just unreach
-        self.assert_(poller2.alive == False)
-        self.assert_(poller2.attempt == 3)
-        self.assert_(poller2.reachable == False)
+        self.assertEqual(False, poller2.alive)
+        self.assertEqual(3, poller2.attempt)
+        self.assertEqual(False, poller2.reachable)
 
         # and others satellites too
-        self.assert_(reactionner1.alive == True)
-        self.assert_(reactionner1.attempt == 0)
-        self.assert_(reactionner1.reachable == True)
+        self.assertEqual(True, reactionner1.alive)
+        self.assertEqual(0, reactionner1.attempt)
+        self.assertEqual(True, reactionner1.reachable)
         # still alive, just unreach
-        self.assert_(reactionner2.alive == False)
-        self.assert_(reactionner2.attempt == 3)
-        self.assert_(reactionner2.reachable == False)
+        self.assertEqual(False, reactionner2.alive)
+        self.assertEqual(3, reactionner2.attempt)
+        self.assertEqual(False, reactionner2.reachable)
 
         # and others satellites too
-        self.assert_(broker1.alive == True)
-        self.assert_(broker1.attempt == 0)
-        self.assert_(broker1.reachable == True)
+        self.assertEqual(True, broker1.alive)
+        self.assertEqual(0, broker1.attempt)
+        self.assertEqual(True, broker1.reachable)
         # still alive, just unreach
-        self.assert_(broker2.alive == True)
-        self.assert_(broker2.attempt == 0)
-        self.assert_(broker2.reachable == True)
+        self.assertEqual(True, broker2.alive)
+        self.assertEqual(0, broker2.attempt)
+        self.assertEqual(True, broker2.reachable)
 
         # Now we check how we should dispatch confs
         self.dispatcher.check_dispatch()
         # the conf should not be in a good shape
-        self.assert_(self.dispatcher.dispatch_ok == False)
+        self.assertEqual(False, self.dispatcher.dispatch_ok)
 
         # Now we really dispatch them!
         self.dispatcher.dispatch()
-        self.assert_(self.any_log_match('Dispatch OK of conf in scheduler scheduler-all-1'))
-        self.assert_(self.any_log_match('Dispatch OK of configuration 0 to reactionner reactionner-all-1'))
-        self.assert_(self.any_log_match('Dispatch OK of configuration 0 to poller poller-all-1'))
+        self.assert_any_log_match('Dispatch OK of conf in scheduler scheduler-all-1')
+        self.assert_any_log_match('Dispatch OK of configuration 0 to reactionner reactionner-all-1')
+        self.assert_any_log_match('Dispatch OK of configuration 0 to poller poller-all-1')
 
-        self.assert_(self.any_log_match('Dispatch OK of configuration 1 to broker broker-all-1'))
-        self.assert_(self.any_log_match('Dispatch OK of configuration 0 to broker broker-all-2'))
+        self.assert_any_log_match('Dispatch OK of configuration 1 to broker broker-all-1')
+        self.assert_any_log_match('Dispatch OK of configuration 0 to broker broker-all-2')
         self.clear_logs()
 
 
         # And look if we really dispatch conf as we should
         for r in self.conf.realms:
             for cfg in r.confs.values():
-                self.assert_(cfg.is_assigned == True)
-                self.assert_(cfg.assigned_to in [scheduler1, scheduler2])
+                self.assertEqual(True, cfg.is_assigned)
+                self.assertIn(cfg.assigned_to, [scheduler1, scheduler2])
 
 
 
