@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -23,13 +23,20 @@
 #
 
 from shinken_test import *
-
-time_hacker.set_real_time()
+from shinken.objects.serviceescalation import Serviceescalation
 
 class TestEscalations(ShinkenTest):
 
     def setUp(self):
         self.setup_with_file('etc/shinken_escalations.cfg')
+        time_hacker.set_real_time()
+
+    def test_wildcard_in_service_descrption(self):
+        self.print_header()
+        sid = int(Serviceescalation.id) - 1
+        generated = self.sched.conf.escalations.find_by_name('Generated-Serviceescalation-%d' % sid)
+        for svc in self.sched.services.find_srvs_by_hostname("test_host_0"):
+            self.assertIn(generated, svc.escalations)
 
     def test_simple_escalation(self):
         self.print_header()
@@ -54,14 +61,14 @@ class TestEscalations(ShinkenTest):
         print "- 1 x OK -------------------------------------"
         self.scheduler_loop(1, [[svc, 0, 'OK']], do_sleep=True, sleep_time=0.1)
 
-        self.assert_(svc.current_notification_number == 0)
+        self.assertEqual(0, svc.current_notification_number)
 
         tolevel2 = self.sched.conf.escalations.find_by_name('ToLevel2')
-        self.assert_(tolevel2 is not None)
-        self.assert_(tolevel2 in svc.escalations)
+        self.assertIsNot(tolevel2, None)
+        self.assertIn(tolevel2, svc.escalations)
         tolevel3 = self.sched.conf.escalations.find_by_name('ToLevel3')
-        self.assert_(tolevel3 is not None)
-        self.assert_(tolevel3 in svc.escalations)
+        self.assertIsNot(tolevel3, None)
+        self.assertIn(tolevel3, svc.escalations)
 
 
         for es in svc.escalations:
@@ -84,7 +91,7 @@ class TestEscalations(ShinkenTest):
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
 
         # We check if we really notify the level1
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level1.*;CRITICAL;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level1.*;CRITICAL;')
         self.show_and_clear_logs()
         #self.show_and_clear_actions()
         self.show_actions()
@@ -96,7 +103,7 @@ class TestEscalations(ShinkenTest):
         # notification_number is already sent. the next one has been scheduled
         # and is waiting for notification_interval to pass. so the current
         # number is 2
-        self.assert_(svc.current_notification_number == 1)
+        self.assertEqual(1, svc.current_notification_number)
         print "OK, level1 is notified, notif nb = 1"
 
         print "---------------------------------1st round with a hard"
@@ -104,43 +111,47 @@ class TestEscalations(ShinkenTest):
         cnn = svc.current_notification_number
         print "- 1 x BAD repeat -------------------------------------"
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
+        self.assertIn(True, [n.escalated for n in self.sched.actions.values()])
 
         # Now we raise the notif number of 2, so we can escalade
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;')
         self.show_and_clear_logs()
         self.show_actions()
         print "cnn and cur", cnn, svc.current_notification_number
-        self.assert_(svc.current_notification_number > cnn)
+        self.assertGreater(svc.current_notification_number, cnn)
         cnn = svc.current_notification_number
 
         # One more bad, we go 3
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;'))
+        self.assertIn(True, [n.escalated for n in self.sched.actions.values()])
+        self.assert_any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;')
         self.show_and_clear_logs()
 
         # We go 4, still level2
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;'))
+        self.assertIn(True, [n.escalated for n in self.sched.actions.values()])
+        self.assert_any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;')
         self.show_and_clear_logs()
         # We go 5! we escalade to level3
 
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;'))
+        self.assertIn(True, [n.escalated for n in self.sched.actions.values()])
+        self.assert_any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;')
         self.show_and_clear_logs()
 
         # Now we send 10 more notif, we must be still level5
         for i in range(10):
             self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
-            self.assert_(self.any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;'))
+            self.assert_any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;')
             self.show_and_clear_logs()
 
         # Now we recover, it will be fun because all of level{1,2,3} must be send a
         # notif
         self.scheduler_loop(2, [[svc, 0, 'OK']], do_sleep=True, sleep_time=0.1)
         self.show_actions()
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level1.*;OK;'))
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level2.*;OK;'))
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level3.*;OK;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level1.*;OK;')
+        self.assert_any_log_match('SERVICE NOTIFICATION: level2.*;OK;')
+        self.assert_any_log_match('SERVICE NOTIFICATION: level3.*;OK;')
         self.show_and_clear_logs()
 
     def test_time_based_escalation(self):
@@ -166,15 +177,15 @@ class TestEscalations(ShinkenTest):
         print "- 1 x OK -------------------------------------"
         self.scheduler_loop(1, [[svc, 0, 'OK']], do_sleep=True, sleep_time=0.1)
 
-        self.assert_(svc.current_notification_number == 0)
+        self.assertEqual(0, svc.current_notification_number)
 
         # We check if we correclty linked our escalations
         tolevel2_time = self.sched.conf.escalations.find_by_name('ToLevel2-time')
-        self.assert_(tolevel2_time is not None)
-        self.assert_(tolevel2_time in svc.escalations)
+        self.assertIsNot(tolevel2_time, None)
+        self.assertIn(tolevel2_time, svc.escalations)
         tolevel3_time = self.sched.conf.escalations.find_by_name('ToLevel3-time')
-        self.assert_(tolevel3_time is not None)
-        self.assert_(tolevel3_time in svc.escalations)
+        self.assertIsNot(tolevel3_time, None)
+        self.assertIn(tolevel3_time, svc.escalations)
 
         # Go for the running part!
 
@@ -195,7 +206,7 @@ class TestEscalations(ShinkenTest):
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
 
         # We check if we really notify the level1
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level1.*;CRITICAL;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level1.*;CRITICAL;')
         self.show_and_clear_logs()
         self.show_actions()
 
@@ -204,7 +215,7 @@ class TestEscalations(ShinkenTest):
         # notification_number is already sent. the next one has been scheduled
         # and is waiting for notification_interval to pass. so the current
         # number is 2
-        self.assert_(svc.current_notification_number == 1)
+        self.assertEqual(1, svc.current_notification_number)
         print "OK, level1 is notified, notif nb = 1"
 
         print "---------------------------------1st round with a hard"
@@ -223,13 +234,13 @@ class TestEscalations(ShinkenTest):
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.001)
 
         # Now we raise a notification time of 1hour, we escalade to level2
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;')
         self.show_and_clear_logs()
         self.show_actions()
 
         print "cnn and cur", cnn, svc.current_notification_number
         # We check that we really raise the notif number too
-        self.assert_(svc.current_notification_number > cnn)
+        self.assertGreater(svc.current_notification_number, cnn)
         cnn = svc.current_notification_number
 
         for n in svc.notifications_in_progress.values():
@@ -238,7 +249,7 @@ class TestEscalations(ShinkenTest):
 
         # One more bad, we say: he, it's still near 1 hour, so still level2
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;')
         self.show_and_clear_logs()
 
         # Now we go for level3, so again we say: he, in fact we start one hour earlyer,
@@ -250,7 +261,7 @@ class TestEscalations(ShinkenTest):
 
         # One more, we bypass 7200, so now it's level3
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;')
         self.show_and_clear_logs()
 
 
@@ -261,16 +272,16 @@ class TestEscalations(ShinkenTest):
                 n.t_to_go = time.time()
 
             self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
-            self.assert_(self.any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;'))
+            self.assert_any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;')
             self.show_and_clear_logs()
 
         # Now we recover, it will be fun because all of level{1,2,3} must be send a
         # recovery notif
         self.scheduler_loop(2, [[svc, 0, 'OK']], do_sleep=True, sleep_time=0.1)
         self.show_actions()
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level1.*;OK;'))
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level2.*;OK;'))
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level3.*;OK;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level1.*;OK;')
+        self.assert_any_log_match('SERVICE NOTIFICATION: level2.*;OK;')
+        self.assert_any_log_match('SERVICE NOTIFICATION: level3.*;OK;')
         self.show_and_clear_logs()
 
     # Here we search to know if a escalation really short the notification
@@ -301,15 +312,15 @@ class TestEscalations(ShinkenTest):
         print "- 1 x OK -------------------------------------"
         self.scheduler_loop(1, [[svc, 0, 'OK']], do_sleep=True, sleep_time=0.1)
 
-        self.assert_(svc.current_notification_number == 0)
+        self.assertEqual(0, svc.current_notification_number)
 
         # We check that we really linked our escalations :)
         tolevel2_time = self.sched.conf.escalations.find_by_name('ToLevel2-time')
-        self.assert_(tolevel2_time is not None)
-        self.assert_(tolevel2_time in svc.escalations)
+        self.assertIsNot(tolevel2_time, None)
+        self.assertIn(tolevel2_time, svc.escalations)
         tolevel3_time = self.sched.conf.escalations.find_by_name('ToLevel3-time')
-        self.assert_(tolevel3_time is not None)
-        self.assert_(tolevel3_time in svc.escalations)
+        self.assertIsNot(tolevel3_time, None)
+        self.assertIn(tolevel3_time, svc.escalations)
 
         #--------------------------------------------------------------
         # service reaches soft;1
@@ -329,7 +340,7 @@ class TestEscalations(ShinkenTest):
 
         print "  ** LEVEL1 ** " * 20
         # We check if we really notify the level1
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level1.*;CRITICAL;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level1.*;CRITICAL;')
         self.show_and_clear_logs()
         self.show_actions()
 
@@ -338,7 +349,7 @@ class TestEscalations(ShinkenTest):
         # notification_number is already sent. the next one has been scheduled
         # and is waiting for notification_interval to pass. so the current
         # number is 2
-        self.assert_(svc.current_notification_number == 1)
+        self.assertEqual(1, svc.current_notification_number)
         print "OK, level1 is notified, notif nb = 1"
 
         print "---------------------------------1st round with a hard"
@@ -356,7 +367,7 @@ class TestEscalations(ShinkenTest):
             print abs(next - now)
             # Check if we find the next notification for the next hour,
             # and not for the next day like we ask before
-            self.assert_(abs(next - now - 3600) < 10)
+            self.assertLess(abs(next - now - 3600), 10)
 
         # And we hack the notification so we can raise really the level2 escalation
         for n in svc.notifications_in_progress.values():
@@ -369,13 +380,13 @@ class TestEscalations(ShinkenTest):
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.001)
 
         # Now we raise the time since the begining at 1 hour, so we can escalade
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;')
         self.show_and_clear_logs()
         self.show_actions()
 
         print "Level 2 got warn, now we search for level3"
         print "cnn and cur", cnn, svc.current_notification_number
-        self.assert_(svc.current_notification_number > cnn)
+        self.assertGreater(svc.current_notification_number, cnn)
         cnn = svc.current_notification_number
 
         # Now the same thing, but for level3, so one more hour
@@ -386,7 +397,7 @@ class TestEscalations(ShinkenTest):
 
         # One more bad, we say: he, it's 7200 sc of notif, so must be still level3
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;')
         self.show_and_clear_logs()
 
         for n in svc.notifications_in_progress.values():
@@ -396,7 +407,7 @@ class TestEscalations(ShinkenTest):
 
         # One more, we bypass 7200, so now it's still level3
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;')
         self.show_and_clear_logs()
 
 
@@ -407,7 +418,7 @@ class TestEscalations(ShinkenTest):
                 n.t_to_go = time.time()
 
             self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
-            self.assert_(self.any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;'))
+            self.assert_any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;')
             self.show_and_clear_logs()
 
         # Ok now we get the normal stuff, we do NOT want to raise so soon a
@@ -419,17 +430,17 @@ class TestEscalations(ShinkenTest):
         for n in svc.notifications_in_progress.values():
             print n, n.t_to_go, time.time(), n.t_to_go - time.time()
             # Should be "near" one day now, so 84000s
-            self.assert_(8300 < abs(n.t_to_go - time.time()) < 85000)
+            self.assertLess(8300 < abs(n.t_to_go - time.time()), 85000)
         # And so no notification
-        self.assert_(not self.any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;'))
+        self.assert_no_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;')
 
         # Now we recover, it will be fun because all of level{1,2,3} must be send a
         # recovery notif
         self.scheduler_loop(2, [[svc, 0, 'OK']], do_sleep=True, sleep_time=0.1)
         self.show_actions()
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level1.*;OK;'))
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level2.*;OK;'))
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level3.*;OK;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level1.*;OK;')
+        self.assert_any_log_match('SERVICE NOTIFICATION: level2.*;OK;')
+        self.assert_any_log_match('SERVICE NOTIFICATION: level3.*;OK;')
         self.show_and_clear_logs()
 
     def test_time_based_escalation_with_short_notif_interval(self):
@@ -454,18 +465,18 @@ class TestEscalations(ShinkenTest):
         print "- 1 x OK -------------------------------------"
         self.scheduler_loop(1, [[svc, 0, 'OK']], do_sleep=True, sleep_time=0.1)
 
-        self.assert_(svc.current_notification_number == 0)
+        self.assertEqual(0, svc.current_notification_number)
 
         # We hack the interval_length for short time, like 10s
         svc.__class__.interval_length = 5
 
         # We check if we correclty linked our escalations
         tolevel2_time = self.sched.conf.escalations.find_by_name('ToLevel2-shortinterval')
-        self.assert_(tolevel2_time is not None)
-        self.assert_(tolevel2_time in svc.escalations)
+        self.assertIsNot(tolevel2_time, None)
+        self.assertIn(tolevel2_time, svc.escalations)
         #tolevel3_time = self.sched.conf.escalations.find_by_name('ToLevel3-time')
-        #self.assert_(tolevel3_time is not None)
-        #self.assert_(tolevel3_time in svc.escalations)
+        #self.assertIsNot(tolevel3_time, None)
+        #self.assertIn(tolevel3_time, svc.escalations)
 
         # Go for the running part!
 
@@ -486,7 +497,7 @@ class TestEscalations(ShinkenTest):
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
 
         # We check if we really notify the level1
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level1.*;CRITICAL;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level1.*;CRITICAL;')
         self.show_and_clear_logs()
         self.show_actions()
 
@@ -495,7 +506,7 @@ class TestEscalations(ShinkenTest):
         # notification_number is already sent. the next one has been scheduled
         # and is waiting for notification_interval to pass. so the current
         # number is 2
-        self.assert_(svc.current_notification_number == 1)
+        self.assertEqual(1, svc.current_notification_number)
         print "OK, level1 is notified, notif nb = 1"
 
         print "---------------------------------1st round with a hard"
@@ -520,7 +531,7 @@ class TestEscalations(ShinkenTest):
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.001)
 
         # Now we raise a notification time of 1hour, we escalade to level2
-        self.assert_(not self.any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;'))
+        self.assert_no_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;')
         self.show_and_clear_logs()
         self.show_actions()
 
@@ -531,13 +542,13 @@ class TestEscalations(ShinkenTest):
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.001)
 
         # Now we raise a notification time of 1hour, we escalade to level2
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;')
         self.show_and_clear_logs()
         self.show_actions()
 
         print "cnn and cur", cnn, svc.current_notification_number
         # We check that we really raise the notif number too
-        self.assert_(svc.current_notification_number > cnn)
+        self.assertGreater(svc.current_notification_number, cnn)
         cnn = svc.current_notification_number
         
         # Ok we should have one notification
@@ -545,11 +556,11 @@ class TestEscalations(ShinkenTest):
         print "LEN", len(next_notifications)
         for n in next_notifications:
             print n
-        self.assert_(len(next_notifications) == 1)
+        self.assertEqual(1, len(next_notifications))
         n = next_notifications.pop()
         print "Current NOTIFICATION", n.__dict__, n.t_to_go, time.time(), n.t_to_go - time.time(), n.already_start_escalations
         # Should be in the escalation ToLevel2-shortinterval
-        self.assert_('ToLevel2-shortinterval' in n.already_start_escalations)
+        self.assertIn('ToLevel2-shortinterval', n.already_start_escalations)
 
         # Ok we want to be sure we are using the current escalation interval, the 1 interval = 5s
         # So here we should have a new notification for level2
@@ -559,7 +570,7 @@ class TestEscalations(ShinkenTest):
 
         # One more bad, we say: he, it's still near 1 hour, so still level2
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;')
         self.show_and_clear_logs()
 
         # Ok now go in the Level3 thing
@@ -569,23 +580,23 @@ class TestEscalations(ShinkenTest):
 
         # One more, we bypass 7200, so now it's level3
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;'))
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level2.*;CRITICAL;')
+        self.assert_any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;')
         self.show_and_clear_logs()
 
         # Ok we should have one notification
         next_notifications = svc.notifications_in_progress.values()
-        self.assert_(len(next_notifications) == 1)
+        self.assertEqual(1, len(next_notifications))
         n = next_notifications.pop()
         print "Current NOTIFICATION", n.__dict__, n.t_to_go, time.time(), n.t_to_go - time.time(), n.already_start_escalations
         # Should be in the escalation ToLevel2-shortinterval
-        self.assert_('ToLevel2-shortinterval' in n.already_start_escalations)
-        self.assert_('ToLevel3-shortinterval' in n.already_start_escalations)
+        self.assertIn('ToLevel2-shortinterval', n.already_start_escalations)
+        self.assertIn('ToLevel3-shortinterval', n.already_start_escalations)
 
         # Make a loop for pass the next notification
         time.sleep(5)
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;')
         self.show_and_clear_logs()
 
         print "Current NOTIFICATION", n.__dict__, n.t_to_go, time.time(), n.t_to_go - time.time(), n.already_start_escalations
@@ -594,16 +605,16 @@ class TestEscalations(ShinkenTest):
         time.sleep(5)
 
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level3.*;CRITICAL;')
         self.show_and_clear_logs()
 
         # Now we recover, it will be fun because all of level{1,2,3} must be send a
         # recovery notif
         self.scheduler_loop(2, [[svc, 0, 'OK']], do_sleep=True, sleep_time=0.1)
         self.show_actions()
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level1.*;OK;'))
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level2.*;OK;'))
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION: level3.*;OK;'))
+        self.assert_any_log_match('SERVICE NOTIFICATION: level1.*;OK;')
+        self.assert_any_log_match('SERVICE NOTIFICATION: level2.*;OK;')
+        self.assert_any_log_match('SERVICE NOTIFICATION: level3.*;OK;')
         self.show_and_clear_logs()
 
 
