@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -33,10 +33,10 @@ class TestHostGroupWithSpace(ShinkenTest):
 
     def test_hostgroup_with_space(self):
         svc = self.sched.services.find_srv_by_name_and_hostname("test_host_0", "test_With Spaces")
-        self.assert_(svc is not None)
+        self.assertIsNot(svc, None)
 
         svc = self.sched.services.find_srv_by_name_and_hostname("test_host_0", 'test_With anoter Spaces')
-        self.assert_(svc is not None)
+        self.assertIsNot(svc, None)
 
 if __name__ == '__main__':
     unittest.main()
