@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -33,7 +33,7 @@ class TestLinkifyTemplate(ShinkenTest):
     def test_linkify_template(self):
         svc = self.conf.services.find_srv_by_name_and_hostname("test_host_0", "test_ok_0")
         b = svc.is_correct()
-        self.assert_(not b)
+        self.assertFalse(b)
 
 
 if __name__ == '__main__':
