@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -44,8 +44,8 @@ class TestNoEventHandlerDuringDowntime(ShinkenTest):
         svc.checks_in_progress = []
         svc.act_depend_of = []  # no hostchecks on critical checkresults
         self.scheduler_loop(2, [[host, 0, 'UP | value1=1 value2=2'], [router, 0, 'UP | rtt=10'], [svc, 0, 'OK | value1=0 value2=0']])
-        self.assert_(host.state == 'UP')
-        self.assert_(host.state_type == 'HARD')
+        self.assertEqual('UP', host.state)
+        self.assertEqual('HARD', host.state_type)
 
         now = time.time()
         # downtime valid for the next 2 minutes
@@ -55,13 +55,13 @@ class TestNoEventHandlerDuringDowntime(ShinkenTest):
         # Make a loop to activate the downtime
         self.scheduler_loop(1, [])
         # We check so the downtime is really active
-        self.assert_(self.any_log_match('SERVICE DOWNTIME ALERT.*;STARTED'))
+        self.assert_any_log_match('SERVICE DOWNTIME ALERT.*;STARTED')
 
         self.scheduler_loop(2, [[host, 0, 'UP | value1=1 value2=2'], [router, 0, 'UP | rtt=10'], [svc, 2, 'OK | value1=0 valu\
 e2=0']])
 
         # There should be NO event handlers during a downtime!
-        self.assert_(not self.any_log_match('SERVICE EVENT HANDLER.*;CRITICAL'))
+        self.assert_no_log_match('SERVICE EVENT HANDLER.*;CRITICAL')
 
 
 
