@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -45,18 +45,18 @@ class TestNoNotificationPeriod(ShinkenTest):
         svc.checks_in_progress = []
         svc.act_depend_of = []  # no hostchecks on critical checkresults
         self.scheduler_loop(2, [[host, 0, 'UP | value1=1 value2=2'], [router, 0, 'UP | rtt=10'], [svc, 0, 'OK | value1=0 value2=0']])
-        self.assert_(host.state == 'UP')
-        self.assert_(host.state_type == 'HARD')
+        self.assertEqual('UP', host.state)
+        self.assertEqual('HARD', host.state_type)
 
         # Now get bad :)
         self.scheduler_loop(2, [[svc, 2, 'BAD | value1=0 value2=0']])
-        self.assert_(svc.notification_period is None)
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION.*;CRITICAL'))
+        self.assertIs(None, svc.notification_period)
+        self.assert_any_log_match('SERVICE NOTIFICATION.*;CRITICAL')
 
         # Now for the host :)
         self.scheduler_loop(5, [[host, 2, 'BAD | value1=0 value2=0']])
-        self.assert_(host.notification_period is None)
-        self.assert_(self.any_log_match('HOST NOTIFICATION.*;DOWN'))
+        self.assertIs(None, host.notification_period)
+        self.assert_any_log_match('HOST NOTIFICATION.*;DOWN')
 
 
 
