@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -26,6 +26,7 @@
 import time
 
 from shinken_test import unittest, ShinkenTest
+from shinken_test import time_hacker
 
 
 class TestNotif(ShinkenTest):
@@ -53,7 +54,7 @@ class TestNotif(ShinkenTest):
         print "- 1 x OK -------------------------------------"
         self.scheduler_loop(1, [[svc, 0, 'OK']], do_sleep=True, sleep_time=0.1)
 
-        self.assert_(svc.current_notification_number == 0)
+        self.assertEqual(0, svc.current_notification_number)
         #--------------------------------------------------------------
         # service reaches soft;1
         # there must not be any notification
@@ -80,7 +81,7 @@ class TestNotif(ShinkenTest):
         # notification_number is already sent. the next one has been scheduled
         # and is waiting for notification_interval to pass. so the current
         # number is 2
-        self.assert_(svc.current_notification_number == 1)
+        self.assertEqual(1, svc.current_notification_number)
         print "---------------------------------1st round with a hard"
         print "find a way to get the number of the last reaction"
         cnn = svc.current_notification_number
@@ -89,13 +90,13 @@ class TestNotif(ShinkenTest):
         self.show_and_clear_logs()
         self.show_actions()
         print "cnn and cur", cnn, svc.current_notification_number
-        self.assert_(svc.current_notification_number > cnn)
+        self.assertGreater(svc.current_notification_number, cnn)
         cnn = svc.current_notification_number
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
         self.show_and_clear_logs()
         self.show_actions()
         print "svc.current_notification_number, cnn", svc.current_notification_number, cnn
-        self.assert_(svc.current_notification_number > cnn)
+        self.assertGreater(svc.current_notification_number, cnn)
         #--------------------------------------------------------------
         # 2 cycles = 2 minutes = 2 new notifications
         #--------------------------------------------------------------
@@ -104,7 +105,7 @@ class TestNotif(ShinkenTest):
         self.show_and_clear_logs()
         self.show_actions()
         print "svc.current_notification_number, cnn", svc.current_notification_number, cnn
-        self.assert_(svc.current_notification_number > cnn)
+        self.assertGreater(svc.current_notification_number, cnn)
         #--------------------------------------------------------------
         # 2 cycles = 2 minutes = 2 new notifications (theoretically)
         # BUT: test_contact filters notifications
@@ -117,7 +118,7 @@ class TestNotif(ShinkenTest):
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
         self.show_and_clear_logs()
         self.show_actions()
-        self.assert_(svc.current_notification_number == cnn)
+        self.assertEqual(cnn, svc.current_notification_number)
         #--------------------------------------------------------------
         # again a normal cycle
         # test_contact receives his mail
@@ -130,14 +131,14 @@ class TestNotif(ShinkenTest):
         self.show_and_clear_logs()
         self.show_actions()
         print "svc.current_notification_number, cnn", svc.current_notification_number, cnn
-        self.assert_(svc.current_notification_number == cnn + 1)
+        self.assertEqual(cnn + 1, svc.current_notification_number)
         #--------------------------------------------------------------
         # now recover. there must be no scheduled/inpoller notification
         #--------------------------------------------------------------
         self.scheduler_loop(1, [[svc, 0, 'GOOD']], do_sleep=True, sleep_time=0.1)
         self.show_and_clear_logs()
         self.show_and_clear_actions()
-        self.assert_(svc.current_notification_number == 0)
+        self.assertEqual(0, svc.current_notification_number)
 
     def test_continuous_notifications_delayed(self):
         self.print_header()
@@ -163,17 +164,18 @@ class TestNotif(ShinkenTest):
         self.scheduler_loop(1, [[svc, 0, 'OK']], do_sleep=True, sleep_time=1)
         self.show_and_clear_logs()
         self.show_and_clear_actions()
-        self.assert_(svc.current_notification_number == 0)
+        self.assertEqual(0, svc.current_notification_number)
         #-----------------------------------------------------------------
         # check fails and enters soft state.
         # there must be no notification, only the event handler
         #-----------------------------------------------------------------
         self.scheduler_loop(1, [[svc, 1, 'BAD']], do_sleep=True, sleep_time=1)
-        self.assert_(self.count_actions() == 1)
-        print time.time()
-        print  svc.last_time_warning, svc.last_time_critical, svc.last_time_unknown, svc.last_time_ok
+        self.assertEqual(1, self.count_actions())
+        now = time.time()
+        print svc.last_time_warning, svc.last_time_critical, svc.last_time_unknown, svc.last_time_ok
         last_time_not_ok = svc.last_time_non_ok_or_up()
         deadline = svc.last_time_non_ok_or_up() + svc.first_notification_delay * svc.__class__.interval_length
+        print("deadline is in %s secs" % (deadline - now))
         #-----------------------------------------------------------------
         # check fails again and enters hard state.
         # now there is a (scheduled for later) notification and an event handler
@@ -183,19 +185,12 @@ class TestNotif(ShinkenTest):
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
         self.show_and_clear_logs()
         self.show_actions()
-        self.assert_(svc.current_notification_number == 0)
-        #-----------------------------------------------------------------
-        # repeat bad checks during the delay time
-        # there is 1 action which is the scheduled notification
-        #-----------------------------------------------------------------
-        loop = 0
-        while deadline > time.time():
-            loop += 1
-            self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
-            self.show_and_clear_logs()
-            self.show_actions()
-            print deadline - time.time()
-            ###self.assert_(self.count_actions() == 1)
+        self.assertEqual(0, svc.current_notification_number)
+        # sleep up to deadline:
+        time_hacker.time_warp(deadline - now)
+        # even if time_hacker is used here, we still call time.sleep()
+        # to show that we must wait the necessary delay time:
+        time.sleep(deadline - now)
         #-----------------------------------------------------------------
         # now the delay period is over and the notification can be sent
         # with the next bad check
@@ -204,13 +199,13 @@ class TestNotif(ShinkenTest):
         #-----------------------------------------------------------------
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=1)
         print "Counted actions", self.count_actions()
-        self.assert_(self.count_actions() == 2)
+        self.assertEqual(2, self.count_actions())
         # 1 master, 1 child
-        self.assert_(svc.current_notification_number == 1)
+        self.assertEqual(1, svc.current_notification_number)
         self.show_actions()
-        self.assert_(len(svc.notifications_in_progress) == 1)  # master is zombieand removed_from_in_progress
+        self.assertEqual(1, len(svc.notifications_in_progress))  # master is zombieand removed_from_in_progress
         self.show_logs()
-        self.assert_(self.log_match(1, 'SERVICE NOTIFICATION.*;CRITICAL;'))
+        self.assert_log_match(1, 'SERVICE NOTIFICATION.*;CRITICAL;')
         self.show_and_clear_logs()
         self.show_actions()
         #-----------------------------------------------------------------
@@ -219,14 +214,14 @@ class TestNotif(ShinkenTest):
         # current_notification_number was reset to 0
         #-----------------------------------------------------------------
         self.scheduler_loop(2, [[svc, 0, 'GOOD']], do_sleep=True, sleep_time=1)
-        self.assert_(self.log_match(1, 'SERVICE ALERT.*;OK;'))
-        self.assert_(self.log_match(2, 'SERVICE EVENT HANDLER.*;OK;'))
-        self.assert_(self.log_match(3, 'SERVICE NOTIFICATION.*;OK;'))
+        self.assert_log_match(1, 'SERVICE ALERT.*;OK;')
+        self.assert_log_match(2, 'SERVICE EVENT HANDLER.*;OK;')
+        self.assert_log_match(3, 'SERVICE NOTIFICATION.*;OK;')
         # evt reap 2 loops
-        self.assert_(svc.current_notification_number == 0)
-        self.assert_(len(svc.notifications_in_progress) == 0)
-        self.assert_(len(svc.notified_contacts) == 0)
-        #self.assert_(self.count_actions() == 2)
+        self.assertEqual(0, svc.current_notification_number)
+        self.assertEqual(0, len(svc.notifications_in_progress))
+        self.assertEqual(0, len(svc.notified_contacts))
+        #self.assertEqual(2, self.count_actions())
         self.show_and_clear_logs()
         self.show_and_clear_actions()
 
@@ -250,7 +245,7 @@ class TestNotif(ShinkenTest):
         self.scheduler_loop(1, [[svc, 0, 'OK']], do_sleep=True, sleep_time=0.1)
         self.show_and_clear_logs()
         self.show_and_clear_actions()
-        self.assert_(svc.current_notification_number == 0)
+        self.assertEqual(0, svc.current_notification_number)
         #-----------------------------------------------------------------
         # check fails and enters soft state.
         # there must be no notification, only the event handler
@@ -258,7 +253,7 @@ class TestNotif(ShinkenTest):
         self.scheduler_loop(1, [[svc, 1, 'BAD']], do_sleep=True, sleep_time=0.1)
         self.show_and_clear_logs()
         self.show_actions()
-        self.assert_(self.count_actions() == 1)
+        self.assertEqual(1, self.count_actions())
         #-----------------------------------------------------------------
         # check fails again and enters hard state.
         # now there is a (scheduled for later) notification and an event handler
@@ -268,8 +263,8 @@ class TestNotif(ShinkenTest):
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
         self.show_and_clear_logs()
         self.show_actions()
-        self.assert_(self.count_actions() == 2)
-        self.assert_(svc.current_notification_number == 0)
+        self.assertEqual(2, self.count_actions())
+        self.assertEqual(0, svc.current_notification_number)
         #-----------------------------------------------------------------
         # repeat bad checks during the delay time
         # but only one time. we don't want to reach the deadline
@@ -278,19 +273,20 @@ class TestNotif(ShinkenTest):
         self.scheduler_loop(1, [[svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
         self.show_and_clear_logs()
         self.show_actions()
-        self.assert_(self.count_actions() == 1)
+        self.assertEqual(1, self.count_actions())
         #-----------------------------------------------------------------
         # relax with a successful check
         # there is 1 action, the eventhandler.
         #-----------------------------------------------------------------
         self.scheduler_loop(1, [[svc, 0, 'GOOD']], do_sleep=True, sleep_time=0.1)
-        self.assert_(self.log_match(1, 'SERVICE ALERT.*;OK;'))
-        self.assert_(self.log_match(2, 'SERVICE EVENT HANDLER.*;OK;'))
-        self.assert_(not self.log_match(3, 'SERVICE NOTIFICATION.*;OK;'))
+        self.assert_log_match(1, 'SERVICE ALERT.*;OK;')
+        self.assert_log_match(2, 'SERVICE EVENT HANDLER.*;OK;')
+        self.assert_log_match(3, 'SERVICE NOTIFICATION.*;OK;',
+                              no_match=True)
         self.show_actions()
-        self.assert_(len(svc.notifications_in_progress) == 0)
-        self.assert_(len(svc.notified_contacts) == 0)
-        self.assert_(self.count_actions() == 1)
+        self.assertEqual(0, len(svc.notifications_in_progress))
+        self.assertEqual(0, len(svc.notified_contacts))
+        self.assertEqual(1, self.count_actions())
         self.show_and_clear_logs()
         self.show_and_clear_actions()
 
@@ -315,7 +311,7 @@ class TestNotif(ShinkenTest):
         # initialize host/service state
         #--------------------------------------------------------------
         self.scheduler_loop(1, [[host, 0, 'UP'], [svc, 0, 'OK']], do_sleep=True, sleep_time=0.1)
-        self.assert_(svc.current_notification_number == 0)
+        self.assertEqual(0, svc.current_notification_number)
         #--------------------------------------------------------------
         # service reaches hard;2
         # a notification must have been created
@@ -324,19 +320,19 @@ class TestNotif(ShinkenTest):
         self.scheduler_loop(2, [[host, 0, 'UP'], [svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
         self.show_logs()
         self.show_actions()
-        self.assert_(self.log_match(1, 'SERVICE ALERT.*;CRITICAL;SOFT'))
-        self.assert_(self.log_match(2, 'SERVICE EVENT HANDLER.*;CRITICAL;SOFT'))
-        self.assert_(self.log_match(3, 'SERVICE ALERT.*;CRITICAL;HARD'))
-        self.assert_(self.log_match(4, 'SERVICE EVENT HANDLER.*;CRITICAL;HARD'))
-        self.assert_(self.log_match(5, 'SERVICE NOTIFICATION.*;CRITICAL;'))
-        self.assert_(svc.current_notification_number == 1)
+        self.assert_log_match(1, 'SERVICE ALERT.*;CRITICAL;SOFT')
+        self.assert_log_match(2, 'SERVICE EVENT HANDLER.*;CRITICAL;SOFT')
+        self.assert_log_match(3, 'SERVICE ALERT.*;CRITICAL;HARD')
+        self.assert_log_match(4, 'SERVICE EVENT HANDLER.*;CRITICAL;HARD')
+        self.assert_log_match(5, 'SERVICE NOTIFICATION.*;CRITICAL;')
+        self.assertEqual(1, svc.current_notification_number)
         self.clear_logs()
         self.clear_actions()
         #--------------------------------------------------------------
         # reset host/service state
         #--------------------------------------------------------------
         self.scheduler_loop(1, [[host, 0, 'UP'], [svc, 0, 'OK']], do_sleep=True, sleep_time=0.1)
-        self.assert_(svc.current_notification_number == 0)
+        self.assertEqual(0, svc.current_notification_number)
         duration = 300
         now = time.time()
         # fixed downtime valid for the next 5 minutes
@@ -347,8 +343,8 @@ class TestNotif(ShinkenTest):
         # no notificatio
         #--------------------------------------------------------------
         self.scheduler_loop(2, [[host, 0, 'UP'], [svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
-        self.assert_(self.any_log_match('HOST NOTIFICATION.*;DOWNTIMESTART'))
-        self.assert_(not self.any_log_match('SERVICE NOTIFICATION.*;CRITICAL;'))
+        self.assert_any_log_match('HOST NOTIFICATION.*;DOWNTIMESTART')
+        self.assert_no_log_match('SERVICE NOTIFICATION.*;CRITICAL;')
         self.show_and_clear_logs()
         self.show_and_clear_actions()
 
@@ -381,7 +377,7 @@ class TestNotif(ShinkenTest):
         print "- 1 x OK -------------------------------------"
         self.scheduler_loop(1, [[svc, 0, 'OK']], do_sleep=True, sleep_time=0.1)
 
-        self.assert_(svc.current_notification_number == 0)
+        self.assertEqual(0, svc.current_notification_number)
         #--------------------------------------------------------------
         # service reaches soft;1
         # there must not be any notification
@@ -408,7 +404,7 @@ class TestNotif(ShinkenTest):
         # check_notification: yes (hard)
         print "---current_notification_number", svc.current_notification_number
         # The contact refuse our notification, so we are still at 0
-        self.assert_(svc.current_notification_number == 0)
+        self.assertEqual(0, svc.current_notification_number)
         print "---------------------------------1st round with a hard"
         print "find a way to get the number of the last reaction"
         cnn = svc.current_notification_number
@@ -445,7 +441,7 @@ class TestNotif(ShinkenTest):
         self.scheduler_loop(1, [[svc, 3, 'BAD']], do_sleep=True, sleep_time=0.1)
         self.show_and_clear_logs()
         self.show_actions()
-        self.assert_(svc.current_notification_number == cnn)
+        self.assertEqual(cnn, svc.current_notification_number)
         #--------------------------------------------------------------
         # again a normal cycle
         # test_contact receives his mail
@@ -458,7 +454,7 @@ class TestNotif(ShinkenTest):
         self.show_and_clear_logs()
         self.show_actions()
         print "svc.current_notification_number, cnn", svc.current_notification_number, cnn
-        #self.assert_(svc.current_notification_number == cnn + 1)
+        #self.assertEqual(cnn + 1, svc.current_notification_number)
         #--------------------------------------------------------------
         # now recover. there must be no scheduled/inpoller notification
         #--------------------------------------------------------------
@@ -466,10 +462,10 @@ class TestNotif(ShinkenTest):
 
         # I do not want a notification of a recovery because
         # the user did not have the notif first!
-        self.assert_(not self.any_log_match('notify-service'))
+        self.assert_no_log_match('notify-service')
         self.show_and_clear_logs()
         self.show_and_clear_actions()
-        self.assert_(svc.current_notification_number == 0)
+        self.assertEqual(0, svc.current_notification_number)
 
     def test_svc_in_dt_and_crit_and_notif_interval_0(self):
         self.print_header()
@@ -491,7 +487,7 @@ class TestNotif(ShinkenTest):
         # initialize host/service state
         #--------------------------------------------------------------
         self.scheduler_loop(1, [[host, 0, 'UP'], [svc, 0, 'OK']], do_sleep=True, sleep_time=0.1)
-        self.assert_(svc.current_notification_number == 0)
+        self.assertEqual(0, svc.current_notification_number)
         #--------------------------------------------------------------
         # service reaches hard;2
         # a notification must have been created
@@ -500,19 +496,19 @@ class TestNotif(ShinkenTest):
         self.scheduler_loop(2, [[host, 0, 'UP'], [svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
         self.show_logs()
         self.show_actions()
-        self.assert_(self.log_match(1, 'SERVICE ALERT.*;CRITICAL;SOFT'))
-        self.assert_(self.log_match(2, 'SERVICE EVENT HANDLER.*;CRITICAL;SOFT'))
-        self.assert_(self.log_match(3, 'SERVICE ALERT.*;CRITICAL;HARD'))
-        self.assert_(self.log_match(4, 'SERVICE EVENT HANDLER.*;CRITICAL;HARD'))
-        self.assert_(self.log_match(5, 'SERVICE NOTIFICATION.*;CRITICAL;'))
-        self.assert_(svc.current_notification_number == 1)
+        self.assert_log_match(1, 'SERVICE ALERT.*;CRITICAL;SOFT')
+        self.assert_log_match(2, 'SERVICE EVENT HANDLER.*;CRITICAL;SOFT')
+        self.assert_log_match(3, 'SERVICE ALERT.*;CRITICAL;HARD')
+        self.assert_log_match(4, 'SERVICE EVENT HANDLER.*;CRITICAL;HARD')
+        self.assert_log_match(5, 'SERVICE NOTIFICATION.*;CRITICAL;')
+        self.assertEqual(1, svc.current_notification_number)
         self.clear_logs()
         self.clear_actions()
         #--------------------------------------------------------------
         # reset host/service state
         #--------------------------------------------------------------
         #self.scheduler_loop(1, [[host, 0, 'UP'], [svc, 0, 'OK']], do_sleep=True, sleep_time=0.1)
-        #self.assert_(svc.current_notification_number == 0)
+        #self.assertEqual(0, svc.current_notification_number)
         duration = 2
         now = time.time()
         # fixed downtime valid for the next 5 minutes
@@ -523,12 +519,12 @@ class TestNotif(ShinkenTest):
         # no notificatio
         #--------------------------------------------------------------
         self.scheduler_loop(2, [[host, 0, 'UP'], [svc, 2, 'BAD']], do_sleep=True, sleep_time=0.1)
-        self.assert_(self.any_log_match('SERVICE DOWNTIME ALERT.*;STARTED'))
-        self.assert_(not self.any_log_match('SERVICE NOTIFICATION.*;CRITICAL;'))
+        self.assert_any_log_match('SERVICE DOWNTIME ALERT.*;STARTED')
+        self.assert_no_log_match('SERVICE NOTIFICATION.*;CRITICAL;')
         # To get out of the DT.
         self.scheduler_loop(2, [[host, 0, 'UP'], [svc, 2, 'BAD']], do_sleep=True, sleep_time=2)
-        self.assert_(not self.any_log_match('SERVICE NOTIFICATION.*;CRITICAL;'))
-        self.assert_(svc.current_notification_number == 1)
+        self.assert_no_log_match('SERVICE NOTIFICATION.*;CRITICAL;')
+        self.assertEqual(1, svc.current_notification_number)
         self.show_and_clear_logs()
         self.show_and_clear_actions()
 
