@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -27,7 +27,7 @@ from shinken_test import *
 
 class TestProblemImpact(ShinkenTest):
     def setUp(self):
-        self.setup_with_file('etc/nagios_problem_impact.cfg')
+        self.setup_with_file('etc/shinken_problem_impact.cfg')
 
     def test_problems_impacts(self):
         self.print_header()
@@ -39,14 +39,14 @@ class TestProblemImpact(ShinkenTest):
         now = time.time()
 
         # The problem_impact_state change should be enabled in the configuration
-        self.assert_(self.conf.enable_problem_impacts_states_change == True)
+        self.assertEqual(True, self.conf.enable_problem_impacts_states_change)
 
         host_router_0 = self.sched.hosts.find_by_name("test_router_0")
         host_router_0.checks_in_progress = []
-        self.assert_(host_router_0.business_impact == 2)
+        self.assertEqual(2, host_router_0.business_impact)
         host_router_1 = self.sched.hosts.find_by_name("test_router_1")
         host_router_1.checks_in_progress = []
-        self.assert_(host_router_1.business_impact == 2)
+        self.assertEqual(2, host_router_1.business_impact)
 
         # Then initialize host under theses routers
         host_0 = self.sched.hosts.find_by_name("test_host_0")
@@ -65,8 +65,8 @@ class TestProblemImpact(ShinkenTest):
         self.scheduler_loop(1, [[host_router_0, 0, 'UP'], [host_router_1, 0, 'UP'], [host_0, 0, 'UP'], [host_1, 0, 'UP']], do_sleep=False)
 
         for h in all_hosts:
-            self.assert_(h.state == 'UP')
-            self.assert_(h.state_type == 'HARD')
+            self.assertEqual('UP', h.state)
+            self.assertEqual('HARD', h.state_type)
 
         #--------------------------------------------------------------
         # Now we add some problems to routers
@@ -75,8 +75,8 @@ class TestProblemImpact(ShinkenTest):
         self.scheduler_loop(1, [[host_router_0, 2, 'DOWN'], [host_router_1, 2, 'DOWN']], do_sleep=False)
         # Max attempt is at 5, should be soft now
         for h in all_routers:
-            self.assert_(h.state == 'DOWN')
-            self.assert_(h.state_type == 'SOFT')
+            self.assertEqual('DOWN', h.state)
+            self.assertEqual('SOFT', h.state_type)
 
         print "- routers get DOWN /HARD-------------------------------------"
         # Now put 4 more checks so we get DOWN/HARD
@@ -87,8 +87,8 @@ class TestProblemImpact(ShinkenTest):
 
         # Max attempt is reach, should be HARD now
         for h in all_routers:
-            self.assert_(h.state == 'DOWN')
-            self.assert_(h.state_type == 'HARD')
+            self.assertEqual('DOWN', h.state)
+            self.assertEqual('HARD', h.state_type)
 
         #--------------------------------------------------------------
         # Routers get HARD/DOWN
@@ -102,40 +102,40 @@ class TestProblemImpact(ShinkenTest):
 
         # Should be problems and have sub servers as impacts
         for h in all_routers:
-            self.assert_(h.is_problem == True)
+            self.assertEqual(True, h.is_problem)
             # Now routers are problems, they should have take the max
             # business_impact value ofthe impacts, so here 5
-            self.assert_(h.business_impact == 5)
+            self.assertEqual(5, h.business_impact)
             for s in all_servers:
-                self.assert_(s in h.impacts)
-                self.assert_(s.get_dbg_name() in host_router_0_brok.data['impacts']['hosts'])
-                self.assert_(s.get_dbg_name() in host_router_1_brok.data['impacts']['hosts'])
+                self.assertIn(s, h.impacts)
+                self.assertIn(s.get_dbg_name(), host_router_0_brok.data['impacts']['hosts'])
+                self.assertIn(s.get_dbg_name(), host_router_1_brok.data['impacts']['hosts'])
 
         # Should have host notification, but it's not so simple:
         # our contact say: not under 5, and our hosts are 2. But
         # the impacts have huge business_impact, so the hosts gain such business_impact
-        self.assert_(self.any_log_match('HOST NOTIFICATION.*;'))
+        self.assert_any_log_match('HOST NOTIFICATION.*;')
         self.show_and_clear_logs()
 
 
         # Now impacts should really be .. impacts :)
         for s in all_servers:
-            self.assert_(s.is_impact == True)
-            self.assert_(s.state == 'UNREACHABLE')
+            self.assertEqual(True, s.is_impact)
+            self.assertEqual('UNREACHABLE', s.state)
             # And check the services are impacted too
             for svc in s.services:
                 print "Service state", svc.state
-                self.assert_(svc.state == 'UNKNOWN')
-                self.assert_(svc.get_dbg_name() in host_router_0_brok.data['impacts']['services'])
-                self.assert_(svc.get_dbg_name() in host_router_1_brok.data['impacts']['services'])
+                self.assertEqual('UNKNOWN', svc.state)
+                self.assertIn(svc.get_dbg_name(), host_router_0_brok.data['impacts']['services'])
+                self.assertIn(svc.get_dbg_name(), host_router_1_brok.data['impacts']['services'])
                 brk_svc = svc.get_update_status_brok()
                 brk_svc.prepare()
-                self.assert_(brk_svc.data['source_problems']['hosts'] == ['test_router_0', 'test_router_1'])
+                self.assertEqual(['test_router_0', 'test_router_1'], brk_svc.data['source_problems']['hosts'])
             for h in all_routers:
-                self.assert_(h in s.source_problems)
+                self.assertIn(h, s.source_problems)
                 brk_hst = s.get_update_status_brok()
                 brk_hst.prepare()
-                self.assert_(h.get_dbg_name() in brk_hst.data['source_problems']['hosts'])
+                self.assertIn(h.get_dbg_name(), brk_hst.data['source_problems']['hosts'])
 
         #--------------------------------------------------------------
         # One router get UP now
@@ -146,18 +146,18 @@ class TestProblemImpact(ShinkenTest):
         self.scheduler_loop(1, [[host_router_0, 0, 'UP']], do_sleep=False)
 
         # should be UP/HARD now
-        self.assert_(host_router_0.state == 'UP')
-        self.assert_(host_router_0.state_type == 'HARD')
+        self.assertEqual('UP', host_router_0.state)
+        self.assertEqual('HARD', host_router_0.state_type)
 
         # And should not be a problem any more!
-        self.assert_(host_router_0.is_problem == False)
-        self.assert_(host_router_0.impacts == [])
+        self.assertEqual(False, host_router_0.is_problem)
+        self.assertEqual([], host_router_0.impacts)
 
         # And check if it's no more in sources problems of others servers
         for s in all_servers:
             # Still impacted by the other server
-            self.assert_(s.is_impact == True)
-            self.assert_(s.source_problems == [host_router_1])
+            self.assertEqual(True, s.is_impact)
+            self.assertEqual([host_router_1], s.source_problems)
 
         #--------------------------------------------------------------
         # The other router get UP :)
@@ -167,24 +167,24 @@ class TestProblemImpact(ShinkenTest):
         self.scheduler_loop(1, [[host_router_1, 0, 'UP']], do_sleep=False)
 
         # should be UP/HARD now
-        self.assert_(host_router_1.state == 'UP')
-        self.assert_(host_router_1.state_type == 'HARD')
+        self.assertEqual('UP', host_router_1.state)
+        self.assertEqual('HARD', host_router_1.state_type)
 
         # And should not be a problem any more!
-        self.assert_(host_router_1.is_problem == False)
-        self.assert_(host_router_1.impacts == [])
+        self.assertEqual(False, host_router_1.is_problem)
+        self.assertEqual([], host_router_1.impacts)
 
         # And check if it's no more in sources problems of others servers
         for s in all_servers:
             # Still impacted by the other server
-            self.assert_(s.is_impact == False)
-            self.assert_(s.state == 'UP')
-            self.assert_(s.source_problems == [])
+            self.assertEqual(False, s.is_impact)
+            self.assertEqual('UP', s.state)
+            self.assertEqual([], s.source_problems)
 
         # And our "business_impact" should have failed back to our
         # conf value, so 2
-        self.assert_(host_router_0.business_impact == 2)
-        self.assert_(host_router_1.business_impact == 2)
+        self.assertEqual(2, host_router_0.business_impact)
+        self.assertEqual(2, host_router_1.business_impact)
         # It's done :)
 
     def test_problems_impacts_with_crit_mod(self):
@@ -197,14 +197,14 @@ class TestProblemImpact(ShinkenTest):
         now = time.time()
 
         # The problem_impact_state change should be enabled in the configuration
-        self.assert_(self.conf.enable_problem_impacts_states_change == True)
+        self.assertEqual(True, self.conf.enable_problem_impacts_states_change)
 
         host_router_0 = self.sched.hosts.find_by_name("test_router_0")
         host_router_0.checks_in_progress = []
-        self.assert_(host_router_0.business_impact == 2)
+        self.assertEqual(2, host_router_0.business_impact)
         host_router_1 = self.sched.hosts.find_by_name("test_router_1")
         host_router_1.checks_in_progress = []
-        self.assert_(host_router_1.business_impact == 2)
+        self.assertEqual(2, host_router_1.business_impact)
 
         # Then initialize host under theses routers
         host_0 = self.sched.hosts.find_by_name("test_host_0")
@@ -219,7 +219,7 @@ class TestProblemImpact(ShinkenTest):
         # Our crit mod that will allow us to play with on the fly
         # business_impact modulation
         critmod = self.sched.conf.businessimpactmodulations.find_by_name('Raise')
-        self.assert_(critmod is not None)
+        self.assertIsNot(critmod, None)
 
         # We lie here, from now we do not want criticities
         for h in all_hosts:
@@ -233,8 +233,8 @@ class TestProblemImpact(ShinkenTest):
         self.scheduler_loop(1, [[host_router_0, 0, 'UP'], [host_router_1, 0, 'UP'], [host_0, 0, 'UP'], [host_1, 0, 'UP']], do_sleep=False)
 
         for h in all_hosts:
-            self.assert_(h.state == 'UP')
-            self.assert_(h.state_type == 'HARD')
+            self.assertEqual('UP', h.state)
+            self.assertEqual('HARD', h.state_type)
 
         #--------------------------------------------------------------
         # Now we add some problems to routers
@@ -243,8 +243,8 @@ class TestProblemImpact(ShinkenTest):
         self.scheduler_loop(1, [[host_router_0, 2, 'DOWN'], [host_router_1, 2, 'DOWN']], do_sleep=False)
         # Max attempt is at 5, should be soft now
         for h in all_routers:
-            self.assert_(h.state == 'DOWN')
-            self.assert_(h.state_type == 'SOFT')
+            self.assertEqual('DOWN', h.state)
+            self.assertEqual('SOFT', h.state_type)
 
         print "- routers get DOWN /HARD-------------------------------------"
         # Now put 4 more checks so we get DOWN/HARD
@@ -255,8 +255,8 @@ class TestProblemImpact(ShinkenTest):
 
         # Max attempt is reach, should be HARD now
         for h in all_routers:
-            self.assert_(h.state == 'DOWN')
-            self.assert_(h.state_type == 'HARD')
+            self.assertEqual('DOWN', h.state)
+            self.assertEqual('HARD', h.state_type)
 
         #--------------------------------------------------------------
         # Routers get HARD/DOWN
@@ -270,62 +270,62 @@ class TestProblemImpact(ShinkenTest):
 
         # Should be problems and have sub servers as impacts
         for h in all_routers:
-            self.assert_(h.is_problem == True)
+            self.assertEqual(True, h.is_problem)
             # Now routers are problems, they should have take the max
             # business_impact value ofthe impacts, so here 2 because we lower all critcity for our test
-            self.assert_(h.business_impact == 2)
+            self.assertEqual(2, h.business_impact)
             for s in all_servers:
-                self.assert_(s in h.impacts)
-                self.assert_(s.get_dbg_name() in host_router_0_brok.data['impacts']['hosts'])
-                self.assert_(s.get_dbg_name() in host_router_1_brok.data['impacts']['hosts'])
+                self.assertIn(s, h.impacts)
+                self.assertIn(s.get_dbg_name(), host_router_0_brok.data['impacts']['hosts'])
+                self.assertIn(s.get_dbg_name(), host_router_1_brok.data['impacts']['hosts'])
 
         # Should have host notification, but it's not so simple:
         # our contact say: not under 5, and our hosts are 2. And here
         # the business_impact was still low for our test
-        self.assert_(not self.any_log_match('HOST NOTIFICATION.*;'))
+        self.assert_no_log_match('HOST NOTIFICATION.*;')
         self.show_and_clear_logs()
 
 
         # Now impacts should really be .. impacts :)
         for s in all_servers:
-            self.assert_(s.is_impact == True)
-            self.assert_(s.state == 'UNREACHABLE')
+            self.assertEqual(True, s.is_impact)
+            self.assertEqual('UNREACHABLE', s.state)
             # And check the services are impacted too
             for svc in s.services:
                 print "Service state", svc.state
-                self.assert_(svc.state == 'UNKNOWN')
-                self.assert_(svc.get_dbg_name() in host_router_0_brok.data['impacts']['services'])
-                self.assert_(svc.get_dbg_name() in host_router_1_brok.data['impacts']['services'])
+                self.assertEqual('UNKNOWN', svc.state)
+                self.assertIn(svc.get_dbg_name(), host_router_0_brok.data['impacts']['services'])
+                self.assertIn(svc.get_dbg_name(), host_router_1_brok.data['impacts']['services'])
                 brk_svc = svc.get_update_status_brok()
                 brk_svc.prepare()
-                self.assert_(brk_svc.data['source_problems']['hosts'] == ['test_router_0', 'test_router_1'])
+                self.assertEqual(['test_router_0', 'test_router_1'], brk_svc.data['source_problems']['hosts'])
             for h in all_routers:
-                self.assert_(h in s.source_problems)
+                self.assertIn(h, s.source_problems)
                 brk_hst = s.get_update_status_brok()
                 brk_hst.prepare()
-                self.assert_(h.get_dbg_name() in brk_hst.data['source_problems']['hosts'])
+                self.assertIn(h.get_dbg_name(), brk_hst.data['source_problems']['hosts'])
 
 
         for h in all_hosts:
             for s in h.services:
                 s.update_business_impact_value()
-                self.assert_(s.business_impact == 2)
+                self.assertEqual(2, s.business_impact)
 
         # Now we play with modulation!
         # We put modulation period as None so it will be right all time :)
         critmod.modulation_period = None
 
         crit_srv = self.sched.services.find_srv_by_name_and_hostname("test_host_1", "test_ok_1")
-        self.assert_(critmod in crit_srv.business_impact_modulations)
+        self.assertIn(critmod, crit_srv.business_impact_modulations)
 
         # Now we set the modulation period as always good, we check that the service
         # really update it's business_impact value
         self.sched.update_business_values()
         # So the service with the modulation should got it's business_impact raised
-        self.assert_(crit_srv.business_impact == 5)
+        self.assertEqual(5, crit_srv.business_impact)
         # And the routers too (problems)
-        self.assert_(host_router_0.business_impact == 5)
-        self.assert_(host_router_1.business_impact == 5)
+        self.assertEqual(5, host_router_0.business_impact)
+        self.assertEqual(5, host_router_1.business_impact)
 
         #--------------------------------------------------------------
         # One router get UP now
@@ -336,18 +336,18 @@ class TestProblemImpact(ShinkenTest):
         self.scheduler_loop(1, [[host_router_0, 0, 'UP']], do_sleep=False)
 
         # should be UP/HARD now
-        self.assert_(host_router_0.state == 'UP')
-        self.assert_(host_router_0.state_type == 'HARD')
+        self.assertEqual('UP', host_router_0.state)
+        self.assertEqual('HARD', host_router_0.state_type)
 
         # And should not be a problem any more!
-        self.assert_(host_router_0.is_problem == False)
-        self.assert_(host_router_0.impacts == [])
+        self.assertEqual(False, host_router_0.is_problem)
+        self.assertEqual([], host_router_0.impacts)
 
         # And check if it's no more in sources problems of others servers
         for s in all_servers:
             # Still impacted by the other server
-            self.assert_(s.is_impact == True)
-            self.assert_(s.source_problems == [host_router_1])
+            self.assertEqual(True, s.is_impact)
+            self.assertEqual([host_router_1], s.source_problems)
 
         #--------------------------------------------------------------
         # The other router get UP :)
@@ -357,24 +357,24 @@ class TestProblemImpact(ShinkenTest):
         self.scheduler_loop(1, [[host_router_1, 0, 'UP']], do_sleep=False)
 
         # should be UP/HARD now
-        self.assert_(host_router_1.state == 'UP')
-        self.assert_(host_router_1.state_type == 'HARD')
+        self.assertEqual('UP', host_router_1.state)
+        self.assertEqual('HARD', host_router_1.state_type)
 
         # And should not be a problem any more!
-        self.assert_(host_router_1.is_problem == False)
-        self.assert_(host_router_1.impacts == [])
+        self.assertEqual(False, host_router_1.is_problem)
+        self.assertEqual([], host_router_1.impacts)
 
         # And check if it's no more in sources problems of others servers
         for s in all_servers:
             # Still impacted by the other server
-            self.assert_(s.is_impact == False)
-            self.assert_(s.state == 'UP')
-            self.assert_(s.source_problems == [])
+            self.assertEqual(False, s.is_impact)
+            self.assertEqual('UP', s.state)
+            self.assertEqual([], s.source_problems)
 
         # And our "business_impact" should have failed back to our
         # conf value, so 2
-        self.assert_(host_router_0.business_impact == 2)
-        self.assert_(host_router_1.business_impact == 2)
+        self.assertEqual(2, host_router_0.business_impact)
+        self.assertEqual(2, host_router_1.business_impact)
         # It's done :)
 
 
