@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -30,9 +30,22 @@ class TestServiceNoHost(ShinkenTest):
         self.setup_with_file('etc/shinken_service_nohost.cfg')
 
     def test_service_with_no_host(self):
-        # Be sure than the conf is valid (a service is void, but it's not a crime)
-        # and it will not be defined
-        self.assert_(self.sched.conf.conf_is_correct)
+        # A service that has no host to be linked to should raise on error.
+        self.assertIs(False, self.conf.conf_is_correct)
+
+        [b.prepare() for b in self.broks.values()]
+        logs = [b.data['log'] for b in self.broks.values() if b.type == 'log']
+
+
+        self.assertLess(
+            0,
+            len( [ log
+                        for log in logs
+                        if re.search(
+                                'a service item has been defined without unique_key ',
+                                log)
+            ])
+        )
 
 
 if __name__ == '__main__':
