@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -31,7 +31,17 @@ class Testservice_without_host(ShinkenTest):
         self.setup_with_file('etc/shinken_service_without_host.cfg')
 
     def test_service_without_host_do_not_break(self):
-        self.assert_(self.conf.conf_is_correct)
+        self.assertIs(False, self.conf.conf_is_correct)
+
+        [b.prepare() for b in self.broks.values()]
+        logs = [b.data['log'] for b in self.broks.values() if b.type == 'log']
+        self.assertLess(
+            0,
+            len([ log
+                    for log in logs
+                    if re.search("The service 'WillError' got an unknown host_name 'NOEXIST'",
+                            log)
+            ]))
 
 
 if __name__ == '__main__':
