@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -50,7 +50,7 @@ class TestConfig(ShinkenTest):
         untaggued_checks = self.sched.get_to_run_checks(True, False, poller_tags=['None'])
         cc = untaggued_checks[0]
         # There must still be a sequence of 10 blanks
-        self.assert_(cc.command.find("Port 2          ") != -1)
+        self.assertNotEqual(cc.command.find("Port 2          "), -1)
 
 if __name__ == '__main__':
     unittest.main()
