@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -28,13 +28,13 @@ from shinken_test import *
 class TestServiceWhithBadHost(ShinkenTest):
     def setUp(self):
         try:
-            self.setup_with_file('etc/nagios_srv_badhost.cfg')
+            self.setup_with_file('etc/shinken_srv_badhost.cfg')
         except AttributeError:
             pass
 
     # Nagios allow service with no host to exist, it will just drop them
     def test_ServiceWhitNoHost(self):
-        self.assert_(self.conf.conf_is_correct == False)
+        self.assertEqual(False, self.conf.conf_is_correct)
 
 
 if __name__ == '__main__':
