@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -27,11 +27,11 @@ from shinken_test import *
 
 class TestServiceWhitNoHost(ShinkenTest):
     def setUp(self):
-        self.setup_with_file('etc/nagios_srv_nohost.cfg')
+        self.setup_with_file('etc/shinken_srv_nohost.cfg')
 
     # Nagios allow service with no host to exist, it will just drop them
     def test_ServiceWhitNoHost(self):
-        self.assert_(self.sched.conf.is_correct)
+        self.assertTrue(self.sched.conf.is_correct)
 
 
 if __name__ == '__main__':
