@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -38,22 +38,22 @@ class TestTPStateLog(ShinkenTest):
         now = time.time()
         tp = self.sched.timeperiods.find_by_name('24x7')
 
-        self.assert_(tp is not None)
+        self.assertIsNot(tp, None)
         tp.check_and_log_activation_change()
-        self.assert_(self.any_log_match("TIMEPERIOD TRANSITION: 24x7;-1;1"))
+        self.assert_any_log_match("TIMEPERIOD TRANSITION: 24x7;-1;1")
         self.show_and_clear_logs()
 
         # Now make this tp unable to be active again by removing al it's daterange:p
         dr = tp.dateranges
         tp.dateranges = []
         tp.check_and_log_activation_change()
-        self.assert_(self.any_log_match("TIMEPERIOD TRANSITION: 24x7;1;0"))
+        self.assert_any_log_match("TIMEPERIOD TRANSITION: 24x7;1;0")
         self.show_and_clear_logs()
 
         # Ok, let get back to work :)
         tp.dateranges = dr
         tp.check_and_log_activation_change()
-        self.assert_(self.any_log_match("TIMEPERIOD TRANSITION: 24x7;0;1"))
+        self.assert_any_log_match("TIMEPERIOD TRANSITION: 24x7;0;1")
         self.show_and_clear_logs()
 
 
