@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2009-2010:
+# Copyright (C) 2009-2014:
 #    Gabes Jean, naparuba@gmail.com
 #    Gerhard Lausser, Gerhard.Lausser@consol.de
 #
@@ -50,45 +50,45 @@ class TestUnknownNotChangeState(ShinkenTest):
 
         print "GO OK" * 10
         self.scheduler_loop(2, [[host, 0, 'UP | value1=1 value2=2'], [router, 0, 'UP | rtt=10'], [svc, 0, 'OK | value1=0 value2=0']])
-        self.assert_(svc.state == 'OK')
-        self.assert_(svc.state_type == 'HARD')
+        self.assertEqual('OK', svc.state)
+        self.assertEqual('HARD', svc.state_type)
 
         print "GO CRITICAL SOFT" * 10
         # Ok we are UP, now we seach to go in trouble
         self.scheduler_loop(1, [[svc, 2, 'PROBLEM | value1=1 value2=2']])
         # CRITICAL/SOFT
-        self.assert_(svc.state == 'CRITICAL')
-        self.assert_(svc.state_type == 'SOFT')
+        self.assertEqual('CRITICAL', svc.state)
+        self.assertEqual('SOFT', svc.state_type)
         # And again and again :)
         print "GO CRITICAL HARD" * 10
         self.scheduler_loop(2, [[svc, 2, 'PROBLEM | value1=1 value2=2']])
         # CRITICAL/HARD
-        self.assert_(svc.state == 'CRITICAL')
-        self.assert_(svc.state_type == 'HARD')
+        self.assertEqual('CRITICAL', svc.state)
+        self.assertEqual('HARD', svc.state_type)
 
         # Should have a notification about it
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION.*;CRITICAL'))
+        self.assert_any_log_match('SERVICE NOTIFICATION.*;CRITICAL')
         self.show_and_clear_logs()
 
         print "GO UNKNOWN HARD" * 10
         # Then we make it as a unknown state
         self.scheduler_loop(1, [[svc, 3, 'Unknown | value1=1 value2=2']])
         # And we DO NOT WANT A NOTIF HERE
-        self.assert_(not self.any_log_match('SERVICE NOTIFICATION.*;UNKNOWN'))
+        self.assert_no_log_match('SERVICE NOTIFICATION.*;UNKNOWN')
         self.show_and_clear_logs()
 
         print "Return CRITICAL HARD" * 10
         # Then we came back as CRITICAL
         self.scheduler_loop(1, [[svc, 2, 'CRITICAL | value1=1 value2=2']])
         print svc.state, svc.state_type
-        self.assert_(not self.any_log_match('SERVICE NOTIFICATION.*;CRITICAL'))
+        self.assert_no_log_match('SERVICE NOTIFICATION.*;CRITICAL')
         self.show_and_clear_logs()
 
         print "Still CRITICAL HARD" * 10
         # Then we came back as CRITICAL
         self.scheduler_loop(1, [[svc, 2, 'CRITICAL | value1=1 value2=2']])
         print svc.state, svc.state_type
-        self.assert_(not self.any_log_match('SERVICE NOTIFICATION.*;CRITICAL'))
+        self.assert_no_log_match('SERVICE NOTIFICATION.*;CRITICAL')
         self.show_and_clear_logs()
 
         # We check if we can still have new notifications of course
@@ -97,7 +97,7 @@ class TestUnknownNotChangeState(ShinkenTest):
             n.t_to_go = time.time()
         self.scheduler_loop(1, [[svc, 2, 'CRITICAL | value1=1 value2=2']])
         print svc.state, svc.state_type
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION.*;CRITICAL'))
+        self.assert_any_log_match('SERVICE NOTIFICATION.*;CRITICAL')
         self.show_and_clear_logs()
 
     # We got problem with unknown results on bad connections
@@ -117,38 +117,38 @@ class TestUnknownNotChangeState(ShinkenTest):
 
         print "GO OK" * 10
         self.scheduler_loop(2, [[host, 0, 'UP | value1=1 value2=2'], [router, 0, 'UP | rtt=10'], [svc, 0, 'OK | value1=0 value2=0']])
-        self.assert_(svc.state == 'OK')
-        self.assert_(svc.state_type == 'HARD')
+        self.assertEqual('OK', svc.state)
+        self.assertEqual('HARD', svc.state_type)
 
         print "GO CRITICAL SOFT" * 10
         # Ok we are UP, now we seach to go in trouble
         self.scheduler_loop(1, [[svc, 2, 'PROBLEM | value1=1 value2=2']])
         # CRITICAL/SOFT
-        self.assert_(svc.state == 'CRITICAL')
-        self.assert_(svc.state_type == 'SOFT')
+        self.assertEqual('CRITICAL', svc.state)
+        self.assertEqual('SOFT', svc.state_type)
         # And again and again :)
         print "GO CRITICAL HARD" * 10
         self.scheduler_loop(2, [[svc, 2, 'PROBLEM | value1=1 value2=2']])
         # CRITICAL/HARD
-        self.assert_(svc.state == 'CRITICAL')
-        self.assert_(svc.state_type == 'HARD')
+        self.assertEqual('CRITICAL', svc.state)
+        self.assertEqual('HARD', svc.state_type)
 
         # Should have a notification about it
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION.*;CRITICAL'))
+        self.assert_any_log_match('SERVICE NOTIFICATION.*;CRITICAL')
         self.show_and_clear_logs()
 
         print "GO UNKNOWN HARD" * 10
         # Then we make it as a unknown state
         self.scheduler_loop(1, [[svc, 3, 'Unknown | value1=1 value2=2']])
         # And we DO NOT WANT A NOTIF HERE
-        self.assert_(not self.any_log_match('SERVICE NOTIFICATION.*;UNKNOWN'))
+        self.assert_no_log_match('SERVICE NOTIFICATION.*;UNKNOWN')
         self.show_and_clear_logs()
 
         print "Return CRITICAL HARD" * 10
         # Then we came back as WARNING here, so a different than we came in the phase!
         self.scheduler_loop(1, [[svc, 1, 'WARNING | value1=1 value2=2']])
         print svc.state, svc.state_type
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION.*;WARNING'))
+        self.assert_any_log_match('SERVICE NOTIFICATION.*;WARNING')
         self.show_and_clear_logs()
 
         # We check if we can still have new notifications of course
@@ -157,13 +157,13 @@ class TestUnknownNotChangeState(ShinkenTest):
             n.t_to_go = time.time()
         self.scheduler_loop(1, [[svc, 1, 'WARNING | value1=1 value2=2']])
         print svc.state, svc.state_type
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION.*;WARNING'))
+        self.assert_any_log_match('SERVICE NOTIFICATION.*;WARNING')
         self.show_and_clear_logs()
 
         # And what if we came back as critical so? :)
         self.scheduler_loop(1, [[svc, 2, 'CRITICAL | value1=1 value2=2']])
         print svc.state, svc.state_type
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION.*;CRITICAL'))
+        self.assert_any_log_match('SERVICE NOTIFICATION.*;CRITICAL')
         self.show_and_clear_logs()
 
     # But we want to still raise notif as unknown if we first met this state
@@ -179,28 +179,28 @@ class TestUnknownNotChangeState(ShinkenTest):
         svc.act_depend_of = []  # no hostchecks on critical checkresults
 
         self.scheduler_loop(2, [[host, 0, 'UP | value1=1 value2=2'], [router, 0, 'UP | rtt=10'], [svc, 0, 'OK | value1=0 value2=0']])
-        self.assert_(svc.state == 'OK')
-        self.assert_(svc.state_type == 'HARD')
+        self.assertEqual('OK', svc.state)
+        self.assertEqual('HARD', svc.state_type)
 
         # Ok we are UP, now we seach to go in trouble
         self.scheduler_loop(1, [[svc, 3, 'PROBLEM | value1=1 value2=2']])
         # UNKOWN/SOFT
-        self.assert_(svc.state == 'UNKNOWN')
-        self.assert_(svc.state_type == 'SOFT')
+        self.assertEqual('UNKNOWN', svc.state)
+        self.assertEqual('SOFT', svc.state_type)
         # And again and again :)
         self.scheduler_loop(2, [[svc, 3, 'PROBLEM | value1=1 value2=2']])
         # UNKNOWN/HARD
-        self.assert_(svc.state == 'UNKNOWN')
-        self.assert_(svc.state_type == 'HARD')
+        self.assertEqual('UNKNOWN', svc.state)
+        self.assertEqual('HARD', svc.state_type)
 
         # Should have a notification about it!
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION.*;UNKNOWN'))
+        self.assert_any_log_match('SERVICE NOTIFICATION.*;UNKNOWN')
         self.show_and_clear_logs()
 
         # Then we make it as a critical state
         # and we want a notif too
         self.scheduler_loop(1, [[svc, 2, 'critical | value1=1 value2=2']])
-        self.assert_(self.any_log_match('SERVICE NOTIFICATION.*;CRITICAL'))
+        self.assert_any_log_match('SERVICE NOTIFICATION.*;CRITICAL')
         self.show_and_clear_logs()
 
     # We got problem with unknown results on bad connections
@@ -218,31 +218,31 @@ class TestUnknownNotChangeState(ShinkenTest):
 
         print "GO OK" * 10
         self.scheduler_loop(2, [[host, 0, 'UP | value1=1 value2=2'], [router, 0, 'UP | rtt=10'], [svc, 0, 'OK | value1=0 value2=0']])
-        self.assert_(svc.state == 'OK')
-        self.assert_(svc.state_type == 'HARD')
+        self.assertEqual('OK', svc.state)
+        self.assertEqual('HARD', svc.state_type)
 
         print "GO DOWN SOFT" * 10
         # Ok we are UP, now we seach to go in trouble
         self.scheduler_loop(1, [[host, 2, 'PROBLEM | value1=1 value2=2']])
         # CRITICAL/SOFT
-        self.assert_(host.state == 'DOWN')
-        self.assert_(host.state_type == 'SOFT')
+        self.assertEqual('DOWN', host.state)
+        self.assertEqual('SOFT', host.state_type)
         # And again and again :)
         print "GO CRITICAL HARD" * 10
         self.scheduler_loop(2, [[host, 2, 'PROBLEM | value1=1 value2=2']])
         # CRITICAL/HARD
-        self.assert_(host.state == 'DOWN')
-        self.assert_(host.state_type == 'HARD')
+        self.assertEqual('DOWN', host.state)
+        self.assertEqual('HARD', host.state_type)
 
         # Should have a notification about it
-        self.assert_(self.any_log_match('HOST NOTIFICATION.*;DOWN'))
+        self.assert_any_log_match('HOST NOTIFICATION.*;DOWN')
         self.show_and_clear_logs()
 
         print "GO UNREACH HARD" * 10
         # Then we make it as a unknown state
         self.scheduler_loop(3, [[router, 2, 'Bad router | value1=1 value2=2']])
         # so we warn about the router, not the host
-        self.assert_(self.any_log_match('HOST NOTIFICATION.*;DOWN'))
+        self.assert_any_log_match('HOST NOTIFICATION.*;DOWN')
         self.show_and_clear_logs()
 
         print "BIBI" * 100
@@ -253,13 +253,13 @@ class TestUnknownNotChangeState(ShinkenTest):
         self.scheduler_loop(1, [[host, 2, 'CRITICAL | value1=1 value2=2']])
         print host.state, host.state_type
         self.show_and_clear_logs()
-        self.assert_(host.state == 'UNREACHABLE')
-        self.assert_(host.state_type == 'HARD')
+        self.assertEqual('UNREACHABLE', host.state)
+        self.assertEqual('HARD', host.state_type)
 
         # The the router came back :)
         print "Router is back from Hell" * 10
         self.scheduler_loop(1, [[router, 0, 'Ok, I am back guys | value1=1 value2=2']])
-        self.assert_(self.any_log_match('HOST NOTIFICATION.*;UP'))
+        self.assert_any_log_match('HOST NOTIFICATION.*;UP')
         self.show_and_clear_logs()
 
         # But how the host will say now?
@@ -267,7 +267,7 @@ class TestUnknownNotChangeState(ShinkenTest):
         print host.state, host.state_type
         # And here we DO NOT WANT new notification
         # If you follow, it THE important point of this test!
-        self.assert_(not self.any_log_match('HOST NOTIFICATION.*;DOWN'))
+        self.assert_no_log_match('HOST NOTIFICATION.*;DOWN')
         self.show_and_clear_logs()
 
         print "Now go in the future, I want a notification"
@@ -279,7 +279,7 @@ class TestUnknownNotChangeState(ShinkenTest):
         self.scheduler_loop(1, [[host, 2, 'CRITICAL | value1=1 value2=2']])
         print host.state, host.state_type
         # And here we DO NOT WANT new notification
-        self.assert_(self.any_log_match('HOST NOTIFICATION.*;DOWN'))
+        self.assert_any_log_match('HOST NOTIFICATION.*;DOWN')
         self.show_and_clear_logs()
 
 
